;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  get_azav_mean2  -  Time average of azimuthal averages
; 
;        usage: get_azav_mean2,dir,qq,recf,nfiles,start,jump,files=files,
;                 gr=gr,outfile=outfile,glob=glob,sc=sc,notquiet=notquiet,
;                 swap=swap,psf=psf,namepsf=namepsf,wnd=wnd
;               where dir      = data directory
;                     qq       = quantity index
;                     recf     = record per file
;                     nfiles   = number of files to read           
;                     start    = starting file iteration      
;                     jump = number of iterations between files    
;                     files    = list of files (used if nfiles, start and skip are nul) 
;                     gr       = stellar rotaiton rate (in solar
;                     units)
;                     outfile  = name of the output file
;                     glob     = prefix of data directory    
;                     sc       = prefix of filenames                
;                     notquiet = verbose if smaller than 2   
;                     swap     = dependant on the endianess of files    
;                     psf      = type of output (screen or .eps)            
;                     namepsf  = name of the .eps output file       
;                     wnd      = number of the window for screen
;                     output   
;                     daysflag = set if time units are days (rather
;                     than sec) 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names

pro get_azav_mean2,dir,qq,recf,nfiles,start,jump,files=files,gr=gr,$
                   outfile=outfile,glob=glob,sc=sc,notquiet=notquiet,$
                   swap=swap,psf=psf,namepsf=namepsf,wnd=wnd,daysflag=daysflag
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Usage message 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

   if n_params() lt 6 then begin 
      print,'get_azav_mean2,dir,qq,recf,nfiles,start,jump,files=files,gr=gr,'+$
            'outfile=outfile,glob=glob,sc=sc,notquiet=notquiet,swap=swap,'+$
            'psf=psf,namepsf=namepsf,wnd=wnd'
      return
   endif
   
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Input settings
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(dir) eq 0 then begin
     print,'  get_azav_mean2.pro:  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'

  if n_elements(qq) eq 0 then begin
     print,'  get_azav_mean2.pro:  parameter qq must be set'
     return
  endif

  if n_elements(recf) eq 0 then begin
     print,'  get_azav_mean2.pro:  parameter recper must be set'
     return
  endif


  if nfiles eq 0 or jump eq 0 then begin
     if files(0) eq -1 then files=findfile(dir)
     firstchar=byte(strmid(files,0,1))
     wh=where((firstchar ge 48b) and (firstchar le 57))
     if wh lt 0 then begin
        print,'  get_azav_mean2.pro:  directory does not contain any valid files'
        return
     endif
     filesl=long(files(wh))
     nfiles=n_elements(files)  
  endif else begin
     filesl=lindgen(nfiles)*jump+start
  endelse

  if not keyword_set(outfile)  then outfile  = 'AZAV_mean'
  if not keyword_set(gr)       then gr       = 1
  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(sc)       then sc       = 1
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0
  if not keyword_set(opl)      then opl      = 0
  if not keyword_set(psf)      then psf      = 0
  if not keyword_set(namepsf)  then namepsf  = "AZAV_test"
  if not keyword_set(wnd)      then wnd      = 0
  if not keyword_set(daysflag) then daysflag = 0
  
  if (glob eq 0) then dir = '/dsm/stars2/f/cemeriau/'+dir
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Graphics devices  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  !p.font=1
  !x.charsize=1.
  !y.charsize=1.
  !p.charsize=3
  device,set_font='Helvetica Italic',/tt_font
  if psf eq 0 then begin
     device,decomposed=0
  endif
  r=[0b,255b,130b,255b,255b,255b,255b,0b  ,75b ,0b  ,75b ,0b  ,75b ,255b,255b,255b,255b]
  g=[0b,255b,130b,0b  ,75b ,0b  ,75b ,0b  ,75b ,255b,255b,255b,255b,255b,255b,170b,195b]
  b=[0b,255b,130b,0b  ,75b ,255b,255b,255b,255b,255b,255b,0b  ,75b ,0b  ,75b ,0b  ,75b ]
  tvlct,r,g,b

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Creation of file array
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  textnum=strcompress(filesl,/r)
  if sc eq 1 then begin
     files = dir + 'AZAV/azav_0' +textnum
  endif else begin
     files = dir +textnum
  endelse

  nfiles=n_elements(files) & nt=intarr(nfiles) & q=intarr(nfiles)
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Initialization
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  nt(*) = recf    
  ntt = long(total(nt))
  
  snap_iter = ntt-1
  P10_iter  = [0,ntt-1]    
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Case for output file name
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  aux_var_name = get_name2(qq)
  outfile = outfile+'_'+aux_var_name
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Global rate and period initialization
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  d=0.0
  dt = 1.d0/(3600.d0*24.d0)
  Global_rate = gr*2.6d-6 
  if (Global_rate ne 2.6d-6) then begin
     print,'!!!                                        !!!'
     print,'!!! Not computing with solar rotation rate !!!'
     print,'!!!                                        !!!'
     wait,2
  endif
  
  P = dt * ((2.*!pi) / Global_rate) ; solar value

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Read in preliminaries - assume N_r, N_Theta remain the same
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  qq2 = -1
  if qq eq 128 then begin
     qq  = 112
     qq2 = 115
  endif
  read_azav2,qq,files(0),0,rad=rad,theta=theta,time=t_o,deltat=deltat,$
             notquiet=notquiet,swap=swap
  
  N_R     = size(rad)   & N_R     = N_R[1]
  N_Theta = size(theta) & N_Theta = N_Theta[1]

  costheta = cos(theta)
  print,'deltat : ',deltat

  iter_1=fix(P/deltat)
  if (iter_1+0.5 lt P/deltat) then iter_1=iter_1+1
  print,iter_1,ntt
  if (iter_1 gt ntt-1) then iter_1=ntt-1
  P1_iter   = [0,iter_1]
  
; double precision accumulation
  f = dblarr(N_Theta,N_R,3)
  ff = fltarr(N_Theta,N_R)
  tt = fltarr(ntt)

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
; Now do the accumulation
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
  
  itt=0
  for ifile=0,nfiles-1 do begin
     for it = 0, nt(ifile)-1 do begin

        read_azav2,qq,files(ifile),it,f=ff,time=time,$
                   notquiet=notquiet,swap=swap
        
        if qq2 gt -1 then begin
           read_azav2,qq2,files(ifile),it,f=ff1,notquiet=notquiet,swap=swap
           ff = ff1 + ff
        endif 

        if daysflag eq 0 then time=time/86400
        if itt eq snap_iter then begin
           f(*,*,0) = ff
        endif
        if (itt ge P1_iter(0)) and (itt le P1_iter(1)) then begin
           f(*,*,1) = f(*,*,1) + ff
        endif
        if (itt ge P10_iter(0)) and (itt le P10_iter(1)) then begin
           f(*,*,2) = f(*,*,2) + ff
        endif

        if itt eq snap_iter   then snap_time = time
        if itt eq P1_iter(0)  then begin_P1  = time
        if itt eq P1_iter(1)  then end_P1    = time
        if itt eq P10_iter(0) then begin_P10 = time
        if itt eq P10_iter(1) then end_P10   = time
        
        tt(itt) = time
        
        itt=itt+1
        v=ff
     endfor
  endfor     
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
; turn sum to average
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  norm = 1.d0/float(P1_iter(1)-P1_iter(0)+1)
  f(*,*,1) = f(*,*,1) * norm
  
  norm = 1.d0/float(P10_iter(1)-P10_iter(0)+1)
  f(*,*,2) = f(*,*,2) * norm
  
  v=reform(f(*,*,1))
  if psf eq 0 then image_polar,v,rad,costheta,title='1 Period Average'
  v=reform(f(*,*,2))
  wait,2
  if psf eq 0 then image_polar,v,rad,costheta,title='Max Periods Average'
  wait,2
  
  print,'  min,max,avg : ',rad(0),min(v(*,0)),max(v(*,0)) ;total(abs(v))/n_elements(v)
  print,'  min,max,avg : ',rad(N_r-1),min(v(*,N_r-1)),max(v(*,N_r-1))
  
  if notquiet lt 2 then   stop

  if psf eq 0 then begin
     !p.multi=[0,1,2]
     plot,90.-acos(costheta)*!radeg,v(*,0),title='r='+strtrim(string(rad(0),format='(g10.4)'),2),ytitle='!17 <V!D!7h!17!N> (m/s)',xtitle='Latitude !7h!17',thick=3,ythick=5,xthick=5,charsize=1.8
     plot,90.-acos(costheta)*!radeg,v(*,N_r-1),title='r='+strtrim(string(rad(N_r-1),format='(g10.4)'),2),ytitle='!17 <V!D!7h!17!N> (m/s)',xtitle='Latitude !7h!17',thick=3,ythick=5,xthick=5,charsize=1.8
     !p.multi=0
  endif

  if notquiet lt 2 then stop
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
; Print information
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  print,' '
  print,'Global Rotation',P,' days' 
  print,' '
  
  dur_P1  = (end_P1-begin_P1)/P
  dur_P10 = (end_P10-begin_P10)/P
  
  print,'-------------------------------------------'
  print,'output file          : '+outfile
  print,'snapshot time        : '+strtrim(string(snap_time,format='(f10.2)'),2)+' days'
  print,'1 period time range  : '+strtrim(string(begin_P1,format='(f10.2)'),2)+$
        '--'+strtrim(string(end_P1,format='(f10.2)'),2)+' days'
  print,'          duration/P : '+strtrim(string(dur_P1,format='(f10.2)'),2)
  print,'Max period time range : '+strtrim(string(begin_P10,format='(f10.2)'),2)+$
        '--'+strtrim(string(end_P10,format='(f10.2)'),2)+' days'
  print,'          duration/P : '+strtrim(string(dur_P10,format='(f10.2)'),2)
  
  nit1  = P1_iter(1)-P1_iter(0) + 1
  nit10 = P10_iter(1)-P10_iter(0) + 1
  
  
  print,' '
  print,'Number of iterations: '+strtrim(string(ntt  ,format='(i6)'),2)
  print,'          1  period : '+strtrim(string(nit1 ,format='(i6)'),2)
  print,'         Max period : '+strtrim(string(nit10,format='(i6)'),2)
  
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
; Save data
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  dims=fltarr(2)
  dims(*) = [N_Theta, N_R]
  
  times=fltarr(5) 
  times(*) = [snap_time,begin_P1,end_P1,begin_P10,end_P10]
  
  ff = fltarr(N_Theta,N_R,3)
  ff(*) = f
  
  close,2 & openw,2,outfile
  writeu,2,dims
  writeu,2,rad,costheta
  writeu,2,times
  writeu,2,ff
  close,2
  
  namepsf = dir+'AZAV/'+outfile
  mv_var = 'mv '+outfile+' '+dir+'AZAV/'+outfile
  print,mv_var
  spawn,mv_var

  print,' '
  print,'check min,max: ',min(f),max(f)

end








