;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  get_shav_mean2.pro  -  Calculate mean shav
;
;       usage: get_shav_mean2,dir,qq,sq,recper,nfiles,start,jump,glob=glob,sc=sc,
;              notquiet=notquiet,swap=swap,savefile=savefile
;                 
;               where dir      = data directory
;                     qq       = output quantity index
;                     sq       = statistical quantity([0,1,2,3,4,5]=[mean,
;                              variance,skewness,kurtosis,min,max]),
;                              default=0 
;                     recper   = number of records per file
;                     nfiles   = number of files
;                     start    = number of the first file
;                     jump     = jump between files
;                     glob     = prefix of data directory
;                     sc       = prefix of filenames
;                     notquiet = verbose if smaller than 2
;                     swap     = change endianess of the file 
;                     savefile = name of IDL saving file
;
;  M.DeRosa - 4 Sep 1998 - modified from Mark's routine
;  A.S. Brun - 2009 - ASH 1.4 version
;  C.Emeriau-Viard - 26 Sept 2016 - Version 2.0 (adapted from see_shav2)
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names

pro get_shav_mean2,dir,qq,sq,recper,nfiles,start,jump,glob=glob,sc=sc,$
              notquiet=notquiet,swap=swap,savefile=savefile

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 7 then begin
     print,'get_shav_mean2,dir,qq,sq,recper,nfiles,start,jump,glob=glob,'+$
           'sc=sc,notquiet=notquiet,swap=swap,savefile=savefile'
     return
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(dir) eq 0 then begin
     print,'  get_shav_mean2.pro:  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'

  if n_elements(qq) eq 0 then begin
     print,'  get_shav_mean2.pro:  parameter q must be set'     
     return
  endif

  if n_elements(sq) eq 0 then begin
     print,'  get_shav_mean2.pro:  parameter sq must be set'     
     return
  endif
  
  if n_elements(recper) eq 0 then begin
     print,'  get_shav_mean2.pro:  parameter recper must be set'
     return
  endif
  
  if n_elements(nfiles) eq 0 then begin
     print,'  get_shav_mean2.pro:  parameter nfiles must be set'
     return
  endif
  
  if n_elements(start) eq 0 then begin
     print,'  get_shav_mean2.pro:  parameter start must be set'
     return
  endif

  if n_elements(jump) eq 0 then begin
     print,'  get_shav_mean2.pro:  parameter jump must be set'
     return
  endif

  if nfiles eq 0 or jump eq 0 then begin
     if files(0) eq -1 then files=findfile(dir)
     firstchar=byte(strmid(files,0,1))
     wh=where((firstchar ge 48b) and (firstchar le 57))
     if wh lt 0 then begin
        print,'  see_scalar2.pro:  directory does not contain any valid files'
        return
     endif
     files=long(files(wh))
     nfiles=n_elements(files)  
  endif else begin
     files=lindgen(nfiles)*jump+start
  endelse

  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(sc)       then sc       = 1
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0
  if not keyword_set(savefile) then savefile = 'Mean_SHAV'

  if glob eq 0 then begin
     dir="/dsm/stars2/f/cemeriau/EvolZR/"+dir
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  close,/all

  r=[0b,255b,130b,255b,255b,255b,255b,0b  ,75b ,0b  ,75b ,0b  ,75b ,255b,255b,255b,255b]
  g=[0b,255b,130b,0b  ,75b ,0b  ,75b ,0b  ,75b ,255b,255b,255b,255b,255b,255b,170b,195b]
  b=[0b,255b,130b,0b  ,75b ,255b,255b,255b,255b,255b,255b,0b  ,75b ,0b  ,75b ,0b  ,75b ]
  tvlct,r,g,b
  
  device,set_font='Helvetica',/tt_font

  !p.font         = 1
  !x.style        = 1
  !x.thick        = 1
  !y.thick        = 1
  !p.thick        = 1
  !p.charthick    = 1.8
  !x.charsize     = 1.2 
  !y.charsize     = 1.2
  !p.charsize     = 1.5
  !x.tickinterval = 0.1
  !p.multi        = 0
  th              = 3

  title    = get_name2(qq)
  savefile = savefile +'_0'+strcompress(files(0),/r)+'_to_0'+strcompress(files(nfiles-1),/r)+'.idl'

  if notquiet lt 2 then print,title

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Set up filename, etc.
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  textnum=strcompress(files,/r)
  
  case sc of
     1: file = dir+'SHAV/shav_0'+textnum
     2: file = dir+'/shav_0'+textnum
     else: file = dir+textnum
  end

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Calculate time averages
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  read_shav2,qq,file(0),0,sq,f=yy,rad=rad,name=name,$
             notquiet=notquiet,swap=swap,time=time
  n_r = size(rad) & n_r = n_r(1)
  value_mean = dblarr(n_r)
  time_old   = time
  time_tot   = 0 

  for ifiles = 0,nfiles-1 do begin
     for recnum=0,recper-1 do begin
        read_shav2,qq,file(ifiles),recnum,sq,f=yy,rad=rad,name=name,$
                   notquiet=notquiet,swap=swap,time=time
        deltat     = time-time_old
        time_old   = time 
        value_mean = value_mean + deltat*yy
        time_tot   = time_tot + deltat
     endfor
  endfor
  value_mean = value_mean/time_tot
  yy         = value_mean
  save,filename=savefile,yy,rad,qq,name

  if notquiet lt 2 then begin
     plot,rad,yy
     stop
  endif

end
