pro image_contour, a, WINDOW_SCALE = window_scale, ASPECT = aspect, $
	INTERP = interp,title=title,xtitle=xtitle, $
	ytitle=ytitle, xx=xx,yy=yy,levels=levels,c_labels=c_labels,$
	charsize=charsize, b=b, noaxis=noaxis, overplot=overplot, c_thick=c_thick,$
        mini=mini,maxi=maxi,blackline=blackline,c_linestyle=c_linestyle
;+
; NAME:
;	IMAGE_CONT
;
; PURPOSE:
;	Overlay an image and a contour plot.
;
; CATEGORY:
;	General graphics.
;
; CALLING SEQUENCE:
;	IMAGE_CONT, A
;
; INPUTS:
;	A:	The two-dimensional array to display as an image.
;       B:     the two-dimensional array of the same dimensions as a to overlay 
;              (default is A itself) as a contour plot.
;
; KEYWORD PARAMETERS:
; WINDOW_SCALE:	Set this keyword to scale the window size to the image size.
;		Otherwise, the image size is scaled to the window size.
;		This keyword is ignored when outputting to devices with 
;		scalable pixels (e.g., PostScript).
;
;	ASPECT:	Set this keyword to retain the image's aspect ratio.
;		Square pixels are assumed.  If WINDOW_SCALE is set, the 
;		aspect ratio is automatically retained.
;
;	INTERP:	If this keyword is set, bilinear interpolation is used if 
;		the image is resized.
;
; OUTPUTS:
;	No explicit outputs.
;
; COMMON BLOCKS:
;	None.
;
; SIDE EFFECTS:
;	The currently selected display is affected.
;
; RESTRICTIONS:
;	None.
;
; PROCEDURE:
;	If the device has scalable pixels, then the image is written over
;	the plot window.
;
; MODIFICATION HISTORY:
;	DMS, May, 1988.
;       Add overplot keyword, 9/17/99
;-

  on_error,2                    ;Return to caller if an error occurs
  sz = size(a)			;Size of image
  if sz(0) lt 2 then message, 'Parameter not 2D'

	;set window used by contour

  contour,[[0,0],[1,1]],/nodata, xstyle=4, ystyle = 4 ;,/isotropic

  px = !x.window * !d.x_vsize	;Get size of window in device units
  py = !y.window * !d.y_vsize
  swx = px(1)-px(0)		;Size in x in device units
  swy = py(1)-py(0)		;Size in Y
  six = float(sz(1))		;Image sizes
  siy = float(sz(2))
  aspi = six / siy		;Image aspect ratio
  aspw = swx / swy		;Window aspect ratio
  f = aspi / aspw               ;Ratio of aspect ratios

  if not keyword_set(title) then title=' '
  if not keyword_set(xtitle) then xtitle=' '
  if not keyword_set(ytitle) then ytitle=' '
  if not keyword_set(c_labels) then c_labels=[0]
  if not keyword_set(c_thick) then c_thick=[1] ; modif add c_thick
  if not keyword_set(c_linestyle) then c_linestyle=[0]
  if not keyword_set(charsize) then charsize=1.0
  if not keyword_set(b) then b=a
  if not keyword_set(blackline) then blackline=0 

  mx = !d.n_colors-1		;Brightest color

  bw=0
  if (bw eq 1) then begin 
     colors=[mx,mx,mx,mx,mx,mx,mx,mx,mx,mx,mx,0,0,0]
  endif else if (blackline eq 1) then begin
     colors=[0]
  endif else begin
     colors = [mx]
  endelse
  
  if (!d.flags and 1) ne 0 then begin ;Scalable pixels?
     if keyword_set(aspect) then begin ;Retain aspect ratio?
                                ;Adjust window size
        if f ge 1.0 then swy = swy / f else swx = swx * f
     endif

     if (keyword_set(mini) or keyword_set(maxi)) then begin
        
        mina=min(a) & maxa=maxi ; modif 03/13/00 due to new color table
        
        for i=0,six-1 do begin
           for j=0,siy-1 do begin
              if (a(i,j) eq mina) then a(i,j)=maxa
           endfor
        endfor

        aa=bytscl(a,min=mini,max=maxi)
        a=aa
        print,'keyword mini',min(a),max(a)
        tv,a,px(0),py(0),xsize=swx,ysize=swy,/device 

        if (keyword_set(noaxis)) then begin
           xstyle=5 & ystyle=5
        endif else begin
           xstyle=1 & ystyle=1
        endelse
        
        offx=0
        offy=0
        
        contour,a,/noerase,xst=xstyle,yst=ystyle,$ ;Do the contour 
                pos = [px(0)+offx,py(0)+offy, px(0)+offx+swx,py(0)+offy+swy],/dev,$
                c_color =  colors,levels=levels,title=title,xtitle=xtitle, $
                ytitle=ytitle,c_labels=c_labels,c_thick=c_thick,charsize=charsize,$
                /overplot,c_linestyle=c_linestyle ;,/isotropic

     endif else begin 

        mina=min(a) & maxa=max(a) ; modif 03/13/00 due to new color table

        for i=0,six-1 do begin
           for j=0,siy-1 do begin
              if (a(i,j) eq mina) then a(i,j)=maxa
           endfor
        endfor
        
        tvscl,a,px(0),py(0),xsize=swx,ysize=swy,/device ; original
     endelse
     
  endif else begin                         ;Not scalable pixels	
     if keyword_set(window_scale) then begin ;Scale window to image?
        tvscl,a,px(0),py(0)                  ;Output image
        swx = six                            ;Set window size from image
        swy = siy
     endif else begin		;Scale window
        if keyword_set(aspect) then begin
           if f ge 1.0 then swy = swy / f else swx = swx * f
        endif                   ;aspect
        
        if (keyword_set(mini) or keyword_set(maxi)) then begin 
           tv,poly_2d(bytscl(a,min=mini,max=maxi),$ ;Have to resample image with mini and maxi
                      [[0,0],[six/swx,0]], [[0,siy/swy],[0,0]],$
                      keyword_set(interp),swx,swy), $
              px(0),py(0) 
        endif else begin     
           tv,poly_2d(bytscl(a),$ ;Have to resample image
                      [[0,0],[six/swx,0]], [[0,siy/swy],[0,0]],$
                      keyword_set(interp),swx,swy),px(0),py(0)
        endelse                 ; mini
     endelse			;window_scale
  endelse			;scalable pixels
  
  if keyword_set(levels) then begin
     
     if (keyword_set(noaxis)) then begin
        xstyle=5 & ystyle=5
     endif else begin
        xstyle=1 & ystyle=1
     endelse

     if keyword_set(overplot) then begin
        if keyword_set(xx) then begin
           contour,b,xx,yy,/noerase,xst=xstyle,yst=ystyle,$ ;Do the contour 
                   pos = [px(0),py(0), px(0)+swx,py(0)+swy],/dev,$
                   c_color =  colors,levels=levels,title=title,xtitle=xtitle, $
                   ytitle=ytitle,c_labels=c_labels,charsize=charsize,c_thick=c_thick,/overplot,c_linestyle=c_linestyle
        endif else begin
           contour,b,/noerase,xst=xstyle,yst=ystyle,$ ;Do the contour 
                   pos = [px(0),py(0), px(0)+swx,py(0)+swy],/dev,$
                   c_color =  colors,levels=levels,title=title,xtitle=xtitle, $
                   ytitle=ytitle,c_labels=c_labels,charsize=charsize,c_thick=c_thick,/overplot,c_linestyle=c_linestyle
        endelse
     endif else begin
        if keyword_set(xx) then begin
           contour,b,xx,yy,/noerase,xst=xstyle,yst=ystyle,$ ;Do the contour 
                   pos = [px(0),py(0), px(0)+swx,py(0)+swy],/dev,$
                   c_color =  colors,levels=levels,title=title,xtitle=xtitle, $
                   ytitle=ytitle,c_labels=c_labels,c_thick=c_thick,charsize=charsize,c_linestyle=c_linestyle
        endif else begin
           contour,b,/noerase,xst=xstyle,yst=ystyle,$ ;Do the contour 
                   pos = [px(0),py(0), px(0)+swx,py(0)+swy],/dev,$
                   c_color =  colors,levels=levels,title=title,xtitle=xtitle, $
                   ytitle=ytitle,c_labels=c_labels,c_thick=c_thick,charsize=charsize,c_linestyle=c_linestyle
        endelse
     endelse                    ; overplot
     
  endif
  return
end






