;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; r_integration_weight.pro - Calculate weights for radial averages
;                             given by the formula  :
;
;                                          OuterRadius
;                                  integral             r^2 f(r) dr
;                                          InnerRadius
;  radial_average =  sum( w * f) = ---------------------------------
;                                          OuterRadius
;                                  integral             r^2 dr
;                                          InnerRadius
;
; Weights are calculated by two means : 
;      - Gauss-Legendre quadrature : when chebyshev is choosen in ASH
;      - Trapezoidal rule : when finite difference is choosen in ASH
;
; /!\ : Sept 2015 : Gauss-Legendre is not fully checked
;
;      usage:  r_integration_weight,radius
;               where radius = radius over integration domain
;                     cheby  = Gauss-Legendre quadrature (by default
;                     trapezoidal rule is used)
;
; C. Emeriau-Viard - Sept 2015             
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

function r_integration_weight,radius,cheby=cheby
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Constants declaration
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if not keyword_set(cheby) then cheby=0

  zero=0.d0
  half=5.d-1
  one=1.d0
  two=2.d0
  
  rad=double(radius)   ; For a better precision
  N_R=size(radius)
  N_R=N_R[1]

  InnerRadius=double(radius[N_R-1])
  OuterRadius=double(radius[0])
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Gauss-Legendre quadrature
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  r_integration_weights=dblarr(N_R)

  tmp = 3.d0*half*!dPi*(OuterRadius-InnerRadius)/((OuterRadius^3 - InnerRadius^3) * N_R) 
  for r=0,N_R-1 do begin
     x = double((two*rad[r]-InnerRadius-OuterRadius)/(OuterRadius-InnerRadius))
     if (x*x eq one) then begin 
        r_integration_weights[r] = zero
     endif else begin 
        r_integration_weights[r] = rad[r]^2 * tmp * sqrt(one-x*x) 
     endelse
  endfor
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Trapezoidal rule
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  r_integration_weights_2 = dblarr(N_R)
  for i = N_R-2,0,-1 do begin
     h2 = (radius[i]-radius[i+1])/2.0
     r_integration_weights_2[i+1] = r_integration_weights_2[i+1]+h2
     r_integration_weights_2[i] = r_integration_weights_2[i]+h2    
     if (h2 lt 0) then print," H2 NEG : ",i,radius[i],radius[i+1]
  endfor
  
  for i = 0, N_R-1 do begin
     r_integration_weights_2[i] = r_integration_weights_2[i]*Radius[i]^2.0
  endfor
  weight_sum = total(r_integration_weights_2)
  r_integration_weights_2 = r_integration_weights_2/weight_sum
    
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
; Returning results depending of choice of numerical method
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  if (cheby eq 0) then begin
     return,r_integration_weights_2
  endif else begin
     return,r_integration_weights
  endelse

end
