;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Finding index where tab[index] = x  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
function index_rad,tab,x
                                ;print,"Value we are looking for : ",x
  s = size(tab)
  s = s[1]
  
  res=s-1
  i=0
  while (i lt s) do begin
     if (tab[i] le x) then begin
        res = i
        i=s
     endif
     i=i+1
  endwhile
  return,res
end

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; radial_integration.pro - Calculate radial averages of a quantity f
;                          over radiative and convective zones
;                          following the formula : 
;
;                                          OuterRadius 
;                                  integral             r^2 f(r) dr
;                                          InnerRadius  
;  radial_average =  sum( w * f) = ---------------------------------
;                                          OuterRadius 
;                                  integral             r^2 dr 
;                                          InnerRadius          
;
; Weights w are calculated by the function 'r_integration_weight.pro'
;   
;        usage: radial_integration,radius,value,rad=rad 
;               where radius = radius over global integration domain (r)
;                     value  = quantity that will be averaged
;                     rbcz   = proportion of radiative core
;                     test   = use to check calculations over a simple
;                     
; C. Emeriau-Viard - Sept 2015 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

function radial_integration,radius,value,rbcz=rbcz,test=test
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Function initialization
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  if n_params() lt 2 then begin
     print,'radial_integration,radius,value,rad=rad,test=test'
     return,res
  endif
  
  if not keyword_set(rbcz)  then rbcz  = 0
  if not keyword_set(test)  then test  = 0

  rad = rbcz*radius[0]
  
  res=dblarr(3)

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Constants declaration
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  i_end=size(radius)
  i_end=i_end[1]-1
  r_s=radius[0]
  r_i=radius[i_end]
  r_z=r_s
  
                                ; Useful when radius are too high for calculations
  r_f=radius[0]
  r_s1=r_s/r_f
  r_z1=r_z/r_f
  r_i1=r_i/r_f
  
                                ; Initialization of integrals
  int_cz=0
  int_rz=0
  
                                ; Weight of each zone into global average
  b_cz=(r_s1^3-r_z1^3)/(r_s1^3-r_i1^3)
  b_rz=(r_z1^3-r_i1^3)/(r_s1^3-r_i1^3)
    
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Get index that divides convective and radiative zones
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  ;i_rad=i_end
  i_rad=index_rad(radius,rad)
  if (i_rad gt -1) then begin
     r_z = rad
  endif
  
  ; Weight of each zone into global average
  r_z1=r_z/r_f
  b_cz=(r_s1^3-r_z1^3)/(r_s1^3-r_i1^3)
  b_rz=(r_z1^3-r_i1^3)/(r_s1^3-r_i1^3)
    
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Calculation of integral in the convective zone if there are two zones
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  value_cz=value[0:i_rad]
  radius_cz=radius[0:i_rad]
  w_cz=r_integration_weight(radius_cz)
  for r=0,i_rad do begin
     int_cz=int_cz+value[r]*w_cz[r]
  endfor
    
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Calculation of the integral in the radiative zone
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  if i_rad ne i_end then begin
     value_rz=value[i_rad:i_end]
     radius_rz=radius[i_rad:i_end]
     w_rz=r_integration_weight(radius_rz)
     for r=i_rad,i_end do begin
        int_rz=int_rz+value[r]*w_rz[r-(i_rad)]
     endfor
  endif
   
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
; Volume of the two zones (included in integration weights)
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
   
;   v_cz = 4*!pi/3*(radius[0]^3-radius[i_rad]^3)
;   v_rz = 4*!pi/3*(radius[i_rad]^3-radius[i_end]^3)
   
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
; Results
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

;   if v_cz eq 0 then res[0] = 0 else res[0]=int_cz/v_cz
;   if v_rz eq 0 then res[1] = 0 else res[1]=int_rz/v_rz

   res[0]=int_cz
   res[1]=int_rz
   res[2]=i_rad
   
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
; If test>0 : comparing result with analytic case : f=r
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
  
   test_cz  = 3.d0/4.d0*(r_s1^4-r_z1^4)/(r_s1^3-r_z1^3)*r_f ; Expected value in CZ
   test_rz  = 3.d0/4.d0*(r_z1^4-r_i1^4)/(r_z1^3-r_i1^3)*r_f ; Expected value in RZ
   test_sum = b_cz*test_cz + b_rz*test_rz                   ; Weighted sum of RZ and CZ results for global value
   test_fin = 3.d0/4.d0*(r_s1^4-r_i1^4)/(r_s1^3-r_i1^3)*r_f ; Expected global value

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
; Printing results
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  if (test eq 0) then begin
     print," "
     print," ---- Convective zone ---- "
     print,"Expected result : ",test_cz
     print,"Calculated result : ",res[0]
     print,"Error (%) : ",abs(res[0]-test_cz)/test_cz*100
     print," "
     print," ---- Radiative zone ---- "
     print,"Expected result : ",test_rz
     print,"Calculated result : ",res[1]
     print,"Error (%) : ",abs(res[1]-test_rz)/test_rz*100
     print," "
     print," ---- Global ---- "
     print,"Expected result : ",test_fin
     res_tot=res[0]*b_cz+res[1]*b_rz
     print,"Calculated result : ",res_tot
     print,"Error (%) : ",abs(res_tot-test_fin)/test*100
     print," "
  endif else begin
     if test eq 1 then begin
        print," "
        print,"Convective zone result : ",res[0]
        print,"Radiative zone result : ",res[1]
        print," "
     endif
  endelse
  return,res
end
