;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  ratio_spectra2.pro  -  Plot ratio_spectra from files coming from get_spectra2
;   
;  usage : spectra2,file=file,icutmax=icutmax,rho=rho,mag=mag,ross=ross,$
;                   notquiet=notquiet,namepsf=namepsf,savef=savef,$
;                   psf=psf,q=q,rbcz=rbcz,fshsl=file_shsl,rstar=rstar,$
;                   swap=swap
;          where file     = output of get_spectra2
;                icutmax  = number of shells
;                rho      = density to calculate KE
;                mag      = also plot magnetic spectra
;                ross     = spectra on velocity components
;                notquiet = verbose if smaller than 2
;                namepsf  = name of output .ps file
;                savef    = save values as .idl files
;                psf      = type of output (screen or .eps)
;                q        = if greater than 1 plot spectra of q
;                rbcz     = percentage of radiative zone
;                fhsl     = path of the shsl file (to get radii of
;                shells)
;                rstar    = stellar radius
;                swap     = dependant of the endianess of files
;                licut    = list icut
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

@get_names

pro ratio_spectra2,files,mag=mag,radii=radii,glob=glob,notquiet=notquiet,swap=swap,$
                   psf=psf,wnd=wnd,ndep=ndep,background=background,dir=dir,$
                   rbcz=rbcz
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  if n_params() lt 1 then begin
     print,'ratio_spectra2,files,mag=mag,radii=radii,glob=glob,notquiet=notquiet,'+$
           'swap=swap,psf=psf,wnd=wnd'
     return
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if not keyword_set(glob)       then glob       = 0
  if not keyword_set(notquiet)   then notquiet   = 0
  if not keyword_set(swap)       then swap       = 0
  if not keyword_set(psf)        then psf        = 0
  if not keyword_set(mag)        then mag        = 0
  if not keyword_set(wnd)        then wnd        = 0
  if not keyword_set(background) then background = 0
  if not keyword_set(q)          then q          = 0
  if not keyword_set(dir)        then dir        = '/dsm/stars2/f/cemeriau/EvolZR/'
  if not keyword_set(rbcz)       then begin
     nfiles = size(files) & nfiles = nfiles(1)
     rbcz   = dblarr(nfiles)
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Graphics device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  !p.font=1
  device,set_font='Helvetica Italic',/tt_font
  
  device,decomposed=0
  r=[0,255,255,225,195,165,0,0,0,0,0,0]
  g=[0,255,0,0,0,0,0,0,0,0,255,225]
  b=[0,255,0,0,0,0,255,225,195,165,0,0]
  tvlct,r,g,b  
  dec=1

  if (psf eq 0) then  window,wnd,xsize=1600,ysize=1000
  !x.style=1
  
  !p.thick=5 & !x.thick=6 & !y.thick=6 & !p.charsize=2.5
  !p.charthick=1.4
  
  if psf eq 1 then !p.charsize=1.5
  
  !p.multi = 0
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  nf        = size(files) & nf = nf[1]
  n_degree  = dblarr(nf)
  n_depths  = dblarr(nf)

  ; Check if all files have the same size n_degree x n_depths
  for ff = 0,nf-1 do begin
     restore,filename=files[ff]
     nratio   = size(Kl1)
     n_degree[ff] = nratio[1]
     n_depths[ff] = nratio[2]
     print,files[ff],rad/radii[ff]
  endfor
  if notquiet eq 0 then stop

  dep  = min(n_depths)
  lmax = min(n_degree)

  if keyword_set(ndep) then dep = ndep
  
  xra = [1,lmax]

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Create ratio files 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  ratio_axi    = dblarr(nf,lmax,dep)
  ratio_nonaxi = dblarr(nf,lmax,dep)
  name_r       = strarr(nf-1)
  
  del_1   = -1

  for ff = 0,nf-1 do begin ; Loop on files 

     if (ff ge 1) and (background eq 0) then begin ; Update if we do not want to take the same background for all ratios
        axi_old    = axi_new
        nonaxi_old = nonaxi_new
        name_old   = name_new
     endif

     aux_del = 0
     shells  = [0,dep-1]
     restore,filename=files[ff]     
     print,ff,' : ',files[ff],'  --  Nb shells : ',n_depths[ff]
     if n_depths[ff] gt dep then begin
        shells = []
        print,rad/radii[ff] 
        del_shell=[]
        print,'Enter the number of the shells you want to delete (0 being the first)'   
        while n_depths[ff]-aux_del gt dep do begin  
           read,del_1
           del_shell = [del_shell,del_1]
           aux_del = aux_del +1
        endwhile
        for i = 0,n_depths[ff]-1 do begin
           if where(del_shell eq i) eq -1 then shells = [shells,i]
        endfor
     endif

     if ff eq 0 then  begin
        rad_depths = rad[shells]/radii[0]
        leg_depths = []
        lin_depths = []
        for i = 0,dep-1 do begin
           leg_depths = [leg_depths,strcompress(rad_depths[i]*100,/r)]
           lin_depths = [lin_depths,i]
        endfor
     endif
     
     tot_new    = kl1[0:lmax-1,shells]
     axi_new    = kl1[0:lmax-1,shells]-kl1nom0[0:lmax-1,shells]
     nonaxi_new = kl1nom0[0:lmax-1,shells]
     name_new   = extract_name(files[ff],'.')

     if (notquiet eq 0) and (psf eq 0) then begin
        window,wnd+1,xsize=1600,ysize=1000        
        plot_io,tot_new[*,0],title=name_new+' tot',xtitle='Degree'
        for i = 1,dep-1 do begin
           oplot,axi_new[*,i],line=i
        endfor
        window,wnd+2,xsize=1600,ysize=1000        
        plot_io,tot_new[*,0],title=name_new+' axi',xtitle='Degree'
        for i = 1,dep-1 do begin
           oplot,axi_new[*,i],line=i
        endfor
        window,wnd+3,xsize=1600,ysize=1000        
        plot_io,nonaxi_new[*,0],title=name_new+' non_axi',xtitle='Degree'
        for i = 1,dep-1 do begin
           oplot,nonaxi_new[*,i],line=i
        endfor
     endif
          
     if ff ge 1 then begin
        ratio_axi[ff-1,*,*]    = axi_new/axi_old
        ratio_nonaxi[ff-1,*,*] = nonaxi_new/nonaxi_old
        name_r[ff-1]           = name_new+'-'+name_old
     endif

     if background eq 0 then begin
        axi_old    = axi_new 
        nonaxi_old = nonaxi_new
        name_old   = name_new
     endif
  endfor
  
  if (q eq 0) then begin 
     qname = 'KE'
     unit = '(erg/cm!U3!N)'
  endif else begin
     qname = get_name2(q)
     unit=''
  endelse
  
; Global kinetic energy as function of l
;  if psf eq 0 then !p.multi=[0,2,1] 

  for ff = 0,nf-2 do begin      ; Loop on the ratios
          
     if (psf eq 1) then begin ; Open psf file
        set_plot,'ps'
        namepsf = 'Spectra_axi_'+name_r[ff]+'.eps'
        device,filename=namepsf,/color,/landscape
     endif else begin         
        !p.multi = [0,2,1]
     endelse

     yrmin = min(ratio_axi[ff,*,*])
     yrmax = max(ratio_axi[ff,*,*])
     yra   = [yrmin,yrmax]

     ansmm = 1
     while ansmm eq 1 do begin  ; While the minmax are not correct
        plot_oo,ratio_axi[ff,*,0],xtit='!5 degree l !5',ytit=qname+unit,yr=yra,/ys,xr=xra,title=name_r[ff]
        for ii = 1,dep-1 do begin ; Loop on the depths
           oplot,ratio_axi(ff,*,ii),line=ii
        endfor
        legend,leg_depths,linestyle=lin_depths,location=2
        if notquiet lt 1 and psf eq 0 then begin
           print,'Are kinetic extrema correct ? (0/1)'
           read,ansmm
           if ansmm eq 1 then begin
              print,'Enter new min-max values'
              read,ymmin,ymmax
              yra=[ymmin,ymmax]
           endif
        endif else begin
           ansmm = 0
        endelse
     endwhile

     if (psf eq 1) then begin
        device,/close
        mv_var='mv '+namepsf+' '+dir+'figs/'+namepsf
        if notquiet lt 1 then print,mv_var
        spawn,mv_var
     endif else begin
        stop
     endelse

     if (psf eq 1) then begin ; Open psf file
        set_plot,'ps'
        namepsf = 'Spectra_nonaxi_'+name_r[ff]+'.eps'
        device,filename=namepsf,/color,/landscape
     endif else begin         
        !p.multi = [0,2,1]
     endelse

     yrmin = min(ratio_nonaxi[ff,*,*])
     yrmax = max(ratio_nonaxi[ff,*,*])
     yra   = [yrmin,yrmax]

     ansmm = 1
     while ansmm eq 1 do begin  ; While the minmax are not correct
        plot_oo,ratio_nonaxi[ff,*,0],xtit='!5 degree l !5',ytit=qname+unit,yr=yra,/ys,xr=xra,title=name_r[ff]
        for ii = 1,dep-1 do begin ; Loop on the depths
           oplot,ratio_nonaxi(ff,*,ii),line=ii
        endfor
        legend,leg_depths,linestyle=lin_depths,location=2
        if notquiet lt 1 and psf eq 0 then begin
           print,'Are kinetic extrema correct ? (0/1)'
           read,ansmm
           if ansmm eq 1 then begin
              print,'Enter new min-max values'
              read,ymmin,ymmax
              yra=[ymmin,ymmax]
           endif
        endif else begin
           ansmm = 0
        endelse
     endwhile

     if (psf eq 1) then begin
        device,/close
        mv_var='mv '+namepsf+' '+dir+'figs/'+namepsf
        if notquiet lt 1 then print,mv_var
        spawn,mv_var
     endif else begin
        stop
     endelse

  endfor
  
  if (psf eq 1) then begin
     set_plot,'x'
  endif

end
  




