;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;   read_eqsl2.pro  -  Reads equatorial slices files
;
;       usage: read_eqsl2,qq,file,recnum,sq,f=f,rad=rad,phi=phi,
;              nlats=nlats,time=time,deltat=deltat,name=name,
;              notquiet=notquiet,swap=swap 
; 
;               where qq       = output quantity 
;                     file     = filename
;                     recnum   = record number
;                     sq       = statistical quantity ([0,1,2,3]=
;                                [normal,vrms,mean,log]) 
;                     f        = output quantity (2D array in that routine)
;                     rad      = output radius 
;                     nphi     = number of longitude
;                     nlats    = number of output latitudes
;                     time     = output time
;                     deltat   = time step
;                     name     = quantity name                
;                     notquiet = verbose if smaller than 2 
;                     swap     = dependant of the endianess of the file 
;        
;  A.S.Brun and J. Varela - 17/03/2015 - user friendly version
;  C.Emeriau-Viard - 13 May 2016 - Version 2.0
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

pro read_eqsl2,qq,file,recnum,sq,f=f,rad=rad,nphi=nphi,nlats=nlats,time=time,$
               deltat=deltat,name=name,notquiet=notquiet,swap=swap
         
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 4 then begin
     print,'read_eqsl2,qq,file,recnum,sq,f=f,rad=rad,nphi=nphi,nlats=nlats,'+$
           'time=time,deltat=deltat,name=name,notquiet=notquiet,swap=swap'
     return
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  close,/all

  if n_elements(qq) eq 0 then begin
     print,'  read_eqsl2.pro:  parameter qq must be set'
     return
  endif
  if n_elements(file) eq 0 then begin
     print,'  read_eqsl2.pro:  parameter file must be set'
     return
  endif
    if n_elements(recnum) eq 0 then begin
     print,'  read_eqsl2.pro:  parameter recnum must be set'
     return
  endif
  if n_elements(sq) eq 0 then begin
     print,'  read_eqsl2.pro:  parameter sq must be set'
     return
  endif

  if qq lt 1 then begin
     print,'  read_eqsl2.pro:  q must be greater than 0' 
     return
  endif
  
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^                    
;  Associate data file                                                
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
  
  temp=0.0
  openu,lun,file,/get_lun,swap_endian=swap
  readu,lun,temp  & N_Phi        = fix(temp)
  readu,lun,temp  & N_R          = fix(temp)
  readu,lun,temp  & Nlats        = fix(temp)
  readu,lun,temp  & N_quantities = fix(temp)
  eq_slices = assoc(lun,fltarr(N_R,N_Phi+1,nlats,N_quantities))
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^          
;  Read code quantities
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  lat_number = fltarr(nlats) & lat_angle = lat_number
  rad        = fltarr(N_R)
  nphi       = N_phi
 
  lat_number(*) = eq_slices(8,0,*,0,0)
  lat_angle(*)  = eq_slices(9,0,*,0,0) ; correspond to colatitude theta in deg

  rad(*)        = eq_slices(*,0,0,1,0)

  nq            = min([n_quantities,n_r])
  quantities    = intarr(nq)
  quantities(*) = fix(eq_slices(0:nq-1,0,0,2,0))
  
  q    = where(quantities eq qq)+1
  while (q eq 0) do begin
     print,"This quantity does not exist."
     print,"Please, enter a new one :"
     read,qq
     q=where(quantities eq qq)+1
  endwhile
  name = get_name2(qq)

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^          
;  Read in equatorial slices data                
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  iteration = long(eq_slices(5,0,0,0,recnum))
  time      = eq_slices(6,0,0,0,recnum)
  deltat    = eq_slices(7,0,0,0,recnum)

  if notquiet lt 2 then begin
     print,'iteration = ',strtrim(iteration,2),$
           ', time = '   ,strtrim(time     ,2),$
           ', delta t = ',strtrim(deltat   ,2)
  endif     

  f = fltarr(N_R,N_phi,nlats)
  for il = 0,nlats-1 do begin
     v=fltarr(N_R,N_phi) & v(*,*)=eq_slices(*,1:N_phi,il,q-1,recnum)
  
     if max(abs(v)) eq 0.0 then begin
        print,'WARNING : array is identically zero'
     endif
     
     if qq lt 3 then v = v/100

     case sq of 
        1: begin
           print,'!!!! Warning uses normalization by sqrt(vrms^2) at all radii!!!'
           vv = v
           for iii=0,N_R-1 do vv(iii,*)=v(iii,*)/sqrt(mean(v(iii,*)^2.0))
           v  = vv
        end
        2: begin
           vv = v 
           for iii=0,N_R-1 do vv(iii,*)=v(iii,*)-mean(v(iii,*))
           v  = vv
        end
        3: begin
           ndvn=where(v le 0.0)
           indvx=where(v gt 0.0)
           v(indvn) = -alog10(abs(v(indvn)))
           v(indvx) = alog10(v(indvx))
        end
        else: if notquiet lt 1 then print,'Nothing to do'
     endcase
     f(*,*,il)=v
  endfor

  free_lun,lun
  if notquiet lt 1 then begin
     print,name
     stop
  endif 

end




