;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
;   read_shsl2.pro - Reads in shell slices files
; 
;       usage :  read_shsl,qq,file,recnum,sq,f=f,rad=rad,theta=theta,phi=phi,
;                time=time,deltat=deltat,name=name,
;                notquiet=notquiet,swap=swap
; 
;               where qq       = output quantity
;                     file     = filename
;                     recnum   = record number
;                     sq       = statistical quantity ([0,1,2,3]=
;                              [normal,mean,diffrot,vorticity])
;                     f        = output quantity array
;                     rad      = output radius
;                     theta    = output latitude
;                     phi      = output longitude
;                     time     = output time
;                     deltat   = time step
;                     name     = quantity name
;                     notquiet = verbose if smaller than 2
;                     swap     = dependant of the endianess of the file
; 
; C.Emeriau-Viard - 03 June 2016 - Version2.0 (adapted from see_shell_slices14)
; ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

pro read_shsl2,qq,file,recnum,sq,f=f,rad=rad,theta=theta,phi=phi,time=time,$
               deltat=deltat,name=name,notquiet=notquiet,swap=swap
  
; ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^        
; Usage message 
; ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^        

  if n_params() lt 4 then begin
     print,'read_shsl2,qq,file,recnum,sq,f=f,rad=rad,theta=theta,phi=phi,'+$
           'time=time,deltat=deltat,name=name,notquiet=notquiet,swap=swap'
     return
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^    
;  Check parameters, set default
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^    

  close,/all

  if n_elements(qq) eq 0 then begin
     print,'  read_shsl2.pro:  parameter qq is not set'
  endif
  
  if n_elements(file) eq 0 then begin
     print,'  read_shsl2.pro:  parameter file is not set'
     return
  endif

  if n_elements(recnum) eq 0 then begin
     print,'  read_shsl.pro:  parameter recnum is not set'
     return
  endif
  if n_elements(sq) eq 0 then begin
     print,'  read_shsl.pro:  parameter sq is not set'
  endif
  
  if qq lt 1 then begin
     print,'  read_shsl2.pro:  q must be greater than 0'
     return
  endif
  
  if not keyword_set(notquiet) then notquiet=0
  if not keyword_set(swap) then swap = 0
  
; ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
; Associate data file         
; ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
  
  temp = 0.0
  openr,lun,file,/g,swap_endian=swap
  readu,lun,temp  &  n_phi=fix(temp)
  readu,lun,temp  &  n_theta=fix(temp)
  readu,lun,temp  &  n_shells=fix(temp)
  readu,lun,temp  &  n_q=fix(temp)
  shell_slices=assoc(lun,fltarr(n_theta,n_phi+1,n_shells,n_q))
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
;  Reads code quantities 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  shell_number=reform(shell_slices(7,0,0:n_shells-1,0,recnum))
  shell_radius=reform(shell_slices(8,0,0:n_shells-1,0,recnum))
  costheta=shell_slices(0:n_theta-1,0,0,1,recnum)
  sintheta=shell_slices(0:n_theta-1,0,0,2,recnum)

  period = 2*n_theta/n_phi

  rad    = shell_radius 
  theta  = acos(costheta)
  phi    = shift((findgen(n_phi*period)+1)*360/(n_phi*period),1)  &  phi(0)=0.0
  phi=phi+.5*(phi(0)+phi(1))-180.
  phi=[phi,phi(0)+360.]
  quantities=fix(shell_slices(0:n_q-1,0,0,3,0))

  q = where(quantities eq qq)+1 
  while (q eq 0) do begin
     print,"This quantity does not exist."
     print,"Please, enter a new one :"
     read,qq
     q=where(quantities eq qq)+1
  endwhile
  name   = get_name2(qq)

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
;  Reads in shell slices data  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
  
  iteration = shell_slices(4,0,0,0,recnum)
  time      = shell_slices(5,0,0,0,recnum)
  deltat    = shell_slices(6,0,0,0,recnum)
  
  if notquiet lt 2 then begin
     print,'  iteration = ',strtrim(iteration,2),$
           ', time = ',strtrim(time,2),$
           ', deltat = ',strtrim(deltat,2)
  endif

  iter = iteration
  
  f1     = reform(shell_slices(*,*,*,q-1,recnum))
  ff     = dblarr(n_theta,n_phi,n_shells)
  f      = dblarr(n_phi+1,n_theta,n_shells)
  for icut = 0,n_shells -1 do begin
     ff(*,*,icut) = f1(*,1:n_phi,icut)
  endfor

  if q lt 3 then ff = ff/100
  
  case sq of
     1: begin
        for icut = 0,n_shells-1 do begin
           for i=0, n_theta-1 do begin
              fmean=mean(double(ff(i,*,icut)))
              for j = 0, N_phi-1 do begin
                 ff(i,j,icut)=ff(i,j,icut)-fmean
              endfor 
           endfor
        endfor
     end
     2: begin
        for icut = 0,n_shells-1 do begin
           for i=0,n_theta-1 do begin
              ff(i,*,icut) = ff(i,*,icut)/(shell_radius(icut)*sintheta(i))
           endfor
        endfor
     end
     3: begin
        dv1=fltarr(N_theta,N_phi) & dv2=dv1
        for icut = 0,n_shells-1 do begin
           v1=reform(shell_slices(*,1:n_phi,icut,2,recnum)) ; v_phi
           v2=reform(shell_slices(*,1:n_phi,icut,1,recnum)) ; v_theta
           for i=0,n_phi-1 do begin
              dv1(*,i)=deriv(theta,v1(*,i))
           endfor
           for i=0,n_theta-1 do begin
              dv2(i,*)=deriv(phi,v2(i,*))
           endfor
           for i=0,n_theta-1 do begin
              ff(i,*,icut)=(dv1(i,*)+costheta(i)*v1(i,*)/sintheta(i)-dv2(i,*)/sintheta(i))/shell_radius(icut)
           endfor
        endfor
     end
     else: if notquiet lt 2 then print,'Normal'
  endcase

  for icut=0,n_shells-1 do begin
     vv1         = ff(*,*,icut)
     vv2         = transpose([[vv1],[vv1(*,0)]])
     vv3         = reverse(vv2,2) 
     f(*,*,icut) = vv3
  endfor

  free_lun,lun
  if notquiet lt 1 then begin
     print,name
     stop
  endif

end
