;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;   see_azav_mean2.pro  - Plot time average of azimuthal averages
; 
;        usage: see_azav_mean2,filename,multim=multim,rbcz=rbcz,idmx=idmx,
;               where filename = name of the saved file containing
;                                time averaged quantities
;                     multim   = number of periof (0 also means 1 period)
;                     rstar    = stellar radius
;                     rmax     = maximum of radius (in stellar radius)                      
;                     rmin     = minimum of radius (in stellar radius)                      
;                     rbcz     = proportion of the radiative zone
;                     gr       = global rate (if nul -> plot vphi; if
;                                not plot omega)
;                     idmx     = interval of the latitude
;                     filedsdr = if q = -2 --> plot dsdr instead of S (q=2)
;                     glob     = prefix of data directory
;                     sc       = prefix of filenames  
;                     notquiet = verbose if smaller than 2
;                     swap     = dependant on the endianess of file
;                     opl      = plot comparison between two models
;                     psf      = type of output (screen or .eps)
;                     namepsf  = name of the .eps file
;                     wnd      = window number
;                     flip     = reverse longitudes
; 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names
@get_units
@colourbar
  
pro see_azav_mean2,filename,q,rstar=rstar,rmin=rmin,rmax=rmax,rbcz=rbcz,gr=gr,$
                   multim=multim,idmx=idmx,filedsdr=filedsdr,radial_plot=radial_plot,$
                   glob=glob,sc=sc,notquiet=notquiet,swap=swap,opl=opl,psf=psf,$
                   namepsf=namepsf,wnd=wnd,flip=flip,legendd=legendd,ymin=ymin,ymax=ymax
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  if n_params() lt 1 then begin
     print,'see_azav_mean2,filename,q,rstar=rstar,rmin=rmin,rmax=rmax,rbcz=rbcz,gr=gr,'+$
           'multim=multim,idmx=idmx,filedsdr=filedsdr,radial_plot=radial_plot,glob=glob,'+$
           'sc=sc,notquiet=notquiet,swap=swap,opl=opl,psf=psf,namepsf=namepsf,wnd=wnd,'+$
           'flip=flip,legendd=legendd'
     return
  endif  

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Input settings
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(filename) eq 0 then begin
     print,'  se_azav_mean2.pro:  parameter filename must be set'
     return
  endif

  if n_elements(q) eq 0 then begin
     print,'  se_azav_mean2.pro:  parameter q must be set'
     return
  endif
  
  if not keyword_set(dir)         then dir         = './' 
  if not keyword_set(rstar)       then rstar       = 6.9599e10
  if not keyword_set(rmin)        then rmin        = 0.0
  if not keyword_set(rmax)        then rmax        = 1.0
  if not keyword_set(rbcz)        then rbcz        = 0.0
  if not keyword_set(gr)          then gr          = 0.0
  if not keyword_set(multim)      then multim      = 0
  if not keyword_set(idmx)        then idmx        = 0
  if not keyword_set(radial_plot) then radial_plot = 0
  if not keyword_set(glob)        then glob        = 0
  if not keyword_set(sc)          then sc          = 0
  if not keyword_set(notquiet)    then notquiet    = 0
  if not keyword_set(swap)        then swap        = 0
  if not keyword_set(opl)         then opl         = 0 
  if not keyword_set(psf)         then psf         = 0
  if not keyword_set(namepsf)     then namepsf     = 0
  if not keyword_set(wnd)         then wnd         = 0
  if not keyword_set(flip)        then flip        = 0
  if not keyword_set(legendd)     then legendd     = 0
  
  if glob eq 0 then begin
     filename = '/dsm/stars2/f/cemeriau/EvolZR'+filename
     dir      = '/dsm/stars2/f/cemeriau/EvolZR'+dir
  endif 

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  close,/all

  loadct_mld,41      
  !p.multi=0
  !p.font=1 & device,set_font='Helvetica Italic',/tt_font
  !p.charsize = 1.3

  if q ne 3 or q ne 7 or q ne -2 then radial_plot = 1

  if (psf eq 0) then begin
     if radial_plot eq 0 then window,wnd,xs=860,ys=540 else window,wnd,xs=700,ys=900
     device,decomposed=0
  endif else begin
     nom = get_azav_name2(q)
     set_plot,'ps'
     device,filename=nom+'.eps',/landscape,/color,bits=8
  endelse

  xxtt=0.05
       
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Reading of azav file 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  dims = fltarr(2)
  
  close,2 & openr,2,filename,swap_endian=swap
  readu,2,dims

  N_R     = fix(dims(1))
  N_Theta = fix(dims(0))
  r       = fltarr(N_R) & costheta = fltarr(N_theta)
  times  = fltarr(5) 
  
  if multim eq 0 then begin
     ff  = fltarr(N_Theta,N_R,3)
     ff1 = fltarr(N_Theta,N_R,3)
     n_max=2
  endif else begin
     print,' '
     print,'how many one period data?'
     read,nbm
     ff  = fltarr(N_Theta,N_R,3+nbm-1)
     ff1 = fltarr(N_Theta,N_R,3+nbm-1)
     n_max1=3+nbm-2
  endelse
  
  readu,2,r,costheta
  readu,2,times
  readu,2,ff
  close,2
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Latitudes and poles
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  lattg = [75.0,60.0,45.0,30.0,15.0,-15.0,-30.0,-45.0,-60.0,-75.0]
  lat   = 90-acos(costheta(*))*!radeg ; latitude
  ilat  = intarr(12) & ilat(5) = (N_theta/2)-1 & ilat(6) = N_theta/2
  
  for jj=0,4 do begin
     indlt    = where(lat lt lattg(jj))
     ilat(jj) = indlt(0)
  endfor

  for jj=5,9 do begin
     indlt      = where(lat gt lattg(jj))
     ilat(jj+2) = max(indlt)
  endfor

; indices pour skipper les poles
  if (idmx eq 1) then begin
     idn = ilat(0) & idx = ilat(11) ; crop at 75deg
  endif else begin
     idn = 0 & idx = N_theta-1
  endelse
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Time and global rate
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  dt = 1.d0/(3600.d0*24.d0)
  Global_rate=gr*2.6d-6
  if (Global_rate ne 2.6d-6) then print,'Not computing with solar rotation rate'
  P  = dt * ((2.*!pi) /Global_rate)  
  t1 = (times(2)-times(1))/P
  t2 = (times(4)-times(3))/P

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Convertion from cm/s to nhz
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  named   = get_azav_name2(q)
  textu   = get_azav_unit2(named)
  yytitle = named

  if (q eq 3)  then begin
     if gr eq 0 then begin
        print,'Enter the rotation rate in solar units'
        read,gr
     endif
     yytitle="!9 W/2p !3(nHz)"
     for i=0,n_max do begin
        for j=0,N_R-1 do begin
           ff1(*,j,i)=ff(*,j,i)/r(j)/sin(acos(costheta(*)))+Global_rate
        endfor
     endfor
     ff1=ff1/2./!pi*1e9         ; s^-1 -> nHz

     v    = reform(ff1(*,*,n_max))
     ymin = 300
     ymax = 600

     plot,90.-acos(costheta)*!radeg,v(*,2),ytitle='!7 X !17 (nHz)',ystyle=1,$
          yrange=[ymin,ymax],thick=3,ythick=5,charsize=1.8,xs=1,xrange=[-75,75],xticks=1
     axis,xaxis=0,xtitle='Latitude',charsize=1.8,xthick=5,xticks=10,xminor=2,$
          xtickname=['-75','-60','-45','-30','-15','0','15','30','45','60','75']
     axis,xaxis=1,xtickname=[' ',' ',' ',' ',' ',' ',' ',' ',' ',' ',' '],xthick=5,$
          xticks=10,xminor=2
     oplot,90.-acos(costheta)*!radeg,v(*,N_r/2),thick=3,linestyle=3
     oplot,90.-acos(costheta)*!radeg,v(*,N_r-2),thick=3,linestyle=4
     oplot,90.-acos(costheta)*!radeg,456-72*costheta^2-42*costheta^4,linestyle=2,thick=3
          
     levels=300+findgen(20)*10 
     c_labels=[1,1,1,1,1,1,1,1,1]
     c_thick=c_labels+1.8     
          
  endif else begin
     retry:
     case q of
        1: begin
           yaa=-30 & ybb=30
        end
        2: begin
           ff1=ff
           yaa=-40 & ybb=30
        end
        -2: begin
           if not keyword_set(filedsdr) then begin
              filedsdr = ''
              print,'Enter name of dsdr idl file'
              read,filedsdr
              restore,file=filedsdr,/ver
              dsdr2d=ff*0.0
              r(513)=3.99997e10 ; ???? HARDCODE 513
              for i=0,n_max do begin
                 for j=0,N_theta-1 do begin
                    dsdr2d(j,*,i)=deriv(r,ff(j,*,i))
                    ff1(j,*,i)=dsdr2d(j,*,i)+dsdr(*)
                 endfor
              endfor
              yaa=-1e-5 & ybb=1e-5
           endif
        end
        4: begin
           ff1=ff/1e8
           yaa=-2 & ybb=4
        end
        5: begin
           ff1=ff
           yaa=-1 & ybb=1
        end
        6: begin
           ff1=ff
           yaa=-1e3 & ybb=1e3
        end
        7: begin
           ff1=ff/1e11   
           yytitle="Enthalpy Flux / 10!U11!N"
           yaa=-1.1 & ybb=1.0
        end
        else: begin
           ff1 = ff
           yytitle = get_name2(q)
           if not keyword_set(ymin) then yaa = min(ff1) else yaa = ymin
           if not keyword_set(ymax) then ybb = max(ff1) else ybb = ymax
        end
     endcase
  endelse
  

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plots
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^   
  
  v     = reform(ff1(*,*,n_max))
  v_tmp = v 
  
  if not keyword_set(ymin) then mini = min(ff1(idn:idx,*,n_max)) else mini = ymin
  if not keyword_set(ymax) then maxi = max(ff1(idn:idx,*,n_max)) else maxi = ymax
  
  ansmm1 = 1 
  while ansmm1 eq 1 do begin
     if (gr gt 0) and (q eq 3) then begin ;if we plot omega ??? redondance c_labels 
        levels=mini+(maxi-mini)*findgen(10)/9.0
        c_labels=[1,0,1,0,1,0,1,0,1,0,1]
        c_thick=c_labels+1.8
     endif
     
     image_polar,v(idn:idx,*),r,costheta(idn:idx),mini=mini,maxi=maxi,flip=flip,levels=levels,$
                 c_labels=c_labels,c_thick=c_thick,rbcz=rbcz ;vmin=mini
     
     if (psf ge 1) then begin
        if (q eq 3) then begin
           colourbar2,[-0.01,0.32,0.01,0.66],mn=mini,mx=maxi, $
                      zero=Global_rate/2./!pi*1e9,plttype='ps' ;,textu=textu
        endif else begin
           colourbar2,[0.01,0.3,0.03,0.64],mn=mini,mx=maxi,plttype='ps'
        endelse
     endif else begin
        if (q eq 3) then begin
           colourbar2,[0.39,0.35,0.41,0.71],mn=mini, mx=maxi,zero=Global_rate/2./!pi*1e9,textu=textu ;,ccs=2.5,h=0
        endif else begin
           colourbar2,[0.06,0.3,0.08,0.64],mn=mini,mx=maxi ;,textu=textu
        endelse
     endelse
     
     if (radial_plot eq 0) then begin ; polar and radial plots
        !p.multi=[0,2,1]
        
        diffr = (max(r)-min(r))/max(r)
        if rstar lt 3e11 then begin
           xxtt=0.1  
           plot,r/rstar,(v_tmp(ilat(5),*)+v_tmp(ilat(6),*))/2.,ytitle=yytitle,ystyle=1,yrange=[yaa,ybb],xstyle=1,xr=[rmin,rmax],xtickinterval=xxtt,charsize=1.4,charthick=1.4,pos=[0.6,0.1,0.95,0.925],xtitle='!3 r/R!D*!3!N'
           plots,[rbcz,rbcz],[yaa,ybb]
        endif else begin
           plot,alog10(r/rstar),alog10((v_tmp(ilat(5),*)+v_tmp(ilat(6),*))/2.),ytitle=yytitle,ystyle=1,yrange=[alog10(yaa),alog10(ybb)],xstyle=1,xr=[alog10(rmin),alog10(rmax)],charsize=1.4,charthick=1.4,pos=[0.6,0.1,0.95,0.925],xtitle='log!D10!N!3(r/R!D*!3!N)'
        endelse
        if rstar gt 3e11 then begin
           oplot,alog10(r/rstar),alog10((v_tmp(ilat(4),*)+v_tmp(ilat(7),*))/2.),linestyle=1,thick=6
           oplot,alog10(r/rstar),alog10((v_tmp(ilat(3),*)+v_tmp(ilat(8),*))/2.),linestyle=2,thick=6
           oplot,alog10(r/rstar),alog10((v_tmp(ilat(2),*)+v_tmp(ilat(9),*))/2.),linestyle=3,thick=6
           oplot,alog10(r/rstar),alog10((v_tmp(ilat(1),*)+v_tmp(ilat(10),*))/2.),linestyle=4,thick=6
           oplot,alog10(r/rstar),alog10((v_tmp(ilat(0),*)+v_tmp(ilat(11),*))/2.),linestyle=5,thick=6
        endif else begin
           oplot,r/rstar,(v_tmp(ilat(4),*)+v_tmp(ilat(7),*))/2.,linestyle=1,thick=6
           oplot,r/rstar,(v_tmp(ilat(3),*)+v_tmp(ilat(8),*))/2.,linestyle=2,thick=6
           oplot,r/rstar,(v_tmp(ilat(2),*)+v_tmp(ilat(9),*))/2.,linestyle=3,thick=6
           oplot,r/rstar,(v_tmp(ilat(1),*)+v_tmp(ilat(10),*))/2.,linestyle=4,thick=6
           oplot,r/rstar,(v_tmp(ilat(0),*)+v_tmp(ilat(11),*))/2.,linestyle=5,thick=6
           plots,[rbcz,rbcz],[yaa,ybb],line=2,thick=4                                    
        endelse
        if legendd eq -1 then legend, ['0','15','30','45','60','75'], linesty=[0,1,2,3,4,5], thick=5, /bottom, /left, charsize=1.5
        if legendd eq -2 then legend, ['0','15','30','45','60','75'], linesty=[0,1,2,3,4,5], thick=5, /bottom, /right, charsize=1.5
        if legendd eq 1 then legend, ['0','15','30','45','60','75'], linesty=[0,1,2,3,4,5], thick=5, /top, /left, charsize=1.5
        if legendd eq 2 then legend, ['0','15','30','45','60','75'], linesty=[0,1,2,3,4,5], thick=5, /top, /right, charsize=1.5
        
     endif else begin           ; if q <> (-2,3,7)
        plot,lat,v_tmp(*,0),xtitle="!17 Latitude (deg)",xstyle=1,xrange=[-90,90],yrange=[yaa,ybb],ystyle=1,ytitle=named+' ('+textu2+')',thick=3,charsize=1.3,pos=[0.6,0.1,0.95,0.925]
        ii1=[N_r/4,N_r/2,3.*N_r/4.,N_r-1]
        oplot,lat,v_tmp(*,ii1(0)),linestyle=1,thick=3 
        oplot,lat,v_tmp(*,ii1(1)),linestyle=2,thick=3 
        oplot,lat,v_tmp(*,ii1(2)),linestyle=3,thick=3
        oplot,lat,v_tmp(*,ii1(3)),linestyle=4,thick=3
        print,r(0),r(ii)
     endelse  
     
     theta_weights = weights_legendre(costheta)
     theta_weights = theta_weights/total(theta_weights,/double) ; normalized to 1
     vm = dblarr(N_r)*0.d0 & vm2 = vm
     for i=0,N_r-1 do begin
        for k=0,N_theta-1 do begin
           vm(i) = vm(i)+(r(i)/rstar)^2*theta_weights(k)*v(k,i) ; good
        endfor
        vm2(i) = (r(i)/rstar)^2*mean(v(*,i),/double)
     endfor
     
     if notquiet lt 2 then begin
        print,' '
        print,'Do you want to keep these min and max values (0/1)?',mini,maxi
        read,ansmm1
        yaa = mini
        ybb = maxi
        if notquiet eq 2 then ansmm1 = 0
        if (ansmm1 eq 1) then begin
           print,'enter new values, min first'
           read,mini,maxi
           if radial_plot eq 0 then begin
              print,'enter new values for the radial cut, min first'
              read,yaa,ybb
           endif
        endif
     endif
  endwhile

  if (psf eq 0) and radial_plot eq 0 then begin
     window,2 & !p.multi=0
     plot,r/rstar,vm,ytit='<Omega>_lat',xtit='r/R',charsize=2
     oplot,r/rstar,vm2,line=2
  endif


  !p.multi=0
  if (psf eq 1) then begin
     device,/close
      mv_var= 'mv '+namepsf+' '+dir+'/figs/'+namepsf
     print,mv_var
     spawn,mv_var
     set_plot,'x'
  endif
end






