;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  flux_balance2.pro  -  Plots fluxes from round code output
;
;       usage: flux_balance,dir,iter,recnum,lum=lum,glob=glob,sc=sc,$
;              notquiet=notquiet,swap=swap,psf=psf,namepsf=namepsf,$
;              xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax
;               where dir      = data directory (Shell_Avgs output)
;                     iter     = iteration number of filename
;                     recnum   = file record number
;                     lstar      = luminosity of star modelled
;                     rstar    = stellar radius
;                     glob     = prefix of data directory
;                     sc       = prefix of filenames
;                     notquiet = verbose if smaller than 2 
;                     swap     = dependant of the endianess of files
;                     opl      = set 1 to overplot
;                     psf      = type of output (screen or .eps) 
;                     namepsf  = name of the .eps output file
;                     wnd      = window number
;                     legendd  = legend is set if 0 and is hidden either
;
;  M.DeRosa - 12 Oct 1998 - modified from Mark's routine
;  A.S. Brun - 18 May 2004 - ASH 1.2 version
;  A.S. Brun - 2009 - ASH 1.4 version
;  C.Emeriau-Viard - 18 May 2016 - Version 2.0
; 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names

pro see_flux_balance2,dir,iter,recnum,lstar=lstar,rstar=rstar,glob=glob,sc=sc,$
                      notquiet=notquiet,swap=swap,opl=opl,psf=psf,namepsf=namepsf,$
                      wnd=wnd,legendd=legendd,xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^   
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^   

  if n_params() lt 3 then begin
     print,'flux_balance2,dir,iter,recnum,lstar=lstar,rstar=rstar,glob=glob,sc=sc,'+$
           'notquiet=notquiet,swap=swap,opl=opl,psf=psf,namepsf=namepsf,'+$
           'wnd=wnd,legendd=legendd,xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax'
     return
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  if n_elements(dir) eq 0 then begin
     print,'  flux_balance2 :  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'
  
  if n_elements(iter) eq 0 then begin
     print,'  flux_balance2:  parameter iter must be set'
     return
  endif
  
  if n_elements(recnum) eq 0 then begin
     print,'  flux_balance2:  parameter recnum must be set'
     return
  endif

  if not keyword_set(lstar)    then lstar    = 3.842e33
  if not keyword_set(rstar)    then rstar    = 6.72e10
  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(sc)       then sc       = 1
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0
  if not keyword_set(opl)      then opl      = 0
  if not keyword_set(psf)      then psf      = 0
  if not keyword_set(namepsf)  then namepsf  = "Flux_Balance"
  if not keyword_set(wnd)      then wnd      = 0
  if not keyword_set(legendd)  then legendd  = 0
  if not keyword_set(mag)      then mag      = 0
  if not keyword_set(xmin)     then xmin     = 0
  if not keyword_set(xmax)     then xmax     = 1
  if not keyword_set(ymin)     then ymin     = -1
  if not keyword_set(ymax)     then ymax     = 2

  if glob eq 0 then begin
     dir="/dsm/stars2/f/cemeriau/"+dir
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^      
; Graphics device                                                            
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  close,/all

  device,decomposed=0
  r=[0b,255b,130b,255b,255b,255b,255b,0b  ,75b ,0b  ,75b ,0b  ,75b ,255b,255b,255b,255b]
  g=[0b,255b,130b,0b  ,75b ,0b  ,75b ,0b  ,75b ,255b,255b,255b,255b,255b,255b,170b,195b]
  b=[0b,255b,130b,0b  ,75b ,255b,255b,255b,255b,255b,255b,0b  ,75b ,0b  ,75b ,0b  ,75b ]
  tvlct,r,g,b

  device,set_font='Helvetica',/tt_font
  
  !p.font      = 1
  !x.style     = 1
  !x.thick     = 5
  !y.thick     = 5
  !p.thick     = 6
  !p.charthick = 1.8
  !p.charsize  = 2.2
  !x.charsize  = 1
  !y.charsize  = 1
  !x.ticks     = 9
  !p.multi     = 0
  th           = 1

  if opl lt 2 then begin
     if (psf eq 0) then begin
        set_plot,'x'
        window,wnd,xsize=1200,ysize=800
     endif else begin 
        if (psf eq 1) then begin
           set_plot,'ps'
           namepsf = namepsf+'_0'+strcompress(iter,/r)+'.eps'
           device,/encapsulated,/landscape,/color,bits=8,filename=namepsf
        endif
     endelse
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
;  Set up filename array, etc.
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  textnum =strcompress(iter,/r)
  if (sc eq 1) then begin
     file = dir +'/SHAV/shav_0'+textnum
  endif else if (sc eq 2) then begin
     file = dir +'/shav_0'+textnum
  endif else begin
     file = dir+textnum
  endelse
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
;  Get radial kinetic energy flux
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  read_shav2,12,file,recnum,0,f=Fke,rad=radius,swap=swap,notquiet=notquiet
   
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
;  Get radial enthalpy flux
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  read_shav2,20,file,recnum,0,f=Fen,rad=radius,swap=swap,notquiet=notquiet
 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
;  Get radial radiative diffusion flux
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  read_shav2,38,file,recnum,0,f=Frd,rad=radius,swap=swap,notquiet=notquiet
 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Get radial entropy diffusion flux
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  read_shav2,36,file,recnum,0,f=Fed,rad=radius,swap=swap,notquiet=notquiet
 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Get radial viscous diffusion flux
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  read_shav2,32,file,recnum,0,f=Fnu,rad=radius,swap=swap,notquiet=notquiet
 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Get radial magnetic energy flux (radial compo of Poynting vector)
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if mag eq 1 then read_shav2,69,file,recnum,0,f=Fmg,rad=radius,swap=swap,notquiet=notquiet else fmg=fen*0.

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Compute luminosities
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  ftot = fke+fen+frd+fed+fmg+fnu
  ltot = ftot*4*!dpi*radius^2
  lke  = fke*4*!dpi*radius^2
  len  = fen*4*!dpi*radius^2
  lrd  = frd*4*!dpi*radius^2
  led  = fed*4*!dpi*radius^2
  lnu  = fnu*4*!dpi*radius^2
  lmg  = fmg*4*!dpi*radius^2
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Plots : min, max and title
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  c = opl
  if opl le 1 then begin
     c = 1-psf 
     xtitle = '!17 r/R!D*!N'
     ytitle = '!17 L/L!D*!N'
  endif     
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Plots 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if opl gt 2 then oplot,radius/rstar,ltot/lstar,color=c $
  else plot,radius/rstar,ltot/lstar,/xs,/ys,xr=[xmin,xmax],yr=[ymin,ymax],ytitle=ytitle,xtitle=xtitle,xtickinterval=0.15,color=c
  if opl eq 0 then c = 3
  oplot,radius/rstar,replicate(lstar,n_elements(radius))/lstar,color=c
  if opl eq 0 then c = 5
  oplot,radius/rstar,lke/lstar,linestyle=4,color=c
  if opl eq 0 then c = 7 
  oplot,radius/rstar,len/lstar,linestyle=3,color=c
  if opl eq 0 then c = 9 
  oplot,radius/rstar,lrd/lstar,linestyle=2,color=c
  if opl eq 0 then c = 11 
  oplot,radius/rstar,led/lstar,linestyle=5,color=c
  
  if max(abs(fnu)) gt 0 then begin
     if opl eq 0 then c = 13
     oplot,radius/rstar,lnu/lstar,linestyle=1,color=c
  endif 

  if max(abs(fmg)) gt 0 then begin
     if opl eq 0 then c = 11
     oplot,radius/rstar,lmg/lstar,linestyle=1,color=c
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plots : legend
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  !p.charsize=1.2
  if legendd ne 0 then begin
     name1 = ['Total luminosity','Radiative diffusion','Enthalpy','Kinetic energy','Modeled SGS processes']
     nvar  = 5
     ls    = [0,2,3,4,5] 
     ly    = [5,5,5,5,5]
     if opl eq 0 then lc = [1-psf,3,5,7,9,11,13]
     if max(abs(lnu)) gt 0 then begin
        name1 = [name1,'Viscous diffusion']
        nvar  = nvar + 1
        ls    = [ls,1]
        ly    = [ly,5]
        if opl eq 0 then lc = [lc,13]
     endif
     if max(abs(lmg)) gt 0 then begin
        name1 = [name1,'Magnetic contribution']
        nvar  = nvar + 1
        ls    = [ls,1]
        ly    = [ly,5]
        if opl eq 0 then lc = [lc,11]
     endif
     if opl eq 0 then legend,name1,linestyle=ls,color=lc,location=legendd,thick=ly else legend,name1,linestyle=ls,location=legendd,thick=ly
  endif

  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plots : output
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if notquiet lt 2 then begin
     if psf eq 1 then print,'File name ps : ',namepsf
     stop
  endif
  
  if (psf eq 1) then begin 
     device,/close
     mv_var = 'mv '+namepsf+' '+dir+'/figs/'+namepsf
     if notquiet lt 2 then print,mv_var
     spawn,mv_var
  endif
  
  
end




