;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;   see_scalar.pro  -  Plot scalar evolution
;                      Modified from Mark's IDL routine
;
;       usage: see_scalar2,dir,lq,sq,recper,nfiles,start,skip,files=files,$
;              glob=glob,sc=sc,notquiet=notquiet,swap=swap,opl=opl,psf=psf,$
;              namepsf=namepsf,wnd=wnd,legendd=legendd,daysflag=daysflag,$
;              xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax$
;              
;               where dir      = data directory
;                     lq       = scalar output quantities
;                     sq       = option (1=mean(quantity), 2=min(quantity), 3=max(quantity)
;                     recper   = number of records per file
;                     nfiles   = number of files to read
;                     start    = starting file iteration
;                     skip     = number of iterations between files
;                     files    = list of files (used if nfiles, start
;                     and skip are nul)
;                     glob     = prefix of data directory
;                     sc       = prefix of filenames
;                     notquiet = verbose if smaller than 2
;                     swap     = dependant on the endianess of files
;                     opl      = set if overplot command should be used
;                     psf      = type of output (screen or .eps)
;                     namepsf  = name of the .eps output file
;                     wnd      = number of the window for screen output
;                     legendd  = legend is set if 0 and is hidden either
;                     daysflag = set if time units are days (rather than sec)
;
;  M.DeRosa - 25 Aug 1998 - modified from Mark's routine
;             15 Sep 1998 - added files keyword
;  A.S.Brun - 28 Jun 1999 - added linestyl keyword
;  M.DeRosa -  6 Jul 1999 - if directory search, weed out invalid files
;  A.S.Brun - 29 Nov 2000 - added sc keyword for file with or without sc_0
;  C.Emeriau_Viard - 13 May 2016 - Version 2.0
; 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names

pro see_scalar2,dir,lq,sq,recper,nfiles,start,skip,files=files,$
                glob=glob,sc=sc,notquiet=notquiet,swap=swap,opl=opl,psf=psf,$
                namepsf=namepsf,wnd=wnd,legendd=legendd,daysflag=daysflag,$
                avg=avg,xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax,gg=gg,t=t,$
                namevar=namevar

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 7 then begin
     print,'see_scalar2,dir,lq,sq,recper,nfiles,start,skip,files=files,'+$
           'glob=glob,sc=sc,notquiet=notquiet,swap=swap,'+$
           'opl=opl,psf=psf,namepsf=namepsf,wnd=wnd,legendd=legendd,'+$
           'daysflag=daysflag,xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax'
     return
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(dir) eq 0 then begin
     print,'  see_scalar2.pro:  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'

  if n_elements(lq) eq 0 then begin
     print,'  see_scalar2.pro:  parameter lq must be set'
     return
  endif

  if n_elements(sq) eq 0 then begin
     print,'  see_scalar2.pro:  parameter m must be set'
     return
  endif

  if n_elements(recper) eq 0 then begin
     print,'  see_scalar2.pro:  parameter recper must be set'
     return
  endif else recordsperfile=recper

  if nfiles eq 0 or skip eq 0 then begin
     if files(0) eq -1 then files=findfile(dir)
     firstchar=byte(strmid(files,0,1))
     wh=where((firstchar ge 48b) and (firstchar le 57))
     if wh lt 0 then begin
        print,'  see_scalar2.pro:  directory does not contain any valid files'
        return
     endif
     files=long(files(wh))
     nfiles=n_elements(files)  
  endif else begin
     files=lindgen(nfiles)*skip+start
  endelse

  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(sc)       then sc       = 1
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0
  if not keyword_set(opl)      then opl      = 0
  if not keyword_set(psf)      then psf      = 0
  if not keyword_set(namepsf)  then namepsf  = "Scalar"
  if not keyword_set(wnd)      then wnd      = 0
  if not keyword_set(legendd)  then legendd  = 0
  if not keyword_set(daysflag) then daysflag = 1
  if not keyword_set(avg)      then avg      = 0
  if not keyword_set(xmin)     then xmin     = -1000
  if not keyword_set(xmax)     then xmax     = -1000
  if not keyword_set(ymin)     then ymin     = -1000
  if not keyword_set(ymax)     then ymax     = -1000
  
  if glob eq 0 then begin
     dir='/dsm/stars2/f/cemeriau/EvolZR/'+dir
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  close,/all
  
  r=[0b,255b,130b,255b,255b,0b  ,0b  ,0b  ,255b,255b]
  g=[0b,255b,130b,0b  ,0b  ,0b  ,255b,255b,255b,170b]
  b=[0b,255b,130b,0b  ,255b,255b,255b,0b  ,0b  ,0b  ]
  tvlct,r,g,b
  
  device,set_font='Helvetica',/tt_font
  
  !p.font         = 1
  !x.style        = 1
  !x.thick        = 4
  !y.thick        = 4
  !p.thick        = 4
  !p.charthick    = 1.8
  !p.charsize     = 1.8
  !x.charsize     = 1
  !y.charsize     = 1
  !p.multi        = 0
  th              = 5

  if (psf eq 0) then begin
     set_plot,'x'
     window,wnd,xsize=1200,ysize=800
     device,decomposed=0
  endif else begin 
     if (psf eq 1) then begin
        set_plot,'ps'
        namepsf=namepsf+'_0'+strcompress(files(0),/r)+'_to_0'+strcompress(files(nfiles-1),/r)+'.eps'
        device,/encapsulated,/landscape,/color,bits=8,filename=namepsf
     endif
  endelse
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Set up filename array, etc.
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  textnum=strcompress(files,/r)

  case sc of
     1: file=dir+'Scalar/scalar_0'+textnum 
     2: file=dir+'0'+textnum 
     else: file=dir+textnum 
  end
   
   nsize = size(lq) & nvar = nsize(1) & if notquiet lt 1 then print,'nb var:',nvar
   
   ntt   = make_array(nfiles,/long,value=recordsperfile)
   nt    = long(total(ntt))  
   t     = fltarr(nt)   
   dt    = fltarr(nt)   
   
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Check variable list for ratio
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
   
   l     = 0
   n_var = 0
   while l lt nvar do begin
      if lq(l) lt 0 then begin
         l = l+1 
         if l eq nvar then begin
            print,'lq not coherent for ratios'
            return
         endif else begin
            if lq(l) ge 0 then begin
               print,'lq not coherent for ratios'
               return
            endif
         endelse
      endif
      l     = l+1
      n_var = n_var + 1
   endwhile

   c_nvar = nvar   
   nvar  = n_var

   print,'N variables : ',nvar

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Read in data
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

   f     = fltarr(nt,nvar)*0.0
   favg  = fltarr(nvar)*0.0
   favg_p= fltarr(nvar)*0.0
  
   name1 = strarr(nvar)
   col1  = strarr(nvar)
   lin1  = strarr(nvar)
   thi1  = strarr(nvar)


   for i=0,nfiles-1 do begin
      for recnum=0,ntt(i)-1 do begin 
         l     = 0 
         l_aux = 0
         while l lt c_nvar do begin
            if (i eq 0) and recnum eq 0 then nq = notquiet else nq = 2
            if lq(l) ge 0 then begin
               qq  = lq(l)
;               qq2 = -1 
            endif else begin
               qq  = -lq(l)
               l   = l+1
               qq2 = -lq(l)
            endelse
            read_scalar2,qq,file(i),recnum,sq,f=ff,t=tt,dt=dtt,name=name,notquiet=nq,swap=swap,qq2=qq2
            name1(l_aux)=name
            f(i*ntt(i)+recnum,l_aux) = ff
            dt(i*ntt(i)+recnum)  = dtt
            t(i*ntt(i)+recnum)   = tt
            l                    = l+1  
            l_aux                = l_aux+1
         endwhile
      endfor
   endfor
   
   namevar = name1

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Calculate time average (if asks)
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

   if avg ge start then begin
      n_avg = (avg-start)/skip
      for l = 0,nvar-1 do begin
         tavg = 0
         for  fi = n_avg,nfiles-1 do begin
            for recnum = 0,ntt(fi)-1 do begin
               favg[l] = favg[l] + f(fi*ntt(fi)+recnum,l) * dt(fi*ntt(fi)+recnum)
               tavg = tavg + dt(fi*ntt(fi)+recnum)
            endfor
         endfor
      endfor
      favg = favg/tavg

      print,' '
      print,name1(0),' : ',favg(0),'  ('+strcompress(f(nt-1,0),/r)+')'
      favg_p[0] = favg(0)
      s_absolu = strcompress(favg(0),/r)
      s_perc   = strcompress(favg(0),/r)
      s_name   = name1(0)
      for l = 1,nvar-1 do begin
         print,name1(l),' : ',favg(l),favg(l)/favg(0),'  ('+strcompress(f(nt-1,l),/r)+')'
         favg_p[l] = favg(l)/favg(0)
         s_absolu = s_absolu + ' & ' + strcompress(favg(l),/r) 
         s_perc   = s_perc + ' & ' + strcompress(favg_p(l),/r) 
         s_name   = s_name + ' & ' + name1(l)
      endfor 
      print,' '
      print,s_name
      print,s_absolu
      print,s_perc
      print,' '
   endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plots : min, max and title
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

   c = opl
   if opl le 1 then begin
      c = 1-psf
      xtitle = '!17 time (sec)'
      ytitle = name
      if daysflag then begin
         t=t/(3600.*24.d0)
         xtitle = 'Time [days]'
      endif
      
      to=t(0)
      if notquiet lt 1 then  begin
         print,'starting time: ',to
         print,'.c automatically draw all var'
      endif
      
      yra=min(f) & yrb=max(f)
      if xmin eq -1000 then xmin = 0
      if xmax eq -1000 then xmax = t(nt-1)-to
      if ymin eq -1000 then ymin = yra
      if ymax eq -1000 then ymax = yrb
      
      if notquiet lt 2 then begin
         answ1 = 0
         print,'min-max proposed:',ymin,ymax 
         print,'do you want to retain them (0/1)?'
         read,answ1
         if (answ1 ne 0) then begin
            print,'Please enter new values:'
            read,ymin,ymax
         endif
      endif
      
      dx  = xmax - xmin
      e   = fix(alog10(dx))
      a   = fix(dx/10^e)
      xt  = a*10^(e-1)
   endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plots 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

   if opl gt 1 then oplot,t-to,f(*,0),thick=th,color=c else plot_io,t-to,f(*,0),/xs,/ys,xr=[xmin,xmax],yr=[ymin,ymax],xtitle=xtitle,$
      title='Evolution of energies',thick=th,xtickinterval=xt,color=c
   col1[0] = c
   lin1[0] = 0
   thi1[0] = th
   
   for l=1,nvar-1 do begin
      if (l le 5) then begin
         if opl eq 0 then c = 2+l
         oplot,t-to,f(*,l),thick=th,line=l,color=c
         col1[l] = c
         lin1[l] = l
         thi1[l] = th
      endif else begin
         if opl eq 0 then c = l-3
         oplot,t-to,f(*,l),thick=2*th,line=l-5,color=c
         col1[l] = c
         lin1[l] = l-5
         thi1[l] = 2*th
      endelse
   endfor

   gg = f
   
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plots : legend
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

   if (legendd ne 0) and (opl lt 2) then legend,name1,linestyle=lin1,color=col1,thick=thi1,location=legendd

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plots : output
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
   
   if (psf eq 1) then begin
      device,/close
      mv_var='mv '+namepsf+' '+dir+'/figs/'+namepsf
      if notquiet lt 1 then print,mv_var
      spawn,mv_var
      set_plot,'x'
   endif
   
   if notquiet lt 2 then begin
      stop
   endif
   
end
