;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  time_lat_azav2.pro  -  Reads in shell average output and plot versus time
;
;       usage:  time_lat_azav,q,nfiles,start,skip,lr,dir,radstar,$
;               r_bcz=r_bcz,psf=psf,swap=swap
;
;               where dir      = data directory
;                     q        = output quantity index (starting at 1)
;                     sq       = statistical quantity
;                     ([0,1,2,3,4,5]=[mean,variance,skewness,kurtosis,min,max]), default=0
;                     recper   = number of records per file
;                     nfiles   = number of files to read
;                     start    = starting file iteration
;                     skip     = number of iterations between files
;                     lr       = list of radial grid points
;                     rstar    = star radius
;                     omega    = plot omega at omega rate (if not nul)
;                     glob     = prefix of data directory 
;                     sc       = prefix of filenames      
;                     notquiet = verbose if smaller than 2
;                     swap     = dependant on the endianess of files
;                     opl      = set if overplot command should be
;                     used 
;                     psf      = type of output (screen or .eps)
;                     namepsf  = name of the .eps output file 
;                     wnd      = number of the window for screen
;                     output 
;
;  A.S. Brun and J. Varela- 2014 - ASH 2.0 version
;  C.Emeriau-Viard - 21 June 2016 - Version 2.0
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names
@get_units
@UniformDerivative6.pro

pro time_PY_azav14,dir,nfiles,start,skip,omega,lr=lr,rstar=rstar,alpha_pp=alpha_pp,$
                    glob=glob,sc=sc,notquiet=notquiet,swap=swap,opl=opl,$
                    psf=psf,namepsf=namepsf,wnd=wnd

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 5 then begin
     print,'  time_lat_azav14,dir,nfiles,start,skip,omega,lr=lr,rstar=rstar,'+$
           'glob=glob,sc=sc,notquiet=notquiet,swap=swap,opl=opl,'+$
           'psf=psf,namepsf=namepsf,wnd=wnd'
     return
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  if n_elements(dir) eq 0 then begin
     print,'  time_lat_azav.pro:  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'

  if n_elements(nfiles) eq 0 then begin
     print,'  time_lat_azav.pro:  parameter nfiles must be set'
     return
  endif
  if n_elements(start) eq 0 then begin
     print,'  time_lat_azav.pro:  parameter start must be set'
     return
  endif
  if n_elements(skip) eq 0 then begin
     print,'  time_lat_azav.pro:  parameter skip must be set'
     return
  endif
  if n_elements(omega) eq 0 then begin
     print,'  time_lat_azav.pro:  parameter omega (in solar units) must be set'
     return
  endif

  if not keyword_set(alpha_pp) then alpha_pp =1
  if not keyword_set(lr)       then lr       = [0]
  if not keyword_set(rstar)    then rstar    = 1
  if not keyword_set(rbcz)     then rbcz     = 0
  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(sc)       then sc       = 0
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0
  if not keyword_set(opl)      then opl      = 0
  if not keyword_set(psf)      then psf      = 0
  if not keyword_set(namepsf)  then namepsf  = 'ButterflyDiagram'
  if not keyword_set(wnd)      then wnd      = 0

  if glob eq 0 then dir = '/dsm/stars2/f/cemeriau/'+dir

  files=lindgen(nfiles)*skip+start

  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
; Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  close,/all
  
  tv=1 
  flip=0 
  daysflag=1
  
  if (psf eq 0) then begin
     set_plot,'x'
     device,decomposed=0
     window,wnd
  endif else begin
     set_plot,'ps'
     namepsf=namepsf+'_0'+strcompress(files(0),/r)+'_to_0'+strcompress(files(nfiles-1),/r)+'.eps'
     device,/landscape,/color,bits=8,filename=namepsf+'.ps',/helvetica
  endelse
  
  !p.multi=0
  loadct_mld,41

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
; Set up filename array, etc.
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  file=strarr(nfiles)  
  nt=intarr(nfiles) & kk=fltarr(nfiles)  
  nt(*)=1
  nframes = total(nt)
  timel=fltarr(nframes)

  k=start  

  textnum = strcompress(files,/r)      
  if (sc eq 1) then begin
      file=dir+'/AZAV/azav_0'+textnum
   endif else if (sc eq 2) then begin
      file=dir+'0'+textnum
   endif else begin
      file=dir+textnum
   endelse  
  print,'from: ',files(0),' to ',files(nfiles-1)
  
  Global_rate=2.6d-6*omega
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
;  Associate data file
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  read_azav2,3,file(0),0,f=f,rad=rad,theta=theta,time=time,$
                   name=title,notquiet=2,swap=swap,omega=Global_rate
  
  if notquiet lt 1 then print,title

  n_theta = size(theta) & n_theta = n_theta[1]
  n_r     = size(rad)   & n_r     = n_r[1]
  N_depth = n_elements(lr)    ; three depths for lat plot
  to      = time/86400
  print,'TO :::',to

  if notquiet lt 1 then print,'depths: ',N_depth,' r = ',rad(lr)/rstar

  lat=reverse(90.-theta*!radeg)
  sintheta = sin(theta)

  v_lat=fltarr(nframes,N_theta,N_depth)

  title = 'S!Dtheta!N'
  textu = 'm/s!U-1!N'

  idn=0 & idx=N_theta-1 

   mini = fltarr(N_depth)
   maxi = fltarr(N_depth)
  
   for ifile = 0,nfiles-1 do begin
      for it = 0,nt(ifile)-1 do begin
         print,ifile,it
         read_azav2,3,file(ifile),it,f=f,rad=rad,theta=theta,time=time,$
                    name=title,notquiet=2,swap=swap,omega=Global_rate
         domega = ud6(rad[1]-rad[0],f)
         
         rad2D = dblarr(n_theta,n_r) 
         st2D  = dblarr(n_theta,n_r)
         
         for i=0,n_theta-1 do rad2D[i,*] = rad
         for i=0,n_r-1     do st2D[*,i]  = sintheta
         
         stheta = -rad2D*st2D/Global_rate*alpha_pp*domega
         
         for dd=0,n_depth-1 do begin
            j = lr(dd)
            v = stheta(*,j)
            
            if ifile eq 0 and it eq 0 then begin
               mmaux    = minmax(v(idn:idx))
               mini(dd) = mmaux[0]
               maxi(dd) = mmaux[1]
            endif else begin
               mmaux    = minmax(v(idn:idx))    
               mini(dd) = min([mini(dd),mmaux[0]])
               maxi(dd) = max([maxi(dd),mmaux[1]])
            endelse
            v_lat(ifile*nt(ifile)+it,*,dd) = v
         endfor
      endfor
   endfor
   
   title = 'S!Dtheta!N'
   textu = ' m/s!U-1!N'
   
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
; Plot of Stheta (loop to adjust minmax without rereading all files)
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
  
   repet = 1 
   while repet eq 1 do begin
      for dd=0,n_depth-1 do begin
         print,mini(dd),maxi(dd), '  at N_R =', lr(dd)
         
         if notquiet lt 2 then begin
            print,'Do you want to keep them (0/1)'
            read,ans
            if (ans eq 1) then begin
               print,'Enter new min/max:'
               read,a,b
               mini(dd)=a
               maxi(dd)=b
            endif
         endif
      endfor
      
      for ifile=0,nfiles-1 do begin
        for it = 0,nt(ifile)-1 do begin
           
           sp=max(rad)/200.
                     
; Contrary to butterfly diagrams, omega is always strictly positive
; here
           
           levels=100+findgen(21)*20
           c_labels=[0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,0]
           
                                ;plot_on = 0
                                ;if (plot_on eq 1) then begin
           ;   if tv then image_polar,v(idn:idx),rad,costheta(idn:idx),sp=sp,mini=mini(ii),maxi=maxi(ii),levels=levels,c_labels=c_labels, rbcz=rbcz $
           ;   else contour_polar,v(idn:idx),rad,costheta(idn:idx),tit=title
           ;   title1 = title+' t= '+strtrim(string(time-to,format='(g10.3)'),2)+' days'
           ;   if tv then xyouts,0.60,0.06,title1,/normal,charsize=1.5
           ;   if (omega ge 0) then begin
           ;     if tv then colourbar,[0.5,0.03,0.85,0.05],mn=mini(ii),mx=maxi(ii),textu=textu,zero=Global_rate/2./!pi*1e9 
           ;   endif else begin
           ;      if tv then colourbar,[0.5,0.03,0.85,0.05],mn=mini(ii),mx=maxi(ii),textu=textu 
           ;   endelse 
           ;endif                ; plot_on
        endfor                  ; it
     endfor                     ; ifiles
     
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plot : Butterfly
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

     !p.multi=[0,1,N_depth]
     !y.margin=[4,4]
     
     print,'Time sequence:',timel(0),timel(nframes-1)
     
     v_lat_mean=fltarr(N_theta,N_depth) & v_lat_mean(*,*)=0.0
     
     !x.thick=5 & !y.thick=5
     
     ttit1 = strarr(n_depth)

     for ii=N_depth-1,0,-1 do begin
        
        ttit1(ii)=title+' @ r = '+strtrim(string(rad(lr(ii))/rstar,format='(g10.2)'),2)+$
                  ' R' & print,ttit1(ii)
        
        ii1=N_depth-1-ii
        if (ii1 eq 0) then begin
           contour,v_lat(*,*,ii),timel,lat,yr=[-90,90],xr=[0,timel(nframes-1)],$
                   /xsty,/ysty,xtit='!17 time !6[!17days!6]!17',ytit='!17 latitude !6[!17deg!6]!17',$
                   /nodata,ticklen=-abs(!p.ticklen),charsiz=3.2,$
                   position=[0.1,0.08+0.30*ii1,0.9,0.38+0.30*ii1] ;tit=ttit1(ii)
        endif else begin
           contour,v_lat(*,*,ii),timel,lat,yr=[-90,90],xr=[0,timel(nframes-1)],$
                   /ysty,ytit='!17 latitude !6[!17deg!6]!17',xs=4,$
                   /nodata,ticklen=-abs(!p.ticklen),charsiz=3.2,$
                   position=[0.1,0.08+0.30*ii1,0.9,0.38+0.30*ii1]
        endelse

        
                                ; temporal average
        mean_sub=0
        if (mean_sub eq 1) then begin
           v_lat_mean(*,ii)=total(v_lat(*,*,ii),1)/nframes
           For k=0,nframes-1 do begin
              v_lat(k,*,ii)=v_lat(k,*,ii)-v_lat_mean(*,ii)
           Endfor
        endif                   ; mean_sub
        
        
                                ;  overplot image
        x0=!p.clip(0)  &  y0=!p.clip(1)
        xsiz=!p.clip(2)-x0  &  ysiz=!p.clip(3)-y0
        
; smoothing in time
                                ; v_lat=smooth(v_lat,[1,4])
        if (psf eq 0) then remap=congrid(v_lat(*,*,ii),xsiz,ysiz) else remap=v_lat(*,*,ii)

        mul=1.0  
        
        scim,remap,scale=mul*[mini(ii),maxi(ii)],outim=outim,/nowin


        image,smooth(outim,2),x0,y0,xsiz=xsiz,ysiz=ysiz
        contour,smooth(outim,2),/overplot,nlevels=10
        stop

        
;  redraw border
        plots,[x0,x0,x0+xsiz,x0+xsiz,x0],[y0,y0+ysiz,y0+ysiz,y0,y0],/device,thick=5

     Endfor
     
     print,'Is the plot correct ? (0/1)'
     read,repet
  endwhile
  
  if (psf eq 1) then begin 
     device,/close
     set_plot,'x'
  endif
  
end



