;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;   see_zone_scalar2.pro  -  Reads in scalar output from round code
;                      Modified from Mark's IDL routine
;
;       usage:  see_zone_scalar,dir,lq,sq,recper,nfiles,start,skip,$
;               files=files,zone=zone,rad=rad,glob=glob,sc=sc,$
;               notquiet=notquiet,swap=swap,opl=opl,psf=psf,$
;               namepsf=namepsf,wnd=wnd,legendd=legendd,$
;               daysflag=daysflag
;               where dir      = data directory
;                     lq       = indices of scalar output quantities
;                     sq       = option (1=quantity, 2=min(quantity), 3=max(quantity)
;                     recper   = number of records per file
;                     nfiles   = number of files to read
;                     start    = starting file iteration
;                     skip     = number of iterations between files
;                     files    = list of files (uses if nfiles is nul)
;                     zone     = if 0 plot both zones (1 for CZ and 2
;                     for RZ)
;                     rbcz     = proportion of the radiative core
;                     glob     = prefix of data directory
;                     sc       = prefix of data file 
;                     notquiet = verbose if smaller then 2
;                     swap     = dependant on the endianess of the file 
;                     opl      = set if overplot command should be used
;                     psf      = type of output (screen or .eps)
;                     namepsf  = name of the .eps output file
;                     wnd      = number of the window for screen output
;                     legendd  = set if 0 and hidden either
;                     daysflag = set if time units are days (rather than sec)
;
;  M.DeRosa - 25 Aug 1998 - modified from Mark's routine
;             15 Sep 1998 - added files keyword
;  A.S.Brun - 28 Jun 1999 - added linestyl keyword
;  M.DeRosa -  6 Jul 1999 - if directory search, weed out invalid files
;  A.S.Brun - 29 Nov 2000 - added sc keyword for file with or without
;             sc_0
;  C.Emeriau-Viard - 31 Aug 2015 - modified from scalar_sax14
;                    (separation between convective and radiative
;                    zone)
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names

pro see_zone_scalar2,dir,lq,sq,recper,nfiles,start,skip,files=files,zone=zone,$
                     rbcz=rbcz,glob=glob,sc=sc,notquiet=notquiet,swap=swap,$
                     opl=opl,psf=psf,namepsf=namepsf,wnd=wnd,legendd=legendd,$
                     daysflag=daysflag,avg=avg,meanm=meanm,xmin=xmin,xmax=xmax,$
                     ymin=ymin,ymax=ymax,savef=savef


;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 5 then begin
     print,'see_zone_scalar2,dir,lq,lsq,recper,nfiles,start,skip,'+$
           'files=files,zone=zone,rbcz=rbcz,glob=glob,sc=sc,notquiet=notquiet,'+$
           'swap=swap,opl=pol,psf=psf,namepsf=namepsf,wnd=wnd,'+$
           'legendd=legendd,loglog=loglog,daysflag=daysflag,'+$
           'meanm=meanm,norm=norm'
     return
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  if n_elements(dir) eq 0 then begin
     print,'  see_zone_scalar2.pro:  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'

  if n_elements(lq) eq 0 then begin
     print,'  see_zone_scalar2.pro:  parameter lq must be set'
     return
  endif

  if n_elements(recper) eq 0 then begin
     print,'  see_zone_scalar2.pro:  parameter recper must be set'
     return
  endif else recordsperfile=recper
  
  if n_elements(files) eq 0 then begin
     if n_elements(nfiles) eq 0 then begin
        print,'  see_zone_scalar2.pro:  if keyword files not set, '+$
              'then parameter nfiles must be set'
        return
     endif
     if n_elements(start) eq 0 then begin
        print,'  see_zone_scalar2.pro:  if keyword files not set, '+$
              'then parameter start must be set'
        return
     endif else filestart=start
     if n_elements(skip) eq 0 then begin
        print,'  see_zone_scalar2.pro:  if keyword files not set, '+$
              'then parameter skip must be set'
        return
     endif else fileskip=skip
     files=lindgen(nfiles)*fileskip+filestart
  endif else begin
     if files(0) eq -1 then files=findfile(dir)
     firstchar=byte(strmid(files,0,1))
     wh=where((firstchar ge 48b) and (firstchar le 57))
     if wh lt 0 then begin
        print,'  see_zone_scalar2.pro:  directory does not contain any valid files'
        return
     endif
     files=long(files(wh))
     nfiles=n_elements(files)
  endelse

  if not keyword_set(zone)     then zone     = 0
  if not keyword_set(rbcz)     then rbcz     = 0
  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(sc)       then sc       = 0
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0
  if not keyword_set(opl)      then opl      = 0
  if not keyword_set(psf)      then psf      = 0   
  if not keyword_set(namepsf)  then namepsf  = "Scalar_zone"
  if not keyword_set(wnd)      then wnd      = 0
  if not keyword_set(legendd)  then legendd  = 0
  if not keyword_set(loglog)   then loglog   = 0
  if not keyword_set(daysflag) then daysflag = 1
  if not keyword_set(meanm)    then meanm    = 0
  if not keyword_set(norm)     then norm     = 0
  if not keyword_set(xmin)     then xmin     = -1000
  if not keyword_set(xmax)     then xmax     = -1000
  if not keyword_set(ymin)     then ymin     = -1000
  if not keyword_set(ymax)     then ymax     = -1000
  if not keyword_set(avg)      then avg      = -1
  if not keyword_set(savef)    then savef    = 0

  if glob eq 0 then begin 
     dir="/dsm/stars2/f/cemeriau/"+dir
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  close,/all 
  
  r=[0b,255b,130b,255b,255b,255b,255b,0b  ,75b ,0b  ,75b ,0b  ,75b ,255b,255b,255b,255b]
  g=[0b,255b,130b,0b  ,75b ,0b  ,75b ,0b  ,75b ,255b,255b,255b,255b,255b,255b,170b,195b]
  b=[0b,255b,130b,0b  ,75b ,255b,255b,255b,255b,255b,255b,0b  ,75b ,0b  ,75b ,0b  ,75b ]
  tvlct,r,g,b
  
  device,set_font='Helvetica',/tt_font
  
  !p.font      = 1
  !x.style     = 1
  !x.thick     = 4
  !y.thick     = 4
  !p.thick     = 4
  !p.charthick = 1.8
  !p.charsize  = 1.8
  !x.charsize  = 1
  !y.charsize  = 1
  !x.ticks     = 4
  !p.multi     = 0
  th           = 5
  
  if (psf eq 0) then begin 
     set_plot,'x'
     device,decomposed=0
     window,wnd,xsize=1200,ysize=800
  endif else begin
     if (psf eq 1) then begin
        set_plot,'ps'
        zonen = ''
        if zone eq 1 then zonen = '_CZ'
        if zone eq 2 then zonen = '_RZ'
        namepsf = namepsf+zonen+'_0'+strcompress(files(0),/r)+'_to_0'+strcompress(files(nfiles-1),/r)+'.eps'
        device,/landscape,/color,bits=8,filename=namepsf
     endif
  endelse

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Set up filename array, time array
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  textnum = strcompress(files,/r)
  if sc eq 1 then begin
     file    = dir+'SHAV/shav_0'+textnum
  endif else begin
     file    = dir+'0'+textnum
  endelse

  nsize=size(lq) & nvar=nsize(1) & if notquiet lt 1 then print,'nb var:',nvar
  n = rbcz^3
  
  ntt = make_array(nfiles,/long,value=recordsperfile)
  nt = long(total(ntt))
  g     = dblarr(nfiles*recper,2*nvar)
  t     = dblarr(nfiles*recper)
  dt    = dblarr(nfiles*recper)
  iter=lonarr(nt)
  
  if zone eq 0 then begin
     name1 = strarr(2*nvar) 
     col1  = intarr(2*nvar)
     thi1  = intarr(2*nvar)
     lin1  = intarr(2*nvar)
  endif else begin
     name1 = strarr(nvar)
     col1  = intarr(nvar)
     thi1  = intarr(nvar)
     lin1  = intarr(nvar)
  endelse

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Read in data
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^


  for i=0,nfiles-1 do begin
     for recnum=0,ntt(i)-1 do begin   
        for j=0,nvar-1 do begin     
           get_scalar_zone_variables,lq[j],file[i],recnum,f=value,rad=radius,t=time,name=name,sq,notquiet=notquiet,swap=swap,dt=dtt           
           
           i_end=size(value) & i_end=i_end[1]-1
           
           if zone eq 0 then begin
              name1[2*j]  =name+" (CZ)"
              name1[2*j+1]=name+" (RZ)"
           endif else begin
              name1[j] = name
           endelse

           if j eq 0 then begin
              t[i*recper+recnum] = time
              dt[i*recper+recnum] = dtt
           endif


              int_value=radial_integration(radius,value,rbcz=rbcz,test=2)
              iv_cz=int_value[0]
              iv_rz=int_value[1]
              i_rad=int_value[2]
              ;print,iv_cz,iv_rz
              
           if (meanm eq 0) then begin
              g[i*recper+recnum,2*j]  =iv_cz ;/(4*!pi)
              g[i*recper+recnum,2*j+1]=iv_rz ;/(4*!pi)
           endif else begin
              g[i*recper+recnum,2*j]  =mean(value[0:i_rad])
              g[i*recper+recnum,2*j+1]=mean(value[i_rad:i_end])
           endelse
        endfor
     endfor
  endfor


;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Calculate time average (if asks)
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  favg   = dblarr(nfiles*recper,2*nvar)
  tavg   = dblarr(nfiles*recper,2*nvar)
  favg_p = dblarr(nfiles*recper,2*nvar)

   if avg ge start then begin
      n_avg = (avg-start)/skip
      for l = 0,2*nvar-1 do begin
         tavg = 0
         for  fi = n_avg,nfiles-1 do begin
            for recnum = 0,ntt(fi)-1 do begin
               favg[l] = favg[l] + g(fi*ntt(fi)+recnum,l) * dt(fi*ntt(fi)+recnum)
               tavg = tavg + dt(fi*ntt(fi)+recnum)
            endfor
         endfor
      endfor
      favg = favg/tavg

      print,' '
      print,name1(0),' : ',favg(0),'  ('+strcompress(g(nt-1,0),/r)+')'
      print,name1(1),' : ',favg(1),'  ('+strcompress(g(nt-1,1),/r)+')'
      favg_p[0] = favg(0)
      favg_p[1] = favg(1)
     
      s_absolu_cz = strcompress(favg(0),/r)
      s_perc_cz   = strcompress(favg(0),/r)
      s_name_cz   = name1(0)

      s_absolu_rz = strcompress(favg(1),/r)
      s_perc_rz   = strcompress(favg(1),/r)
      s_name_rz   = name1(1)

      s_absolu_t = strcompress(favg(0)*(1-n)+favg(1)*n,/r)

      for l = 1,nvar-1 do begin
         print,name1(2*l),' : ',favg(2*l),favg(2*l)/favg(0),'  ('+strcompress(g(nt-1,2*l),/r)+')'
         print,name1(2*l+1),' : ',favg(2*l+1),favg(2*l+1)/favg(1),'  ('+strcompress(g(nt-1,2*l+1),/r)+')'
         favg_p[2*l] = favg(2*l)/favg(0)
         favg_p[2*l+1] = favg(2*l+1)/favg(1)

         s_absolu_cz = s_absolu_cz + ' & ' + strcompress(favg(2*l),/r) 
         s_perc_cz   = s_perc_cz + ' & ' + strcompress(favg_p(2*l),/r) 
         s_name_cz   = s_name_cz + ' & ' + name1(2*l)

         s_absolu_rz = s_absolu_rz + ' & ' + strcompress(favg(2*l+1),/r) 
         s_perc_rz   = s_perc_rz + ' & ' + strcompress(favg_p(2*l+1),/r) 
         s_name_rz   = s_name_rz + ' & ' + name1(2*l+1)

         s_absolu_t = s_absolu_t + ' & ' + strcompress(favg(2*l)*(1-n)+favg(2*l+1)*n,/r) 

      endfor 
      print,' '
      print,' Convective zone '
      print,s_name_cz
      print,s_absolu_cz
      print,s_perc_cz
      print,' '
      print,' Radiative zone '
      print,s_name_rz
      print,s_absolu_rz
      print,s_perc_rz
      print,' '
      print,s_absolu_t
      print,' '

   endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plots : min, max and title
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  cc = opl
  if opl le 1 then begin
     cc = 1-psf
     xtitle = '!17 time (sec)'
     if daysflag then begin
        t=t/(3600.*24.d0)
        xtitle = 'Time [days]'
     endif
  
     to=t(0)
     if notquiet lt 1 then begin
        print,'starting time: ',to
        print,'.c automatically draw all var'
     endif

     if zone eq 0 then begin
        g1 = g 
     endif else begin
        g1=dblarr(nfiles*recper,nvar)
        for i = 0,nvar-1 do begin
           if zone eq 1 then g1(*,i) = g(*,2*i)
           if zone eq 2 then g1(*,i) = g(*,2*i+1)
        endfor
     endelse
     
     yra=min(g1) & yrb=max(g1)
     if xmin eq -1000 then xmin = 0
     if xmax eq -1000 then xmax = t(nt-1)-to
     if ymin eq -1000 then ymin = yra
     if ymax eq -1000 then ymax = yrb
     

     if (notquiet lt 2) then begin
        answ1 = 0
        print,'min-max proposed:',ymin,ymax
        print,'do you want to retain them (0/1)?'
        read,answ1
        if (answ1 eq 1) then begin
           print,'Please enter new values:'
           read,yra,yrb
        endif
     endif
     
     dx  = xmax - xmin
     e   = fix(alog10(dx))
     a   = fix(dx/10^e)
     xt  = a*10^(e-1)
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
; Plots
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  llz = 3
  llc = 0
  cc1 = 1-psf

  if savef eq 1 then begin
     fn = ''
     print,'Enter filename for IDL saving'
     read,fn
     save,filename=fn,t,to,g,/verbose
  endif

  if opl gt 1 then begin
     if zone ne 2 then oplot,t-to,g(*,2*l),line=llc,thick=th1,color=opl
     if zone eq 0 then oplot,t-to,g(*,2*l+1),line=llz,thick=th1,color=opl 
     if zone eq 2 then oplot,t-to,g(*,2*l+1),line=llc,thick=th1,color=opl
  endif else begin 
     if zone ne 2 then begin
        plot_io,t-to,g(*,0),xtit=xtitle,yr=[yra,yrb],/ys,charsize=1.8,thick=th,line=llc,color=cc,xtickinterval=xt
     endif else begin
        plot_io,t-to,g(*,1),xtit=xtitle,yr=[yra,yrb],/ys,charsize=1.8,thick=th,line=llc,color=cc,xtickinterval=xt
     endelse
     col1[0] = 1-psf
     thi1[0] = th
     lin1[0] = llc
     if zone eq 0 then begin
        oplot,t-to,g(*,1),line=llz,thick=th,color=cc
        col1[1] = cc
        lin1[1] = llz
        thi1[1] = th
     endif
  endelse

  for l=1,nvar-1 do begin
     if (l lt 5) then begin
        th1 = th
        if opl gt 1 then cc1 = opl else begin
           if opl eq 0 then cc1 = 2*l+1
        endelse
        if zone ne 2 then oplot,t-to,g(*,2*l),line=llc,thick=th1,color=cc1
        if zone eq 0 then oplot,t-to,g(*,2*l+1),line=llz,thick=th1,color=cc1
        if zone eq 2 then oplot,t-to,g(*,2*l+1),line=llc,thick=th1,color=cc1
     endif else begin
        th1 = 2*th
        if opl gt 1 then cc1 = opl else begin 
           if opl eq 0 then cc1 = 2*(l-4)+1
        endelse
        if zone ne 2 then oplot,t-to,g(*,2*l),line=llc,thick=th1,color=cc1
        if zone eq 0 then oplot,t-to,g(*,2*l+1),line=llz,thick=th1,color=cc1
        if zone eq 0 then oplot,t-to,g(*,2*l+1),line=llc,thick=th1,color=cc1
     endelse
     if opl le 1 then begin
        case zone of
           0: begin
              col1[2*l]   = cc1
              col1[2*l+1] = cc1
              thi1[2*l]   = th1
              thi1[2*l+1] = th1
              lin1[2*l]   = llc
              lin1[2*l+1] = llz
           end
           else: begin
              col1[l] = cc1
              thi1[l] = th1
              lin1[l] = llc
           end
        endcase
     endif
   endfor

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plots : legend
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  if (legendd ne 0) and (opl le 1) then legend,name1,linestyle=lin1,color=col1,thick=th1,location=legendd
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plots : output
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if (psf eq 1) then begin
     device,/close
     mv_var='mv '+namepsf+' '+dir+'/figs/'+namepsf
     if notquiet lt 1 then print,mv_var
     spawn,mv_var
  endif

  if notquiet lt 2 then stop

end
