;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  get_mean2.pro  -  Calculate mean
;
;       usage: get_shav_mean2,dir,qq,recper,nfiles,start,jump,sq=sq,files=files,
;              glob=glob,sc=sc,notquiet=notquiet,swap=swap,savefile=savefile
;                 
;               where dir      = data directory
;                     qq       = output quantity index
;                     sq       = statistical quantity([0,1,2,3,4,5]=[mean,
;                              variance,skewness,kurtosis,min,max]),
;                              default=0 
;                     recper   = number of records per file
;                     nfiles   = number of files
;                     start    = number of the first file
;                     jump     = jump between files
;                     glob     = prefix of data directory
;                     sc       = prefix of filenames
;                     notquiet = verbose if smaller than 2
;                     swap     = change endianess of the file 
;                     savingIDL = name of IDL saving file
;
;  M.DeRosa - 4 Sep 1998 - modified from Mark's routine
;  A.S. Brun - 2009 - ASH 1.4 version
;  C.Emeriau-Viard - 26 Sept 2016 - Version 2.0 (adapted from see_shav2)
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names

pro get_mean2,dir,qq,rec,nfiles,start,jump,type,sq=sq,files=files,$
                   glob=glob,sc=sc,notquiet=notquiet,swap=swap,savingIDL=savingIDL

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 7 then begin
     print,'get_mean2,dir,qq,rec,nfiles,start,jump,type,sq=sq,files=files,'+$
           'glob=glob,sc=sc,notquiet=notquiet,swap=swap,savingIDL=savingIDL'
     return
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(dir) eq 0 then begin
     print,'  get_mean2.pro:  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'

  if n_elements(qq) eq 0 then begin
     print,'  get_mean2.pro:  parameter q must be set'     
     return
  endif

  if n_elements(rec) eq 0 then begin
     print,'  get_mean2.pro:  parameter recper must be set'
     return
  endif
  
  if n_elements(nfiles) eq 0 then begin
     print,'  get_mean2.pro:  parameter nfiles must be set'
     return
  endif
  
  if n_elements(start) eq 0 then begin
     print,'  get_mean2.pro:  parameter start must be set'
     return
  endif

  if n_elements(jump) eq 0 then begin
     print,'  get_mean2.pro:  parameter jump must be set'
     return
  endif

  if n_elements(type) eq 0 then begin
     print,'  get_mean2.pro:  parameter type must be set'
     return
  endif

  if nfiles eq 0 or jump eq 0 then begin
     if files(0) eq -1 then files=findfile(dir)
     firstchar=byte(strmid(files,0,1))
     wh=where((firstchar ge 48b) and (firstchar le 57))
     if wh lt 0 then begin
        print,'  get_mean2.pro:  directory does not contain any valid files'
        return
     endif
     files=long(files(wh))
     nfiles=n_elements(files)  
  endif else begin
     files=lindgen(nfiles)*jump+start
  endelse

  up_type = strupcase(type) & low_type = strlowcase(type)

  if not keyword_set(sq)        then sq       = 0
  if not keyword_set(glob)      then glob     = 0
  if not keyword_set(sc)        then sc       = 1
  if not keyword_set(notquiet)  then notquiet = 0
  if not keyword_set(swap)      then swap     = 0
  if not keyword_set(savingIDL) then savingIDL = 'Mean_'+up_type

  if glob eq 0 then begin
     dir="/dsm/stars2/f/cemeriau/EvolZR/"+dir
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  close,/all

  savingIDL = savingIDL +'_0'+strcompress(files(0),/r)+'_to_0'+strcompress(files(nfiles-1),/r)+'.idl'

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Set up filename, etc.
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  textnum=strcompress(files,/r)
  
  case sc of
     1: file = dir+up_type+'/'+low_type+'_0'+textnum
     2: file = dir+'/'+low_type+'_0'+textnum
     else: file = dir+textnum
  end

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Calculate time averages
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  read2,up_type,qq,file(0),0,sq=sq,rbcz=rbcz,omega=omega,notquiet=notquiet,$
        swap=swap,time=time,deltat=deltat,f=value_mean
  
  time_old   = time
  time_tot   = 0 
  value_mean = value_mean*0.
  deltat     = 0 

  for ifiles = 0,nfiles-1 do begin
     for recnum = 0,rec-1 do begin
        read2,up_type,qq,file(ifiles),recnum,sq=sq,rbcz=rbcz,omega=omega,$
              notquiet=notquiet,swap=swap,f=yy,iteration=iteration,$
              time=time,deltat=deltat,name=name,rad=radius,theta=theta,$
              phi=phi,nphi=nphi,nlats=nlats
        value_mean = value_mean + deltat*yy
        time_old   = time 
        time_tot   = time_tot + deltat
     endfor
  endfor
  
  value_mean = value_mean/time_tot
  yy         = value_mean
  
  case up_type of
     'SCALAR' : save,filename=savingIDL,qq,rbcz,yy,name
     'SHAV'   : save,filename=savingIDL,qq,yy,name,radius
     'SHSL'   : save,filename=savingIDL,qq,yy,name,radius,theta,phi
     'AZAV'   : save,filename=savingIDL,qq,omega,yy,name,radius,theta
     'EQSL'   : save,filename=savingIDL,qq,yy,name,radius,nphi,nlats
     'POSL'   : begin
        print,'Get_mean on POSL not implemented yet ...'
        return
     end
  end
end
