;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;     get_spectra2.pro  - Use SHSL files to create spectra files
;      
;        usage:  get_spectra2,dir,recperfile,nfiles,start,skip,icutmax=icutmax,
;                recperfile=recperfile,outfile=outfile,sq=sq,wnd=wnd,q=q,swap=swap,
;                glob=glob
;       
;                where dir        = data directory
;                      recperfile = record per file
;                      nfiles     = number of files
;                      start      = first file
;                      skip       = jump between files
;                      q          = quantity we want to study (if 0 KE
;                      (and ME))
;                      sq         = 0 by default (if 1 -> mag ; if 2 ->
;                      velocity components)
;                      icutmax    = number of shells 
;                      outfile    = name of output
;                      glob       = prefix of data directory
;                      sc         = prefix of data files
;                      notquiet   = verbose if smaller than 2
;                      swap       = dependant of the endianess of files
; 
; C.Emeriau-Viard - 07 June 2016 - Version 2.0
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names

pro get_spectra2,dir,recperfile,nfiles,start,skip,q=q,sq=sq,icutmax=icutmax,$
                 outfile=outfile,glob=glob,sc=sc,notquiet=notquiet,swap=swap

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 5 then begin
     print,'get_spectra2,dir,recperfile,nfilesstart,skip,q=q,sq=sq,'+$
           'icutmax=icutmax,outfile=outfile,glob=glob,sc=sc,'+$
           'notquiet=notquiet,swap=swap'
     return
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(dir) eq 0 then begin
     print,'  get_spectra2.pro:  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'

  if n_elements(recperfile) eq 0 then begin
     print,'  get_spectra2.pro:  parameter recperfile must be set'
     return
  endif  

  if n_elements(nfiles) eq 0 then begin
     print,'  get_spectra2.pro:  parameter nfiles must be set'
     return
  endif

  if n_elements(start) eq 0 then begin
     print,'  get_spectra2.pro:  parameter start must be set'
     return
  endif

  if n_elements(skip) eq 0 then begin
     print,'  get_spectra2.pro:  parameter skip must be set'
     return
  endif

  if not keyword_set(q)        then q        = 0  
  if not keyword_set(sq)       then sq       = 0
  if not keyword_set(icutmax)  then icutmax  = 5
  if not keyword_set(outfile)  then outfile  = 'spectra.out'
  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(sc)       then sc       = 0
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0

  if glob eq 0 then begin
     dir='/dsm/stars2/f/cemeriau/'+dir
  endif

  mag = 0 & pol = 0
  if sq eq 1 then mag = 1
  if sq eq 2 then pol = 1

  if (mag eq 1) then outfile='mag_'+outfile
  if (pol eq 1) then outfile='pol_'+outfile
  
  if (q gt 0) then begin
     nameq=get_name2(q)
     print," Spectra on : ",nameq
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Times settings
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  dt = 1.d0/(3600.d0*24.d0)
  P = dt * ((2.*!pi) / 2.6d-6)
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; File array creation
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  filesl=lindgen(nfiles)*skip+start
  textnum=strcompress(filesl,/r)
  if sc eq 1 then begin
     files = dir+'SHSL/shsl_0'+textnum
  endif else begin
     files = dir+textnum
  endelse

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Shell definition reading
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  nt=intarr(nfiles) & icut=intarr(nfiles,icutmax+1)
  nt(*) = recperfile                     
  ntt = long(total(nt))

  for i=0,icutmax do begin
     icut(*,i)=i
  endfor

  it_range = [0,300]
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; First file reading
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  d = 0.0
  dt = 1.d0/(3600.d0*24.d0)
  
  close,1 & openr,1,files(0),swap_endian=swap
  readu,1,d & N_Phi = fix(d)
  readu,1,d & N_Theta = fix(d)
  readu,1,d & N_Shells = fix(d)
  readu,1,d & N_quantities = fix(d)
  close,1 & openr,1,files(0),swap_endian=swap
  shell_slices = assoc(1,fltarr(N_Theta,N_Phi+1,N_Shells,N_quantities))
  rad=reform(shell_slices(8,0,0:icutmax,0,0))
  costheta=fltarr(N_theta) & costheta(*) = shell_slices(*,0,0,1,0)
  l_max = (2*N_Theta - 1)/3
  
  t_o=shell_slices(5,0,0,0,0) & print,'t0= ',t_o*dt,' days'
  print,"Radius of shells : ", rad
  
  KE = fltarr(l_max+1,l_max+1,icutmax+1)
  if (pol eq 1 ) then begin
     vrlm = fltarr(l_max+1,l_max+1,icutmax+1)
     vtlm = fltarr(l_max+1,l_max+1,icutmax+1)
     vplm = fltarr(l_max+1,l_max+1,icutmax+1)
  endif
  if (q gt 0) then begin
     out = fltarr(l_max+1,l_max+1,icutmax+1)
  endif

  v = fltarr(N_phi,N_theta)
  iter = fltarr(ntt)
  time = fltarr(ntt)
  
  itt=0L

  for ifile = 0,nfiles-1 do begin
     close,1 & openr,1,files(ifile),swap_endian=swap
     readu,1,d & readu,1,d 
     readu,1,d & N_Shells = fix(d)
     readu,1,d & N_quantities = fix(d)
     close,1 & openr,1,files(ifile),swap_endian=swap
     shell_slices = assoc(1,fltarr(N_Theta,N_Phi+1,N_Shells,N_quantities))
     quantities=intarr(N_quantities)
     quantities = fix(shell_slices(0:n_quantities-1,0,0,3,0))
          
     ltext = files(ifile)+': '+' | r = 1' + $
             strtrim(string((shell_slices(8,0,icut(ifile,0),0,0)*1.d-8),format='(f9.1)'),2)
          
     for i=1,icutmax do ltext = ltext + ', ' + $
        strtrim(string((shell_slices(8,0,icut(ifile,i),0,0)*1.d-8),format='(f9.1)'),2)
     print,ltext
          
     if mag eq 0 then begin
        i1 = where(quantities eq 1) & i2=where(quantities eq 2) & i3=where(quantities eq 3)
     endif else if (mag eq 1) then begin
        i1 = where(quantities eq 61) & i2=where(quantities eq 62) & i3=where(quantities eq 63)
     endif         
     
     if (q gt 0) then i4 = where (quantities eq q)
     
     title1=get_name2(quantities(i1(0))) & title2=get_name2(quantities(i2(0))) & title3=get_name2(quantities(i3(0)))
     print,'Spectra for: ',title1,' ',title2,' ',title3
     if ( q gt 0) then begin
        title4 = get_name2(quantities(i4(0)))
        print,'Spectra for : ',title4
     endif


     for it = 0, nt(ifile)-1 do begin
        if (itt ge it_range(0)) and (itt le it_range(1)) Then begin
           iter(itt) = shell_slices(4,0,0,0,it) 
           time(itt) = (shell_slices(5,0,0,0,it) - t_o)*dt
           print,'       ',+strtrim(iter(itt),2)+', '+$
                 strtrim(string(time(itt),format='(f9.3)'),2)+' days'
           for i=0,icutmax do begin
              if (q eq 0) and (i1(0) ge 0) and (i2(0) ge 0) and (i3(0) ge 0) then begin 
                 v(*,*) = transpose(shell_slices(*,1:N_phi,icut(ifile,i),i1(0),it))
                 PS = spherical_transform_new2(v, costheta) ; changed to new2 on 01/18/05 
                 KE(*,*,i) = KE(*,*,i) + abs(PS)^2
                 if (pol eq 1) then vrlm(*,*,i)=abs(PS)^2 
                 v(*,*) = transpose(shell_slices(*,1:N_phi,icut(ifile,i),i2(0),it))
                 PS = spherical_transform_new2(v, costheta) ; modif 09/14/00
                 KE(*,*,i) = KE(*,*,i) + abs(PS)^2
                 if (pol eq 1) then vtlm(*,*,i)=abs(PS)^2
                 v(*,*) = transpose(shell_slices(*,1:N_phi,icut(ifile,i),i3(0),it))
                 PS = spherical_transform_new2(v, costheta)
                 KE(*,*,i) = KE(*,*,i) + abs(PS)^2
                 if (pol eq 1) then  vplm(*,*,i)=abs(PS)^2
              endif else begin
                 if (q gt 0) then begin
                    v(*,*) = transpose(shell_slices(*,1:N_phi,icut(ifile,i),i4(0),it))
                    PS = spherical_transform_new2(v, costheta)
                    KE(*,*,i)=abs(PS)^2
                 endif
              endelse
           endfor
        endif
        itt=itt+1
     endfor
  endfor     
  KE = KE / float(itt)
  
  l_max1 = l_max

  Km1 = fltarr(l_max1+1,icutmax1+1)*0.d0 & Km1nol0=Km1
  Kl1 = fltarr(l_max1+1,icutmax1+1)*0.d0 & Kl1nom0=Kl1

  for i=0,l_max1 do for j=0,icutmax1 do Km1(i,j)=total(KE1(0:l_max1,i,j),/double)
  for i=0,l_max1 do for j=0,icutmax1 do Km1nol0(i,j)=total(KE1(1:l_max1,i,j),/double)
  for i=0,l_max1 do for j=0,icutmax1 do Kl1(i,j)=total(KE1(i,0:l_max1,j),/double)
  for i=0,l_max1 do for j=0,icutmax1 do Kl1nom0(i,j)=total(KE1(i,1:l_max1,j),/double)

  idx = where(time ne 0.0)
  if n_elements(idx) eq 1 then idxtmp=idx else idxtmp=0
  if (idxtmp eq -1) then begin
     nn=1 & idx=0 
  endif else begin
     nn=n_elements(idx)
  endelse
  tt=fltarr(nn) & ii=tt
  tt(*)=time(idx)
  ii(*)=iter(idx)
  save,file=outfile,l_max1,Km1,Kl1,Km1nol0,Kl1nom0,KE,rad,ii,tt
  
end









