;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  horiz_scale.pro  -  Plot shell averages
;
;       usage: horiz_scale,dir,qq,sq,iter,recnum,rbcz=rbcz,glob=glob,sc=sc,
;              notquiet=notquiet,swap=swap,opl=opl,psf=psf,namepsf=namepsf,
;              wnd=wnd,xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax
;                 
;               where dir      = data directory
;                     qq       = output quantity index
;                     sq       = statistical quantity([0,1,2,3,4,5]=[mean,
;                              variance,skewness,kurtosis,min,max]),
;                              default=0 
;                     iter     = iteration of output file
;                     recnum   = record number
;                     rstar    = star radius
;                     rbcz     = percentage of the radiative zone
;                     glob     = prefix of data directory
;                     sc       = prefix of filenames
;                     notquiet = verbose if smaller than 2
;                     swap     = change endianess of the file 
;                     opl      = set if overplot command should be used
;                     psf      = output screen or psf
;                     namepsf  = name of the .eps output file
;                     wnd      = number of the window for screen output 
;                     xmin     = min
;                     xmax     = max
;                     ymin     = min
;                     ymax     = max
; 
;
;  M.DeRosa - 4 Sep 1998 - modified from Mark's routine
;  A.S. Brun - 2009 - ASH 1.4 version
;  C.Emeriau-Viard - 10 May 2016 - Version 2.0
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names

pro horiz_scale,dir,iter,recnum,rstar=rstar,rbcz=rbcz,glob=glob,sc=sc,$
              notquiet=notquiet,swap=swap,opl=opl,psf=psf,namepsf=namepsf,$
              wnd=wnd,xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax,log=log,$
              build=build

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 3 then begin
     print,'  horiz_scale,dir,iter,recnum,rstar=rstar,rbcz=rbcz,'+$
                 'glob=glob,sc=sc,notquiet=notquiet,swap=swap,opl=opl,psf=psf,'+$
                 'namepsf=namepsf,wnd=wnd,xmin=xmin,xmax=xmax,'+$
                 'ymin=ymin,ymax=ymax'
     return
  endif
     
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(dir) eq 0 then begin
     print,'  horiz_scale.pro:  parameter dir must be set'
     return
  endif

  ;if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'

  if n_elements(iter) eq 0 then begin
     print,'  horiz_scale.pro:  parameter iter must be set'     
     return
  endif

  if n_elements(recnum) eq 0 then begin
     print,'  horiz_scale.pro:  parameter recnum must be set'     
     return
  endif

  if not keyword_set(rstar)    then rstar    = 6.72e10
  if not keyword_set(rbcz)     then rbcz     = 0
  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(sc)       then sc       = 0
  if not keyword_set(swap)     then swap     = 0
  if not keyword_set(opl)      then opl      = 0
  if not keyword_set(psf)      then psf      = 0
  if not keyword_set(namepsf)  then namepsf  = 'SHAV'
  if not keyword_set(wnd)      then wnd      = 0
  if not keyword_set(xmin)     then xmin     = -1000
  if not keyword_set(xmax)     then xmax     = -1000
  if not keyword_set(ymin)     then ymin     = -1000
  if not keyword_set(ymax)     then ymax     = -1000
  if not keyword_set(log)      then log      = 0

  if glob eq 0 then begin
     dir="/dsm/stars2/f/cemeriau/EvolZR/"+dir
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  close,/all

  r=[0b,255b,130b,255b,255b,255b,255b,0b  ,75b ,0b  ,75b ,0b  ,75b ,255b,255b,255b,255b]
  g=[0b,255b,130b,0b  ,75b ,0b  ,75b ,0b  ,75b ,255b,255b,255b,255b,255b,255b,170b,195b]
  b=[0b,255b,130b,0b  ,75b ,255b,255b,255b,255b,255b,255b,0b  ,75b ,0b  ,75b ,0b  ,75b ]
  tvlct,r,g,b
  
  device,set_font='Helvetica',/tt_font

  !p.font         = 1
  !x.style        = 1
  !x.thick        = 1
  !y.thick        = 1
  !p.thick        = 1
  !p.charthick    = 1.8
  !x.charsize     = 1.2 
  !y.charsize     = 1.2
  !p.charsize     = 1.5
  !x.tickinterval = 0.1
  !p.multi        = 0
  th              = 3

  if (psf eq 0) then begin 
     set_plot,'x'
     device,decomposed=0
     if opl le 1 then window,wnd,xsize=800,ysize=500
  endif else begin
     set_plot,'ps'
     title = get_name2(qq)
     if notquiet gt 0 then print,title
     namepsf=namepsf+'_'+strcompress(title,/REMOVE_ALL)+'_0'+strcompress(iter,/r)+".eps"     
     device,/encapsulated,/landscape,/color,bits=8,filename=namepsf
  endelse

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Set up filename, etc.
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  textnum=strcompress(iter,/r)
  
  file = []
  nfiles = size(dir) & nfiles = nfiles(0)
  if nfiles eq 0 then begin
     dir     = [dir]
     textnum = [textnum]
     recnum  = [recnum]
  endif
  nfiles = size(dir) & nfiles = nfiles(1)
  print,nfiles
  for i = 0,nfiles-1 do begin
     case sc of
        0: file = [file,dir(i)+'SHAV/shav_0'+textnum(i)]
        1: file = [file,dir(i)+'/shav_0'+textnum(i)]
        else: file = [file,dir(i)+textnum(i)]
     end
  endfor
    
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Associate data file
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  read_shav2,[61,62,63],file(0),recnum(0),sq=1,f=f,rad=rad,name=name,$
             notquiet=notquiet,swap=swap

  nr = size(rad) & nr = nr(1)
  yy = dblarr(nfiles,nr)

  for ifiles = 0,nfiles-1 do begin
     read_shav2,[61,62,63],file(ifiles),recnum(ifiles),sq=1,f=f,rad=rad,$
                name=name,notquiet=notquiet,swap=swap

     br = abs(f(*,0))
     bh = sqrt(f(*,1)^2+f(*,2)^2)
     
     D  = (1-rbcz(ifiles))*rstar(ifiles)
     
     yy(ifiles,*) = D*br/bh
     
     yy(ifiles,*) = 2*!pi*rstar(ifiles)/yy(ifiles,*)
     rad = rad/rstar(ifiles)
  endfor     

  

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^   
;  Plots : min, max and title
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
  
  c = opl
  if opl le 1 then begin
     c = 1-psf
     xtitle = '!17 Radius'
     ytitle = 'Horizontal scale'
     
     nr = size(rad)
     nr = nr[1]
     
     yra=min(yy) & yrb=max(yy)
     if xmin eq -1000 then xmin = 0
     if xmax eq -1000 then xmax = 1
     if ymin eq -1000 then ymin = yra
     if ymax eq -1000 then ymax = yrb
     
     if notquiet gt 0 then begin
        answ1 = 0
        print,'min-max proposed',ymin,ymax
        print,'do you want to retain then (0/1)?'
        read,answ1
        if (answ1 ne 0) then begin
           print,'Please enter new values:'
           read,ymin,ymax
        endif
     endif
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
; Plots 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  if opl gt 1 then oplot,rad,yy(0),thick=th,color=c $
  else begin     
     case log of
        0: plot,rad,yy(ifiles,*),/xs,/ys,xr=[xmin,xmax],yr=[ymin,ymax],xtitle=xtitle,$
                ytitle=ytitle,title=ytitle,thick=th,color=c 
        1: plot_io,rad,yy,/xs,/ys,xr=[xmin,xmax],yr=[ymin,ymax],xtitle=xtitle,$ 
     ytitle=ytitle,title=ytitle,thick=th,color=c
     end
  endelse
  for ifiles = 1,nfiles-1 do begin
     c = 2*ifiles+1
     oplot,rad,yy(ifiles,*),color=c
  endfor

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
; Plots : output
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  if (psf eq 1) then begin
     device,/close
     mv_var= 'mv '+namepsf+' '+dir+'/figs/'+namepsf
     if notquiet gt 0 then print,mv_var
     spawn,mv_var
  endif

  if notquiet gt 0 then begin
     stop
  endif

end
