;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  see_azav2.pro  -  Plot azimuthal averages
;
;       usage:  see_azav2,dir,q,sq,iter,recnum,rbcz=rbcz,rstar=rstar,to=to,
;               idmx=idmx,glob=glob,sc=sc,notquiet=notquiet,swap=swap,opl=opl,
;               psf=psf,namepsf=namepsf,wnd=wnd,legendd=legendd,tv=tv
; 
;               where dir      = data directory
;                     q        = output quantity index (starting at 1)
;                     sq       = 
;                     iter     = iteration of output file
;                     recnum   = record number
;                     gr       = rotation rate (in solar units)
;                     rbcz     = percentage of the radiative zone
;                     rstar    = stellar radius
;                     to       = time offset (default=0.0)
;                     idmx     = amplitude of theta
;                     glob     = prefix of data directory    
;                     sc       = prefix of filenames 
;                     notquiet = verbose if smaller than 2
;                     swap     = change endianess of the file 
;                     opl      = set if overplot command should be
;                     used 
;                     psf      = output screen or psf    
;                     namepsf  = name of the .eps output file           
;                     wnd      = number of the window for screen
;                     output  
;                     legendd  = set to plot legend to the graph 
;                     daysflag = set if time units are days (rather than sec)
;                     tv       = set if image rather than contour plot
;                     is desired
;                     flip     = reverse latitudes
; 
;  M.DeRosa - 27 Aug 1998 - modified from Mark's routine
;  A.S. Brun - many modif - adapted to ASH 1.2
;  A.S. Brun - 2009 - ASH 1.4 version
;  C.Emeriau-Viard - June 2016 - Version 2.0 
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_units
@get_names
@colourbar

pro multipole_analysis2,dir,rec,nfiles,start,skip,rbcz=rbcz,rstar=rstar,to=to,$
              idmx=idmx,glob=glob,sc=sc,notquiet=notquiet,swap=swap,psf=psf,$
              namepsf=namepsf,wnd=wnd,legendd=legendd,build=build,savingIDL=savingIDL

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  if not keyword_set(notquiet) then notquiet = 1
  if n_elements(build) eq 0 then begin
     build = 0 
     if notquiet ge 1 then begin
        print,'Do you want to read a IDL saving file ? (0/1)'
        print,'0: No'
        print,'1: Create'
        print,'2: Read'
        read,build
     endif
  endif

  case build of
     0: begin
        if n_params() lt 5 then begin
           print,' see_azav2,dir,rec,nfiles,start,skip,'+$
                 'rbcz=rbcz,rstar=rstar,lr=lr,'+$
                 'idmx=idmx,glob=glob,sc=sc,notquiet=notquiet,swap=swap,psf=psf,'+$
                 'namepsf=namepsf,wnd=wnd,legendd=legendd,build=build'
           return
        endif
     end
     1: begin
        if n_params() lt 5 then begin
           print,' see_azav2,dir,rec,nfiles,start,skip,'+$
                 'rbcz=rbcz,rstar=rstar,lr=lr,savingIDL=savingIDL,'+$
                 'idmx=idmx,glob=glob,sc=sc,notquiet=notquiet,swap=swap,psf=psf,'+$
                 'namepsf=namepsf,wnd=wnd,legendd=legendd,build=build'
           return
        endif
     end
     2: begin
        if n_params() lt 2 then begin
           print,' see_azav2,dir,savingIDL,'+$
                 'rbcz=rbcz,rstar=rstar,lr=lr,'+$
                 'idmx=idmx,glob=glob,sc=sc,notquiet=notquiet,swap=swap,psf=psf,'+$
                 'namepsf=namepsf,wnd=wnd,legendd=legendd,build=build'
           return
        endif
     end 
  end

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Input settings
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(dir) eq 0 then begin
     print,'  see_azav2.pro:  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'

  case build of
     2: begin
        if n_elements(rec) eq 0 then begin
           print,'  see_azav2.pro:  parameter savingIDL must be set'
           return
        endif
        savingIDL = rec
     end
     else: begin
        if n_elements(rec) eq 0 then begin
           print,'  see_azav2.pro:  parameter recper must be set'
           return
        endif
        if n_elements(nfiles) eq 0 then begin
           print,'  see_azav2.pro:  parameter nfiles must be set'
           return
        endif
        if n_elements(start) eq 0 then begin
           print,'  see_azav2.pro:  parameter start must be set'
           return
        endif
        if n_elements(skip) eq 0 then begin
           print,'  see_azav2.pro:  parameter skip must be set'
           return
        endif
        recper = rec

        files = lindgen(nfiles)*skip+start
        nfiles = size(files) & nfiles = nfiles(1)
     end
  end
  
  if not keyword_set(rbcz)        then rbcz        = 0
  if not keyword_set(rstar)       then rstar       = 1
  if not keyword_set(lr)          then lr          = [20,200,400]
  if not keyword_set(gr)          then gr          = 0
  if not keyword_set(idmx)        then idmx        = 0
  if not keyword_set(glob)        then glob        = 0
  if not keyword_set(sc)          then sc          = 0
  if not keyword_set(notquiet)    then notquiet    = 0
  if not keyword_set(swap)        then swap        = 0
  if not keyword_set(psf)         then psf         = 0
  if not keyword_set(namepsf)     then namepsf     = 'Multipole_analysis'
  if not keyword_set(wnd)         then wnd         = 0
  if not keyword_set(legendd)     then legendd     = 0
  if not keyword_set(daysflag)    then daysflag    = 0
  if not keyword_set(opl)         then opl         = 0
  if not keyword_set(log)         then log         = 0
  if not keyword_set(savingIDL)   then savingIDL   = 'multipole_analysis.idl'

  print,savingIDL
  
  tv = 1 
  
  if glob eq 0 then dir  = '/dsm/stars2/f/cemeriau/EvolZR/'+dir

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  close,/all

  device,set_font='Helvetica',/tt_font

  r=[0b,255b,130b,255b,255b,255b,255b,0b  ,75b ,0b  ,75b ,0b  ,75b ,255b,255b,255b,255b]
  g=[0b,255b,130b,0b  ,75b ,0b  ,75b ,0b  ,75b ,255b,255b,255b,255b,255b,255b,170b,195b]
  b=[0b,255b,130b,0b  ,75b ,255b,255b,255b,255b,255b,255b,0b  ,75b ,0b  ,75b ,0b  ,75b ]
  tvlct,r,g,b

  !p.font         = 1
  !x.style        = 1
  !x.thick        = 1
  !y.thick        = 1
  !p.thick        = 1
  !p.charthick    = 1
  !p.charsize     = 1
  !x.charsize     = 4
  !y.charsize     = 4
  !x.margin       = 20
  !y.margin       = 7

  th = 3

  if (psf eq 0) then begin
     set_plot,'x'
     if opl le 1 then window,wnd
     device,decomposed=0
  endif else begin
     set_plot,'ps'
     nlr = size(lr) & nlr=nlr(0)
     if nlr eq 1 then begin
        pos     = strpos(savingIDL,'.idl')
        namepsf = strmid(savingIDL,0,pos)
     endif else begin
        nlr = size(lr) & nlr=nlr(0)
        pos     = strpos(savingIDL(0),'.idl')
        namepsf = strmid(savingIDL(0),0,pos)
        for dd  = 1,nlr-1 do begin
           pos     = strpos(savingIDL(dd),'.idl')
           namepsf = namepsf + '_' + strmid(savingIDL(dd),0,pos)
        endfor
     endelse
     namepsf = namepsf+'.eps'
     device,/landscape,/color,bits=8,filename=namepsf ;,xsize=8,ysize=8
  endelse

  !p.multi=[0,2,1]

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Set up filename
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  case build of
     2: savingIDL = dir + savingIDL
     else: begin
        textnum = strcompress(files,/r)
        case sc of
           0: file = dir+'/AZAV/azav_0'+textnum 
           1: file = dir+'azav_0'+textnum 
           2: file = dir+'/AZAV/azav_0'+textnum+'_special'
           else: file = dir +textnum
        end
     end
  end
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Associate data file
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  case build of
     2: begin
        n_fbuild = size(savingIDL) & n_fbuild = n_fbuild(0)
        print,n_fbuild
        if n_fbuild eq 0 then begin
           restore,filename=savingIDL,/verbose
        endif else begin
           nframes_tot = 0
           timel_aux   = []
           br_d_aux    = []
           br_q_aux    = []           
           br_o_aux    = []
           time_end    = 0
           n_files     = size(savingIDL) & n_files = n_files[1]
           for i = 0,n_files-1 do begin
              print,i
              restore,filename = savingIDL(i),/verbose
              delta     = time(1)-time(0)
              time      = time - time(0)+ time_end+delta
              timel_aux = [timel_aux,time]
              t_s       = size(timel_aux) & t_s = t_s(1)
              time_end  = timel_aux(t_s-1)
              br_d_aux  = [br_d_aux,br_d]
              br_q_aux  = [br_q_aux,br_q]
              br_o_aux  = [br_o_aux,br_o]
           endfor
           br_d = br_d_aux
           br_q = br_q_aux
           br_o = br_o_aux
           time = timel_aux
        endelse
     end
     else: begin
        read_azav2,61,file(0),0,f=br_aux,rad=rad,theta=theta,time=time_aux,name=title,$
                         notquiet=notquiet,swap=swap

        nr      = size(rad)      & nr     = nr(1)
        ntheta  = size(theta)    & ntheta = ntheta(1)
        nt      = intarr(nfiles) & nt(*)  = recper
        nframes = total(nt)       

        br = dblarr(nframes,ntheta,nr)
        ii = 0
        time = []
        for i = 0,nfiles-1 do begin
           for recnum = 0,recper-1 do begin
              read_azav2,61,file(i),recnum,f=br_aux,notquiet=notquiet,swap=swap,time=time_aux
              time = [time,time_aux]
              br(ii,*,*) = br_aux
              ii = ii + 1
           endfor
        endfor

        br_d_aux   = dblarr(ntheta)
        br_q_aux   = dblarr(ntheta)
        br_o_aux   = dblarr(ntheta)
        
        br_d       = dblarr(nframes,nr) 
        br_q       = dblarr(nframes,nr) 
        br_o       = dblarr(nframes,nr) 
        
        for frame = 0,nframes-1 do begin
           for radius = 0,nr- 1 do begin
              br_d_aux(*) = br(frame,*,radius)*cos(theta)*sin(theta)
              br_q_aux(*) = br(frame,*,radius)*(3*cos(theta)^2-1)*sin(theta)
              br_o_aux(*) = br(frame,*,radius)*(5*cos(theta)^3-3*cos(theta))*sin(theta)
              
              br_d(frame,radius) = int_tabulated(theta,br_d_aux)
              br_q(frame,radius) = int_tabulated(theta,br_q_aux)
              br_o(frame,radius) = int_tabulated(theta,br_o_aux)
           endfor
        endfor
        
        br_d = sqrt(3*!pi)*br_d
        br_q = sqrt(5*!pi/4)*br_q
        br_o = sqrt(7*!pi/4)*br_o
        
        if build eq 1 then save,filename=savingIDL,br,rad,theta,time,title,nr,ntheta,nframes,br_d,br_q,br_o
     end
  end  

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Select radial cuts 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  nlr = size(lr) & nlr = nlr(1)

  dipole     = br_d(*,lr)
  quadrupole = br_q(*,lr)
  octupole   = br_o(*,lr)

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plot : Min-Max
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  c = opl
  xtitle = '!17 time (sec)'
  ytitle = title
  time = time -time(0)
  if daysflag eq 0 then begin
     time = time/(3600.*24.d0)/1000
     xtitle = 'Time [1000 days]'
  endif
  if opl le 1 then c = 1-psf

  maxi = dblarr(nlr) & mini = dblarr(nlr)

  for dd = 0,nlr-1 do begin
     maxi_d  = max(dipole(*,dd)) & maxi_q = max(quadrupole(*,dd)) & maxi_o = max(octupole(*,dd))
     mini_d  = min(dipole(*,dd)) & mini_q = min(quadrupole(*,dd)) & mini_o = min(octupole(*,dd))
     maxi(dd) = max([maxi_d,maxi_q,maxi_o])
     mini(dd) = min([mini_d,mini_q,mini_o])
  endfor
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; See if we want to modify the proposed values
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  !p.multi=[0,1,nlr]

  repet = 1
  while repet eq 1 do begin
     for dd = 0,nlr-1 do begin
        ans = 0
        print,mini(dd),maxi(dd),'  at N_R =', lr(dd)
        print,'Do you want to keep these extrema ? (0/1)'
        read,ans 
        if ans eq 1 then begin
           print,'Enter new values (min first)'
           read,a,b
           mini(dd) = a
           maxi(dd) = b
        endif
     endfor

     ll_file = make_array(nlr,/double,value=log)
     for dd = 0,nlr-1 do begin
        case log of
           0: plot,time,ll_file,/xs,/ys,yr=[mini(dd),maxi(dd)],xtitle=xtitle,thick=th
           1: plot_io,time,ll_file,/xs,/ys,yr=[mini(dd),maxi(dd)],xtitle=xtitle,thick=th
        end
        if opl eq 0 then c = 3
        oplot,time,dipole(*,dd),thick=th,color=c
        if opl eq 0 then c = 5
        oplot,time,quadrupole(*,dd),thick=th,color=c
        if opl eq 0 then c = 7
        oplot,time,octupole(*,dd),thick=th,color=c
     endfor

     xyouts,0,18000,'l=1',color=3,charsize=2.5
     xyouts,12,18000,'l=2',color=5,charsize=2.5
     xyouts,24,18000,'l=3',color=7,charsize=2.5

     if notquiet ge 1 then begin
        print,'Are these plots OK ?'
        read,repet
     endif else begin
        repet = 0
     endelse
  endwhile

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;   Plots : output
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  if (psf eq 1) then begin
     device,/close
     mv_var= 'mv '+namepsf+' '+dir+'/figs/'+namepsf
     print,mv_var
     spawn,mv_var
     set_plot,'x'
  endif
  
  !p.multi = 0
  
end
     
