;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  read_azav2.pro  -  Reads azimuthal average files
;
;       usage:  read_azav2,qq,file,recnum,omega=omega,f=f,rad=rad,
;               theta=theta,time=time,deltat=deltat,name=name,
;               notquiet=notquiet,swap=swap
; 
;             where qq        = quantity index
;                   file      = filename
;                   recnum    = record number
;                   omega     = plot omega with omega solar rate
;                   f         = output quantity (2D array in that routine)
;                   rad       = output radius
;                   theta     = output latitude
;                   iteration = iteration
;                   time      = output time
;                   deltat    = time step
;                   name      = quantity name
;                   notquiet  = verbose if smaller than 2
;                   swap      = dependant of the endianess of the file
;
;  M.DeRosa - 4 Sep 1998 - modified from Mark's routine
;  A.S. Brun - 2009 - ASH 1.4 version
;  C.Emeriau-Viard - 10 May 2016 - Version 2.0 (adapted from see_shell_avgs14)
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

pro read_azav2,qq,file,recnum,omega=omega,f=f,rad=rad,theta=theta,iteration=iteration,$
               time=time,deltat=deltat,name=name,notquiet=notquiet,swap=swap,sq=sq

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 3 then begin
     print,'read_azav2,qq,file,recnum,omega=omega,f=f,rad=rad,theta=theta,'+$
           'iteration=iteration,time=time,deltat=deltat,name=name,'+$
           'notquiet=notquiet,swap=swap'
     return
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  close,/all
  
  if n_elements(qq) eq 0 then begin
     print,'  read_azav2.pro:  parameter q must be set'
     return
  endif
  if n_elements(file) eq 0 then begin
     print,'  read_azav2.pro:  parameter file must be set'
     return
  endif
  if n_elements(recnum) eq 0 then begin
     print,'  read_azav2.pro:  parameter recnum must be set'
     return
  endif

  if qq lt 1 then begin
     return
  endif

  if not keyword_set(omega)    then omega    = 0 
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0
 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Associate data file
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  temp=0.0
  openr,lun,file,/g,swap_endian=swap
  readu,lun,temp  &  N_R = fix(temp)
  readu,lun,temp  &  N_Theta = fix(temp)
  readu,lun,temp  &  N_Avgs = fix(temp) ;  N_q in the code
  readu,lun,temp  &  N_R_CZ = fix(temp) ;  N_R_1 in the code
  az_avgs = assoc(lun,fltarr(N_theta,N_R,N_Avgs+1,1))

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Read code quantities
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  rad = fltarr(n_r)
  rad(N_R-1) = az_avgs(7,0,0,0,0) ;  inner radius
  rad(0) = az_avgs(9,0,0,0,0)     ; outer radius
  rad(1:N_R-2) = az_avgs(10,0:N_R-3,0,0,0)

  costheta = reform(az_avgs(*,N_R-2,0,0,0))
  sintheta = reform(az_avgs(*,N_R-1,0,0,0))
  theta = acos(costheta)

  quantities = fix(reform(az_avgs(11,0:N_Avgs-1,0,0,0)))

  q = where(quantities eq qq)+1
  while (q eq 0) do begin
     print,"This quantity does not exist : ",qq
     print,"The list is :"
     print,fix(quantities)
     print,"Please, enter a new one :"
     read,qq
     q=where(quantities eq qq)+1
  endwhile
  name = get_name2(qq)
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Read in azimuthal average data
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  iteration  = az_avgs(4,0,0,0,recnum)
  time       = az_avgs(5,0,0,0,recnum)
  deltat     = az_avgs(6,0,0,0,recnum)
  
  if notquiet gt 0 then begin
     print,'  iteration = ',strtrim(iteration,2),$
           ', time = '   ,strtrim(time     ,2),$
           ', delta t = ',strtrim(deltat   ,2)
  endif

  f     = reform(az_avgs(*,*,abs(q),0,recnum))
  
  if (q le 3) then f = f/100

  if (omega gt 0) and (q le 3) then begin
     f = f*100
     for i=0,N_R-1 do begin
        f(*,i)=f(*,i)/rad(i)/sin(acos(costheta(*)))+omega
        if (max(abs(f(*,i))) eq 0.0) then print,'WARNING : array is identically zero'    
     endfor
     f = f/2./!pi*1e9

     if q eq - 3 then begin
        f = -f/omega
        for i=0,n_theta-1 do begin
           f(i,*) = deriv(rad,f(i,*))*r
        endfor
        for i=0,n_r-1 do begin
           f(*,i) = f(*,i)*sintheta
        endfor
     endif
  endif

  free_lun,lun
  if notquiet eq 2 then begin
     print,name
     stop
  endif

end








