;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  read_shav2.pro  -  Reads shell averages files
;
;       usage:  read_shav,qq,file,recnum,sq,f=f,rad=rad,
;               time=time,deltat=deltat,name=name,
;               notquiet=notquiet,swap=swap
; 
;               where qq        = output quantity
;                     file      = filename
;                     recnum    = record number
;                     sq        = statistical quantity ([0,1,2,3,4,5]=[mean,variance
;                               skewness,kurtosis,min,max]), default=0
;                     f         = output quantity (array in that routine)
;                     rad       = output radius
;                     iteration = iteration
;                     time      = time array
;                     deltat    = time step
;                     name      = quantity name
;                     notquiet  = verbose if smaller then 2
;                     swap      = dependant of the endianess of the file
;
;  M.DeRosa - 4 Sep 1998 - modified from Mark's routine
;  A.S. Brun - 2009 - ASH 1.4 version
;  C.Emeriau-Viard - 10 May 2016 - Version 2.0 (adapted from see_shell_avgs14)
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

pro read_shav2,lqq,file,recnum,sq=sq,f=f,rad=rad,iteration=iteration,time=time,$
               deltat=deltat,name=name,notquiet=notquiet,swap=swap

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 3 then begin
     print,' read_shav,lqq,file,recnum,sq,f=f,rad=rad,iteration=iteration'+$
           'time=time,deltat=deltat,name=name,notquiet=notquiet,swap=swap'
     return
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  close,/all

  if n_elements(lqq) eq 0 then begin
     print,'  read_shav2.pro:  parameter q must be set'
     return
  endif
  if n_elements(file) eq 0 then begin
     print,'  read_shav2.pro:  parameter file must be set'
     return
  endif
  if n_elements(recnum) eq 0 then begin
     print,'  read_shav2.pro:  parameter recnum must be set'
     return
  endif

  s_nq = size(lqq) & s_nq = s_nq(0)
  if s_nq eq 0 then lqq=[lqq]
  s_nq =size(lqq) & s_nq = s_nq(1)

  if not keyword_set(sq)       then sq       = 0
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Associate data file
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  temp=0.0
  openr,lun,file,/get_lun,swap_endian=swap
  readu,lun,temp  &  n_q = fix(temp)
  readu,lun,temp  &  n_r = fix(temp)
  readu,lun,temp  &  n_r_1 = fix(temp)
  shell_avgs=assoc(lun,fltarr(n_r,n_q+1,6))

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Read code quantities
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  rad        = shell_avgs(*,0,1,0)
  nq         = min([n_q,n_r])
  quantities = fix(reform(shell_avgs(0:nq-1,0,2,0)))
    
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Time and iteration informations
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  iteration = shell_avgs(3,0,0,recnum) 
  time      = shell_avgs(4,0,0,recnum)
  nqq        = size(lqq) & nqq = nqq(1)
  deltat    = shell_avgs(5,0,0,recnum)

  if notquiet gt 0 then begin
     print,'iteration = ',strtrim(iteration,2),$
           ', time = '   ,strtrim(time     ,2),$
           ', delta t = ',strtrim(deltat   ,2)
  endif     
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Store quantities 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  f    = dblarr(n_r,nqq)
  name = [] 

  for iq = 0,nqq-1 do begin
     qq = lqq(iq)
     q = where(quantities eq qq)+1
     while (q eq 0) do begin
        print,"This quantity does not exist : ",qq
        print,"Please, enter a new one :"
        read,qq
        q=where(quantities eq qq)+1
     endwhile

     name = [name,get_name2(qq)]
     f(*,iq) = shell_avgs(*,q,sq,recnum)  
  endfor

  free_lun,lun
  if (notquiet eq 2) then begin
     print,name
     stop
  endif

end








