;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  flux_balance2.pro  -  Plots fluxes from round code output
;
;       usage: flux_balance,dir,iter,recnum,lum=lum,glob=glob,sc=sc,$
;              notquiet=notquiet,swap=swap,psf=psf,namepsf=namepsf,$
;              xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax
;               where dir      = data directory (Shell_Avgs output)
;                     file     = iteration number of filename or
;                     savingIDL name
;                     rec      = file record number or number of
;                     record per file
;                     lstar    = luminosity of star modelled
;                     rstar    = stellar radius
;                     glob     = prefix of data directory
;                     sc       = prefix of filenames
;                     notquiet = verbose if smaller than 2 
;                     swap     = dependant of the endianess of files
;                     opl      = set 1 to overplot
;                     psf      = type of output (screen or .eps) 
;                     namepsf  = name of the .eps output file
;                     wnd      = window number
;                     legendd  = legend is set if 0 and is hidden either
;
;  M.DeRosa - 12 Oct 1998 - modified from Mark's routine
;  A.S. Brun - 18 May 2004 - ASH 1.2 version
;  A.S. Brun - 2009 - ASH 1.4 version
;  C.Emeriau-Viard - 18 May 2016 - Version 2.0
; 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names

pro see_flux_balance2,dir,file,rec,nfiles,start,skip,lstar=lstar,rstar=rstar,$
                      rbcz=rbcz,glob=glob,sc=sc,notquiet=notquiet,swap=swap,$
                      opl=opl,psf=psf,namepsf=namepsf,wnd=wnd,legendd=legendd,$
                      xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax,build=build
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^   
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^   

  if not keyword_set(notquiet) then notquiet = 1
  if n_elements(build) eq 0 then begin
     build = 0
     if notquiet ge 1 then begin
        print,'Do you want to read or write a IDL saving file ? (0/1)'
        print,'0: No'
        print,'1: Create'
        print,'2: Read'
        read,build
     endif 
  endif
  
  if build eq 0 and n_params() lt 3 then begin
     print,'flux_balance2,dir,iter,recnum,lstar=lstar,rstar=rstar,glob=glob,sc=sc,'+$
           'notquiet=notquiet,swap=swap,opl=opl,psf=psf,namepsf=namepsf,'+$
           'wnd=wnd,legendd=legendd,xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax'
     return
  endif

  if build eq 1 and n_params() lt 2 then begin
     print,'flux_balance2,dir,savingIDL,recper,nfiles,start,skip,lstar=lstar,'+$
           'rstar=rstar,glob=glob,sc=sc,notquiet=notquiet,swap=swap,opl=opl,'+$
           'psf=psf,namepsf=namepsf,wnd=wnd,legendd=legendd,xmin=xmin,'+$
           'xmax=xmax,ymin=ymin,ymax=ymax'
     return
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  if n_elements(dir) eq 0 then begin
     print,'  flux_balance2 :  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'
  
  if n_elements(file) eq 0 then begin
     if build eq 0 then print,'  flux_balance2:  parameter iter must be set' else $
        print,'  flux_balance2:  parameter savingIDL must be set'
     return
  endif
     
  if n_elements(rec) eq 0 then begin
     if build eq 0 then print,'  flux_balance2:  parameter recnum must be set' else $
        print,'  flux_balance2:  parameter recper must be set'
     return
  endif

  case build of
     0: begin
        iter   = file 
        recnum = rec
     end
     1: begin
        savingIDL = file
        recper    = rec
        
        if n_elements(nfiles) eq 0 then begin
           print,'  flux_balance2:  parameter nfiles must be set'
           return
        endif
        if n_elements(start) eq 0 then begin
           print,'  flux_balance2:  parameter start must be set'
           return
        endif
        if n_elements(skip) eq 0 then begin
           print,'  flux_balance2:  parameter skip must be set'
           return
        endif 
     end
     2: begin
        savingIDL = file
     end
  end
  
  if not keyword_set(rbcz)     then rbcz     = 0 
  if not keyword_set(lstar)    then lstar    = 3.842e33
  if not keyword_set(rstar)    then rstar    = 6.72e10
  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(sc)       then sc       = 0
  if not keyword_set(swap)     then swap     = 0
  if not keyword_set(opl)      then opl      = 0
  if not keyword_set(psf)      then psf      = 0
  if not keyword_set(namepsf)  then namepsf  = "Flux_Balance"
  if not keyword_set(wnd)      then wnd      = 0
  if not keyword_set(legendd)  then legendd  = 0
  if not keyword_set(mag)      then mag      = 0
  if not keyword_set(xmin)     then xmin     = 0
  if not keyword_set(xmax)     then xmax     = 1
  if not keyword_set(ymin)     then ymin     = -1
  if not keyword_set(ymax)     then ymax     = 2

  if glob eq 0 then begin
     dir      = "/dsm/stars2/f/cemeriau/EvolZR/"+dir
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^      
; Graphics device                                                            
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  close,/all

  device,decomposed=0
  r=[0b,255b,130b,255b,255b,255b,255b,0b  ,75b ,0b  ,75b ,0b  ,75b ,255b,255b,255b,255b]
  g=[0b,255b,130b,0b  ,75b ,0b  ,75b ,0b  ,75b ,255b,255b,255b,255b,255b,255b,170b,195b]
  b=[0b,255b,130b,0b  ,75b ,255b,255b,255b,255b,255b,255b,0b  ,75b ,0b  ,75b ,0b  ,75b ]
  tvlct,r,g,b

  device,set_font='Helvetica',/tt_font
  
  !p.font      = 1
  !x.style     = 1
  !x.thick     = 5
  !y.thick     = 5
  !p.thick     = 6
  !p.charthick = 1.8
  !p.charsize  = 2.2
  !x.charsize  = 1
  !y.charsize  = 1
  !x.ticks     = 9
  !p.multi     = 0
  th           = 1

  if opl lt 2 then begin
     if (psf eq 0) then begin
        set_plot,'x'
        window,wnd,xsize=1200,ysize=800
     endif else begin 
        if (psf eq 1) then begin
           set_plot,'ps'
           if build eq 0 then namepsf = namepsf+'_0'+strcompress(iter,/r)+'.eps' else $
              namepsf = savingIDL
           device,/encapsulated,/landscape,/color,bits=8,filename=namepsf
        endif
     endelse
  endif
  
  if build eq 1 then savingIDL = savingIDL+'.idl'

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
;  Set up filename array, etc.
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  print,build,sc

  if build eq 0 then begin
     textnum =strcompress(iter,/r)
     case sc of 
        0: file = dir +'/SHAV/shav_0'+textnum
        1: file = dir +'/shav_0'+textnum
        else: file = dir+textnum
     end
  endif else begin
     case sc of 
        0: savingIDL = dir+'SHAV/'+savingIDL
        else: savingIDL = dir+savingIDL
     end
  endelse
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
;  Get radial kinetic energy flux
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  if build eq 0 then begin
     read_shav2,12,file,recnum,f=Fke,rad=radius,swap=swap,notquiet=notquiet
     
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
;  Get radial enthalpy flux
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
     
     read_shav2,20,file,recnum,f=Fen,rad=radius,swap=swap,notquiet=notquiet
     
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
;  Get radial radiative diffusion flux
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
     
     read_shav2,38,file,recnum,f=Frd,rad=radius,swap=swap,notquiet=notquiet
     
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Get radial entropy diffusion flux
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

     read_shav2,36,file,recnum,f=Fed,rad=radius,swap=swap,notquiet=notquiet
     
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Get radial viscous diffusion flux
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
     
     read_shav2,32,file,recnum,f=Fnu,rad=radius,swap=swap,notquiet=notquiet

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Get radial magnetic energy flux (radial compo of Poynting vector)
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if mag eq 1 then read_shav2,69,file,recnum,f=Fmg,rad=radius,swap=swap,notquiet=notquiet else fmg=fen*0.
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Mean case
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  endif else begin

     lq = [12,20,38,36,32]
     if mag eq 1 then lq=[lq,69]
     print,dir,lq,recper,nfiles,start,skip,'SHAV'
     get_mean2,dir,lq,recper,nfiles,start,skip,'SHAV',glob=1,$
                    sc=sc,notquiet=0,swap=swap,savingIDL=savingIDL
     restore,filename=savingIDL,/verbose
     Fke = yy(*,0)
     Fen = yy(*,1)
     Frd = yy(*,2)
     Fed = yy(*,3)
     Fnu = yy(*,4)
     if mag eq 1 then Fmg = yy(*,5) else Fmg = Fnu*0.0
  endelse

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Compute luminosities
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  ftot = fke+fen+frd+fed+fmg+fnu
  ltot = ftot*4*!dpi*radius^2
  lke  = fke*4*!dpi*radius^2
  len  = fen*4*!dpi*radius^2
  lrd  = frd*4*!dpi*radius^2
  led  = fed*4*!dpi*radius^2
  lnu  = fnu*4*!dpi*radius^2
  lmg  = fmg*4*!dpi*radius^2
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Plots : min, max and title
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  c = opl
  if opl le 1 then begin
     c = 1-psf 
     xtitle = '!17 r/R!D*!N'
     ytitle = '!17 L/L!D*!N'
  endif     
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Plots 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if opl gt 2 then oplot,radius/rstar,ltot/lstar,color=c $
  else plot,radius/rstar,ltot/lstar,/xs,/ys,xr=[xmin,xmax],yr=[ymin,ymax],ytitle=ytitle,xtitle=xtitle,xtickinterval=0.1,color=c
  if opl eq 0 then c = 3
  oplot,radius/rstar,replicate(lstar,n_elements(radius))/lstar,color=c
  if opl eq 0 then c = 5
  oplot,radius/rstar,lke/lstar,linestyle=4,color=c
  if opl eq 0 then c = 7 
  oplot,radius/rstar,len/lstar,linestyle=3,color=c
  if opl eq 0 then c = 9 
  oplot,radius/rstar,lrd/lstar,linestyle=2,color=c
  if opl eq 0 then c = 11 
  oplot,radius/rstar,led/lstar,linestyle=5,color=c
  
  if max(abs(fnu)) gt 0 then begin
     if opl eq 0 then c = 13
     oplot,radius/rstar,lnu/lstar,linestyle=1,color=c
  endif 

  if max(abs(fmg)) gt 0 then begin
     if opl eq 0 then c = 11
     oplot,radius/rstar,lmg/lstar,linestyle=1,color=c
  endif

  if rbcz gt 0 then vline,rbcz,l=2,c=2

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plots : legend
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  !p.charsize=1.2
  if legendd ne 0 then begin
     name1 = ['Total luminosity','Radiative diffusion','Enthalpy','Kinetic energy','Modeled SGS processes']
     nvar  = 5
     ls    = [0,2,3,4,5] 
     ly    = [5,5,5,5,5]
     if opl eq 0 then lc = [1-psf,3,5,7,9,11,13]
     if max(abs(lnu)) gt 0 then begin
        name1 = [name1,'Viscous diffusion']
        nvar  = nvar + 1
        ls    = [ls,1]
        ly    = [ly,5]
        if opl eq 0 then lc = [lc,13]
     endif
     if max(abs(lmg)) gt 0 then begin
        name1 = [name1,'Magnetic contribution']
        nvar  = nvar + 1
        ls    = [ls,1]
        ly    = [ly,5]
        if opl eq 0 then lc = [lc,11]
     endif
     if opl eq 0 then legend,name1,linestyle=ls,color=lc,location=legendd,thick=ly else legend,name1,linestyle=ls,location=legendd,thick=ly
  endif

  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plots : output
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if (psf eq 1) then begin 
     device,/close
     mv_var = 'mv '+namepsf+' '+dir+'/figs/'+namepsf
     print,mv_var
     spawn,mv_var
  endif

  if notquiet eq 2 then stop
    
end




