;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;   see_scalar.pro  -  Plot scalar evolution
;                      Modified from Mark's IDL routine
;
;       usage: see_scalar2,dir,lq,sq,recper,nfiles,start,skip,files=files,$
;              glob=glob,sc=sc,notquiet=notquiet,swap=swap,opl=opl,psf=psf,$
;              namepsf=namepsf,wnd=wnd,legendd=legendd,daysflag=daysflag,$
;              xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax$
;              
;               where dir      = data directory
;                     lq       = scalar output quantities
;                     sq       = option (1=mean(quantity), 2=min(quantity), 3=max(quantity)
;                     recper   = number of records per file
;                     nfiles   = number of files to read
;                     start    = starting file iteration
;                     skip     = number of iterations between files
;                     files    = list of files (used if nfiles, start
;                     and skip are nul)
;                     glob     = prefix of data directory
;                     sc       = prefix of filenames
;                     notquiet = verbose if smaller than 2
;                     swap     = dependant on the endianess of files
;                     opl      = set if overplot command should be used
;                     psf      = type of output (screen or .eps)
;                     namepsf  = name of the .eps output file
;                     wnd      = number of the window for screen output
;                     legendd  = legend is set if 0 and is hidden either
;                     daysflag = set if time units are days (rather than sec)
;
;  M.DeRosa - 25 Aug 1998 - modified from Mark's routine
;             15 Sep 1998 - added files keyword
;  A.S.Brun - 28 Jun 1999 - added linestyl keyword
;  M.DeRosa -  6 Jul 1999 - if directory search, weed out invalid files
;  A.S.Brun - 29 Nov 2000 - added sc keyword for file with or without sc_0
;  C.Emeriau_Viard - 13 May 2016 - Version 2.0
; 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names
@get_units
 
pro see_scalar2,dir,lq,sq,recper,nfiles,start,skip,rbcz=rbcz,files=files,$
                glob=glob,sc=sc,notquiet=notquiet,swap=swap,opl=opl,psf=psf,$
                namepsf=namepsf,wnd=wnd,legendd=legendd,daysflag=daysflag,$
                avg=avg,xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 7 then begin
     print,'see_scalar2,dir,lq,sq,recper,nfiles,start,skip,rbcz=rbcz,'+$
           'files=files,glob=glob,sc=sc,notquiet=notquiet,swap=swap,'+$
           'opl=opl,psf=psf,namepsf=namepsf,wnd=wnd,legendd=legendd,'+$
           'daysflag=daysflag,xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax'
     return
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(dir) eq 0 then begin
     print,'  see_scalar2.pro:  parameter dir must be set'
     return
  endif

  if n_elements(lq) eq 0 then begin
     print,'  see_scalar2.pro:  parameter lq must be set'
     return
  endif

  if n_elements(sq) eq 0 then begin
     print,'  see_scalar2.pro:  parameter m must be set'
     return
  endif

  if n_elements(recper) eq 0 then begin
     print,'  see_scalar2.pro:  parameter recper must be set'
     return
  endif else recordsperfile=recper

  if n_elements(nfiles) eq 0 then begin
     print,'  see_scalar2.pro:  parameter nfiles must be set'
     return
  endif

  if n_elements(start) eq 0 then begin
     print,'  see_scalar2.pro:  parameter start must be set'
     return
  endif

  if n_elements(skip) eq 0 then begin
     print,'  see_scalar2.pro:  parameter skip must be set'
     return
  endif

  size_nfiles = size(nfiles) & size_nfiles1 = size_nfiles(0) & size_nfiles2 = size_nfiles(1)  
  size_start  = size(start)  & size_start1  = size_start(0)  & size_start2  = size_start(1)
  size_skip   = size(skip)   & size_skip1   = size_skip(0)   & size_skip2   = size_skip(1)

  if (size_nfiles1 ne size_start1) or (size_start1 ne size_skip1) or (size_skip1 ne size_nfiles1) then begin
     print,'Nfiles, start and skip must havr the same number of parameters'
     return
  endif else begin
     size = size_nfiles1
     case size of
        0: begin
           nfiles   = [nfiles]
           start    = [start]
           skip     = [skip]
           n_models = 1
        end
        1: begin
           if (size_nfiles2 ne size_start2) or (size_start2 ne size_skip2) or (size_skip2 ne size_nfiles2) then begin
              print,'Nfiles, start and skip must havr the same number of parameters'
              return
           endif else begin
              n_models = size_nfiles2
           endelse
        end
     end
  endelse

  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(sc)       then sc       = 1
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0
  if not keyword_set(opl)      then opl      = 0
  if not keyword_set(psf)      then psf      = 0
  if not keyword_set(namepsf)  then namepsf  = "Scalar"
  if not keyword_set(wnd)      then wnd      = 0
  if not keyword_set(legendd)  then legendd  = 0
  if not keyword_set(daysflag) then daysflag = 1
  if not keyword_set(avg)      then avg      = 0
  if not keyword_set(rbcz)     then rbcz     = dblarr(n_models)
  if not keyword_set(xmin)     then xmin     = -1000
  if not keyword_set(xmax)     then xmax     = -1000
  if not keyword_set(ymin)     then ymin     = -1000
  if not keyword_set(ymax)     then ymax     = -1000
  
  if glob eq 0 then begin
     dir='/dsm/stars2/f/cemeriau/EvolZR/'+dir
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  close,/all
  
  r=[0b,255b,130b,255b,255b,0b  ,0b  ,0b  ,255b,255b]
  g=[0b,255b,130b,0b  ,0b  ,0b  ,255b,255b,255b,170b]
  b=[0b,255b,130b,0b  ,255b,255b,255b,0b  ,0b  ,0b  ]
  tvlct,r,g,b
  
  device,set_font='Helvetica',/tt_font
  
  !p.font         = 1
  !x.style        = 1
  !x.thick        = 4
  !y.thick        = 4
  !p.thick        = 4
  !p.charthick    = 1.8
  !p.charsize     = 1.8
  !x.charsize     = 1
  !y.charsize     = 1
  !p.multi        = 0
  th              = 5

  if (psf eq 0) and (opl le 1) then begin
     set_plot,'x'
     window,wnd,xsize=1200,ysize=800
     device,decomposed=0
  endif else begin 
     if (psf eq 1) then begin
        set_plot,'ps'
        namepsf=namepsf+'_0'+strcompress(files(0),/r)+'_to_0'+strcompress(files(nfiles-1),/r)+'.eps'
        device,/encapsulated,/landscape,/color,bits=8,filename=namepsf
     endif
  endelse
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Set up filename array, etc.
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  file = []
  sep  = dblarr(n_models)
  ntt  = []
  nt   = 0 
  for i = 0,n_models-1 do begin

     files = lindgen(nfiles(i))*skip(i)+start(i)
     textnum=strcompress(files,/r)
     if strmid(dir(i),strlen(dir(i))-1,1) ne '/' then dir(i) = dir(i)+'/'

     case sc of
        1   : file_aux = dir(i)+'Scalar/scalar_0'+textnum
        2   : file_aux = dir(i)+'0'+textnum
        else: file_aux = dir(i)+textnum 
     end
     file        = [file,file_aux]
     nfiles_aux  = size(file_aux) & nfiles_aux = nfiles_aux(1)       
     ntt_aux     = make_array(nfiles_aux,/long,value=recordsperfile(i))     
     nt_aux      = long(total(ntt_aux))
     ntt         = [ntt,ntt_aux]
     nt          = nt + nt_aux
     sep(i)      = nt
  endfor
  nfiles = size(file) & nfiles = nfiles(1)
  
  t     = fltarr(nt)   
  dt    = fltarr(nt)   
  
  nsize = size(lq) & nvar = nsize(1) & if notquiet eq 2 then print,'nb var:',nvar
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Check variable list for ratio
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
   
   l     = 0
   n_var = 0
   while l lt nvar do begin
      if lq(l) lt 0 then begin
         l = l+1 
         if l eq nvar then begin
            print,'lq not coherent for ratios'
            return
         endif else begin
            if lq(l) ge 0 then begin
               print,'lq not coherent for ratios'
               return
            endif
         endelse
      endif
      l     = l+1
      n_var = n_var + 1
   endwhile

   c_nvar = nvar   
   nvar  = n_var

   print,'N variables : ',nvar

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Read in data
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

   f     = fltarr(nt,nvar)*0.0
   favg  = fltarr(nvar)*0.0
   favg_p= fltarr(nvar)*0.0
  
   name1 = strarr(nvar)
   col1  = strarr(nvar)
   lin1  = strarr(nvar)
   thi1  = strarr(nvar)

   j = 0
   for i=0,nfiles-1 do begin
      if i eq sep[j] then begin 
         j = j+1
      endif
      for recnum=0,ntt(i)-1 do begin 
         l     = 0 
         l_aux = 0
         while l lt c_nvar do begin
            if (i eq 0) and recnum eq 0 then nq = notquiet else nq = 0
            qq  = abs(lq(l))
            if rbcz(j) eq 0 then begin
               read_scalar2,qq,file(i),recnum,sq=sq,f=ff,time=tt,deltat=dtt,name=name,notquiet=nq,swap=swap 
            endif else begin
               read_scalar_zone2,qq,file(i),recnum,sq=sq,rbcz=rbcz(j),f=ff,time=tt,deltat=dtt,name=name,notquiet=nq,swap=swap
               
            endelse
         if qq lt 0 then  begin
               l   = l+1
               qq = -lq(l)
               if rbcz(j) eq 0 then begin
                  read_scalar2,qq,file(i),recnum,sq=sq,f=ff2,notquiet=nq,swap=swap 
               endif else begin
                  read_scalar_zone2,qq,file(i),recnum,sq=sq,rbcz=rbcz(j),f=ff2,notquiet=nq,swap=swap
               endelse
               ff = ff2/ff
            endif

            name1(l_aux)=name
            f(i*ntt(i)+recnum,l_aux) = ff
            dt(i*ntt(i)+recnum)  = dtt
            t(i*ntt(i)+recnum)   = tt
            l                    = l+1  
            l_aux                = l_aux+1
         endwhile
      endfor
   endfor
   
   namevar = name1

   j  = 0
   to = t(0)
   t1 = 0
   for i = 0,nt-1 do begin
      if i eq sep[j] then begin 
         to = t(i)
         dt = t(i-1) - t(i-2)
         t1 = t(i-1) + dt 
      endif
      t(i) = t(i) - to + t1
   endfor

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Calculate time average (if asks)
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

   if n_models eq 1 and avg ge start(0) then begin
      n_avg = (avg-start(0))/skip(0)
      for l = 0,nvar-1 do begin
         tavg = 0
         for  fi = n_avg,nfiles-1 do begin
            for recnum = 0,ntt(fi)-1 do begin
               favg[l] = favg[l] + f(fi*ntt(fi)+recnum,l) * dt(fi*ntt(fi)+recnum)
               tavg = tavg + dt(fi*ntt(fi)+recnum)
            endfor
         endfor
      endfor
      favg = favg/tavg

      print,' '
      print,name1(0),' : ',favg(0),'  ('+strcompress(f(nt-1,0),/r)+')'
      favg_p[0] = favg(0)
      s_absolu = strcompress(favg(0),/r)
      s_perc   = strcompress(favg(0),/r)
      s_name   = name1(0)
      for l = 1,nvar-1 do begin
         print,name1(l),' : ',favg(l),favg(l)/favg(0),'  ('+strcompress(f(nt-1,l),/r)+')'
         favg_p[l] = favg(l)/favg(0)
         s_absolu = s_absolu + ' & ' + strcompress(favg(l),/r) 
         s_perc   = s_perc + ' & ' + strcompress(favg_p(l),/r) 
         s_name   = s_name + ' & ' + name1(l)
      endfor 
      print,' '
      print,s_name
      print,s_absolu
      print,s_perc
      print,' '
   endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plots : min, max and title
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

   c = opl

   xtitle = '!17 time (sec)'
   ytitle = name
   if daysflag then begin
      t=t/(3600.*24.d0)
      xtitle = 'Time [days]'
   endif
   
   if opl le 1 then begin
      c = 1-psf
            
      to=t(0)

      if notquiet eq 2 then  begin
         print,'starting time: ',to
         print,'.c automatically draw all var'
      endif
      
      yra=min(f) & yrb=max(f)
      if xmin eq -1000 then xmin = 0
      if xmax eq -1000 then xmax = t(nt-1)-to
      if ymin eq -1000 then ymin = yra
      if ymax eq -1000 then ymax = yrb
      
      if notquiet gt 0 then begin
         answ1 = 0
         print,'min-max proposed:',ymin,ymax 
         print,'do you want to retain them (0/1)?'
         read,answ1
         if (answ1 ne 0) then begin
            print,'Please enter new values:'
            read,ymin,ymax
         endif
      endif
      
      dx  = xmax - xmin
      e   = fix(alog10(dx))
      a   = fix(dx/10^e)
      xt  = a*10^(e-1)
   endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plots 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

   title = 'Evolution of energies'
   if rbcz(0) gt 0 then title = title + ' in CZ'
   if rbcz(0) lt 0 then title = title + ' in RZ'

   if opl gt 1 then oplot,t,f(*,0),thick=th,color=c else plot_io,t,f(*,0),/xs,/ys,xr=[xmin,xmax],yr=[ymin,ymax],xtitle=xtitle,$
      title=title,thick=th,xtickinterval=xt,color=c
   col1[0] = c
   lin1[0] = 0
   thi1[0] = th
   
   for l=1,nvar-1 do begin
      if (l le 5) then begin
         if opl eq 0 then c = 2+l
         oplot,t,f(*,l),thick=th,line=l,color=c
         col1[l] = c
         lin1[l] = l
         thi1[l] = th
      endif else begin
         if opl eq 0 then c = l-3
         oplot,t,f(*,l),thick=2*th,line=l-5,color=c
         col1[l] = c
         lin1[l] = l-5
         thi1[l] = 2*th
      endelse
   endfor
   
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plots : legend
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

   if (legendd ne 0) and (opl lt 2) then legend,name1,linestyle=lin1,color=col1,thick=thi1,location=legendd

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plots : output
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
   
   if (psf eq 1) then begin
      device,/close
      mv_var='mv '+namepsf+' '+dir+'/figs/'+namepsf
      print,mv_var
      spawn,mv_var
      set_plot,'x'
   endif
   
   if notquiet gt 0 then begin
      stop
   endif
   
end
