;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  time_lat_azav2.pro  -  Reads in shell average output and plot versus time
;
;       usage:  time_lat_azav2,dir,q,nfiles,start,skip,lr=lr,rstar=rstar,
;                              omega=omega,glob=glob,sc=sc,notquiet=notquiet,
;                              swap=swap,psf=psf,namepsf=namepsf,wnd=wnd,
;                              build=build,file_build=file_build
;
;               where dir        = data directory
;                     q          = output quantity index (starting at 1)
;                     ([0,1,2,3,4,5]=[mean,variance,skewness,kurtosis,min,max]), default=0
;                     recper     = number of records per file
;                     nfiles     = number of files to read
;                     start      = starting file iteration
;                     skip       = number of iterations between files
;                     lr         = list of radial grid points
;                     rstar      = star radius
;                     omega      = plot omega at omega rate (if not nul)
;                     glob       = prefix of data directory 
;                     sc         = prefix of filenames      
;                     notquiet   = verbose if smaller than 2
;                     swap       = dependant on the endianess of files
;                     used 
;                     psf        = type of output (screen or .eps)
;                     namepsf    = name of the .eps output file 
;                     wnd        = number of the window for screen
;                     output 
;                     build      = use of an IDL saving file (1) or AZAV
;                     files (0)
;                     file_build = name of IDL saving file (write if
;                     build = 0 and read if build = 1)  
;
;  A.S. Brun and J. Varela- 2014 - ASH 2.0 version
;  C.Emeriau-Viard - 21 June 2016 - Version 2.0
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names
@get_units

pro time_lat_azav2,dir,q,nfiles,start,skip,recper,lr=lr,rstar=rstar,omega=omega,$
                   app=app,glob=glob,sc=sc,notquiet=notquiet,swap=swap,$
                   psf=psf,namepsf=namepsf,wnd=wnd,build=build,file_build=file_build
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if not keyword_set(build) then begin
     build = 0
     print,'Do you have a IDL saving file ? (0/1) '
     read,build
     build = 1-build
  endif
  
  if build eq 0 and n_params() lt 6 then begin
     print,'time_lat_azav2,dir,q,nfiles,start,skip,recper,lr=lr,rstar=rstar,'+$
           'app=app,omega=omega,glob=glob,sc=sc,notquiet=notquiet,swap=swap,'+$
           'psf=psf,namepsf=namepsf,wnd=wnd,build=build,file_build=file_build'
     return
  endif
  
  if build eq 1 and n_params() lt 2 then begin
     print,'time_lat_azav2,dir,q,lr=lr,rstar=rstar,omega=omega,'+$
           'app=app,glob=glob,sc=sc,notquiet=notquiet,swap=swap,psf=psf'+$
           'namepsf=namepsf,wnd=wnd,build=build,file_build=file_build'
     return
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  if n_elements(dir) eq 0 then begin
     print,'  time_lat_azav.pro:  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'
  
  if n_elements(q) eq 0 then begin
     print,'  time_lat_azav.pro:  parameter q must be set'
     return
  endif
  
  if build eq 0 then begin     
     if n_elements(nfiles) eq 0 then begin
        print,'  time_lat_azav.pro:  parameter nfiles must be set'
        return
     endif
     if n_elements(start) eq 0 then begin
        print,'  time_lat_azav.pro:  parameter start must be set'
        return
     endif
     if n_elements(skip) eq 0 then begin
        print,'  time_lat_azav.pro:  parameter skip must be set'
        return
     endif
  endif
  
  if not keyword_set(app)        then app        = 1
  if not keyword_set(lr)         then lr         = [20,200,400]
  if not keyword_set(rstar)      then rstar      = 1
  if not keyword_set(rbcz)       then rbcz       = 0
  if not keyword_set(omega)      then omega      = 0
  if not keyword_set(glob)       then glob       = 0
  if not keyword_set(sc)         then sc         = 1
  if not keyword_set(notquiet)   then notquiet   = 0
  if not keyword_set(swap)       then swap       = 0
  if not keyword_set(psf)        then psf        = 0
  if not keyword_set(namepsf)    then namepsf    = 'ButterflyDiagram'
  if not keyword_set(wnd)        then wnd        = 0
  if not keyword_set(build)      then build      = 0
  if not keyword_set(file_build) then file_build = 'Butterfly_Build.idl'
  N_depth = n_elements(lr) ; three depths for lat plot

  tv       = 1 
  flip     = 0 
  daysflag = 1

  if glob eq 0 then dir = '/dsm/stars2/f/cemeriau/EvolZR/'+dir
  
  file_build = dir+file_build
  
  if build eq 0 then files=lindgen(nfiles)*skip+start
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
; Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
  
  close,/all

  !p.multi=[0,1,N_depth]
  !y.margin=[4,4]  
  !x.tickinterval = 2
  !x.ticklayout=0
  !x.thick=5 & !y.thick=5
  !x.minor = 5

  if (psf eq 0) then begin
     set_plot,'x'
     device,decomposed=0
     window,wnd
  endif else begin
     set_plot,'ps'
     if build eq 0 then namepsf=namepsf+'_0'+strcompress(files(0),/r)+'_to_0'+strcompress(files(nfiles-1),/r)+'.eps' $
     else namepsf = namepsf+'.eps'
     device,/landscape,/color,bits=8,filename=namepsf,/helvetica
  endelse

  bw=0                                          ;1
  if bw eq 1 then loadct_mld,0 else loadct_mld,41 ; for color saturation fac mul=0.3 is ok

  if (omega ge 0) then begin
     levels=100+findgen(21)*20
     c_labels=[0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,0]
  endif else begin
     levels=mini(0)+(maxi(0)-mini(0))/10*findgen(11)
     c_labels=[0,0,1,0,1,0,1,0,1,0,0]
  endelse

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
; Set up filename array, etc.
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  ans2=1
  if (q eq 3) then begin
     print,'Do you want to plot Omega or Vphi (0/1)?'
     read,ans2
  endif
  Global_rate=2.6d-6*omega

  if build eq 0 then begin ; no saving read AZAV files
     
     file    = strarr(nfiles)  
     nt      = intarr(nfiles)
     nt(*)   = recper
     nframes = total(nt)
     timel   = fltarr(nframes)
     
     textnum = strcompress(files,/r)      
     
     case sc of 
        1:    file = dir+'/AZAV/azav_0'+textnum
        2:    file = dir+'0'+textnum
        else: file = dir+textnum
     end
     
     if notquiet le 1 then print,'from: ',files(0),' to ',files(nfiles-1)
     
     read_azav2,q,file(0),0,f=f,rad=rad,theta=theta,time=time,$
                name=title,notquiet=2,swap=swap,omega=omega
     
  endif else begin
     n_fbuild = size(file_build) & n_fbuild = n_fbuild(0)
     if n_fbuild eq 0 then begin
        restore,filename = file_build,/verbose
     endif else begin
        nframes_tot = 0 
        timel_aux   = []
        time_end    = 0
        n_files     = size(file_build) & n_files = n_files[1]
        delta       = []
        t_max       = []
        for i = 0,n_files-1 do begin ; get total nframes
           restore,filename = file_build(i),/verbose
           nframes_aux = size(v_lat) & nframes_aux = nframes_aux[1]
           print,i,' -- ',nframes_aux
           nframes_tot = nframes_tot + nframes_aux
           n_theta   = size(theta) & n_theta = n_theta[1]
           timel_aux = [timel_aux,timel+time_end]
           delta     = [delta,timel(1)-timel(0)]
           t_s = size(timel_aux) & t_s = t_s[1]
           t_max     = [t_max,timel_aux(t_s-1)-time_end]
           time_end = timel_aux(t_s-1)
           print,'Time_end : ',time_end
        endfor

        min_delta = min(delta)
        N_t       = []
        for i = 0,n_files-1 do begin
           nt_aux = fix(t_max(i)/min_delta)
           N_t = [N_t,nt_aux]
        endfor
        nframes_tot = fix(total(N_t)) 
        print,'Delta : ',delta
        print,'N_t : ',n_t
        print,'Nframes : ',nframes_tot

        v_lat_aux = fltarr(nframes_tot,n_theta,n_depth)
        nframes_begin = 0
        timel_aux = []
        time_end  = 0
        for i = 0,n_files-1 do begin
           restore,filename = file_build(i),/verbose
;           nframes_aux = size(v_lat) & nframes_aux = nframes_aux[1]
           timel = congrid(timel,n_t(i),/interp)
           timel_aux = [timel_aux,timel+time_end]
           t_s = size(timel_aux) & t_s = t_s[1]
           time_end = timel_aux(t_s-1)
           nframes_aux = N_t(i)
           nframes_end = nframes_begin+nframes_aux
           print,nframes_begin,nframes_end-1
           n_theta   = size(theta) & n_theta = n_theta[1]
           print,'NTHETA :',n_theta
 ;          v_interp = v_lat
           v_interp = congrid(v_lat,N_t(i),n_theta,n_depth,/interp)
           v_lat_aux(nframes_begin:nframes_end-1,*,*) = v_interp
           nframes_begin = nframes_end
        endfor
        v_lat   = v_lat_aux
        nframes = nframes_tot
        timel   = timel_aux 
     endelse
  endelse     

  if notquiet lt 1 then print,title
     
  n_theta = size(theta) & n_theta = n_theta[1]
  n_r     = size(rad)   & n_r     = n_r[1]
  to      = time/86400
     
  costheta = cos(theta)
  lat=reverse(90.-acos(costheta)*!radeg) 
     
  if build eq 0 then begin
     v_lat = fltarr(nframes,N_theta,N_depth)
     if notquiet lt 1 then print,'depths: ',N_depth,' r = ',rad(lr)/rstar   
  endif
  ttit1=strarr(N_depth)

  textu=get_unit2(title)
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
; Plot : minima and maxima
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  idn=0 & idx=N_theta-1         ; From north pole to south
  
  vmin=0.0 & vmax=vmin
  if (ans2 eq 0) then begin
     title='Omega'
     vmin=Global_rate/2./!pi*1e9 ; otherwise get 0 when Omega for vmin
     textu=' nHz'
  endif

  mini = fltarr(N_depth)
  maxi = fltarr(N_depth)

  if build eq 0 then begin
     ind = 0
     for ifile = 0,nfiles-1 do begin 
        for it = 0,nt(ifile)-1 do begin
           print,'Files : ',ifile,' -- recper : ',nt(ifile)
           read_azav2,q,file(ifile),it,f=f,rad=rad,theta=theta,time=time,$
                      name=title,notquiet=2,swap=swap,omega=omega           
           if q eq -3 then f = f*app
           if (daysflag eq 1) then time=time/(3600.*24d0)
           timel(ind)=time-to
           for dd = 0,n_depth-1 do begin
              j = lr(dd)
              v = f(*,j)
              if ifile eq 0 and it eq 0 then begin
                 vaux     = minmax(v(idn:idx))
                 mini(dd) = vaux[0]
                 maxi(dd) = vaux[1]
              endif else begin
                 mini(dd) = min([mini(dd),mini(v(idn:idx))])
                 maxi(dd) = max([maxi(dd),maxi(v(idn:idx))])
              endelse
              
              v=reverse(v,1)    ; increasing latitudes
                                
              if (flip eq 1) then begin ; flip longitudes
                 print,' '
                 print,'use flip=1!'
                 print,' '
                 v_tmp=v
                 for i=0,N_theta-1 do begin
                    v(i)=v_tmp(N_theta-i-1)
                 endfor
              endif
              sp=max(rad)/200.
              v_lat(ind,*,dd)=v(*)
           endfor
           ind = ind +1
        endfor
     endfor
     print,'which time are we saving ? '
     print,'Saving : ',file_build
     save,filename=file_build,title,theta,rad,v_lat,time,n_depth,lr,timel,nframes,/verbose
  endif else begin
     for dd = 0,n_depth-1 do begin
        mini(dd) = min(v_lat(*,idn:idx,dd))
        maxi(dd) = max(v_lat(*,idn:idx,dd))
     endfor
  endelse
     
  repet = 1 
  while repet eq 1 do begin
     for dd=0,n_depth-1 do begin
        print,mini(dd),maxi(dd), '  at N_R =', lr(dd)
        print,'Do you want to keep them (0/1)'
        read,ans
        if (ans eq 1) then begin
           print,'Enter new min/max:'
           read,a,b
           mini(dd)=a
           maxi(dd)=b
        endif
     endfor
     
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plot : Butterfly
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 

     
     print,'Time sequence:',timel(0),timel(nframes-1)
     timel = timel/1000

     v_lat_mean=fltarr(N_theta,N_depth) & v_lat_mean(*,*)=0.0

     for ii=N_depth-1,0,-1 do begin
        
        ttit1(ii)=title+' @ r = '+strtrim(string(rad(lr(ii))/rstar(0),format='(g10.2)'),2)+$
                  ' R' & print,ttit1(ii)
        
        ii1=N_depth-1-ii
        if (ii1 eq 0) then begin
           contour,v_lat(*,*,ii),timel,lat,yr=[-90,90],xr=[0,timel(nframes-1)],$
                   /xsty,/ysty,xtit='!17 time !6[!17 10!U3!N days!6]!17',ytit='!17 latitude !6[!17deg!6]!17',$
                   /nodata,yticklen=-abs(!p.ticklen),xticklen=-abs(3*!p.ticklen),charsiz=3.2,$
                   position=[0.1,0.08+0.30*ii1,0.9,0.38+0.30*ii1],tit=ttit1(ii)
        endif else begin
           contour,v_lat(*,*,ii),timel,lat,yr=[-90,90],xr=[0,timel(nframes-1)],$
                   /ysty,ytit='!17 latitude !6[!17deg!6]!17',xs=4,$
                   /nodata,yticklen=-abs(!p.ticklen),xticklen=-abs(3*!p.ticklen),charsiz=3.2,$
                   position=[0.1,0.08+0.30*ii1,0.9,0.38+0.30*ii1]
        endelse
        
                                ; temporal average
        mean_sub=0
        if (mean_sub eq 1) then begin
           v_lat_mean(*,ii)=total(v_lat(*,*,ii),1)/nframes
           For k=0,nframes-1 do begin
              v_lat(k,*,ii)=v_lat(k,*,ii)-v_lat_mean(*,ii)
           Endfor
        endif                   ; mean_sub
        
        if bw eq 1 then begin
           mnbw=min(v_lat) & mxbw=max(v_lat)
           for k=0,nframes-1 do begin
              for j=0,N_theta-1 do begin 
                 if v_lat(k,j,ii) lt 0.0 then v_lat(k,j,ii)=mnbw
                 if v_lat(k,j,ii) gt 0.0 then v_lat(k,j,ii)=mxbw
              endfor
           endfor 
        endif
        
                                ;  overplot image
        x0=!p.clip(0)  &  y0=!p.clip(1)
        xsiz=!p.clip(2)-x0  &  ysiz=!p.clip(3)-y0
        
; smoothing in time
                                ; v_lat=smooth(v_lat,[1,4])
        if (psf eq 0) then remap=congrid(v_lat(*,*,ii),xsiz,ysiz) else remap=v_lat(*,*,ii)
        
        mul=1.0  
        
        scim,remap,scale=mul*[mini(ii),maxi(ii)],outim=outim,/nowin
     
        tv,smooth(outim,2),x0,y0,xsiz=xsiz,ysiz=ysiz
        
;  redraw border
        plots,[x0,x0,x0+xsiz,x0+xsiz,x0],[y0,y0+ysiz,y0+ysiz,y0,y0],/device,thick=5
     
     Endfor
 
     if psf eq 0 then begin
        print,'Is the plot correct ? (0/1)'
        read,repet
     endif else begin
        repet = 0
     endelse

  endwhile
  
  if (psf eq 1) then begin 
     device,/close
     mv_var = 'mv '+namepsf+' '+dir+'/figs/'+namepsf
     print,mv_var
     spawn,mv_var
     set_plot,'x'
  endif
  
end



